searchNodes=[{"doc":"Send commands to Z-Wave devicesGrizzly provides the send_command function as the way to send a command to Z-Wave devices.The send_command function takes the node id that you are trying to send a command to, the command name, and optionally command arguments and command options.A basic command that has no options or arguments looks like this:Grizzly.send_command(node_id, :switch_binary_get)A command with command arguments:Grizzly.send_command(node_id, :switch_binary_set, value: :off)Also, a command can have options.Grizzly.send_command(node_id, :switch_binary_get, [], timeout: 10_000, retries: 5)Some possible return values from send_command are:{:ok, Grizzly.Report.t()} - the command was sent and the Z-Wave device responded with a report. See Grizzly.Report for more information.{:error, :including} - current the Z-Wave controller is adding or removing a device and commands cannot be processed right now{:error, :firmware_updating} - current the Z-Wave controller is updating firmware and commands cannot be processed right now{:error, reason} - there was some other reason for an error, two common ones are: :nack_responseFor a more detailed explanation of the responses from a send_command call see the typedoc for Grizzly.send_command_response().Events from Z-WaveEvents generating from a Z-Wave device, for example a motion detected event, can be handled via the Grizzly.subscribe_command/1 and Grizzly.subscribe_commands/1 functions. This will allow you to subscribe to specific commands. When the command is received from the Z-Wave network it will placed in a Grizzly.Report and set to the subscribing process. The node that generated the report can be accessed with the :node_id field in the report.iex&gt; Grizzly.subscribe_command(:battery_report) # sometime latter iex&gt; flush {:grizzly, :event, %Grizzly.Report{command: %Grizzly.ZWave.Command{name: :battery_report}}}","ref":"Grizzly.html","title":"Grizzly","type":"module"},{"doc":"List the command for a particular command class","ref":"Grizzly.html#commands_for_command_class/1","title":"Grizzly.commands_for_command_class/1","type":"function"},{"doc":"List the support commands","ref":"Grizzly.html#list_commands/0","title":"Grizzly.list_commands/0","type":"function"},{"doc":"Send a raw binary to the Z-Wave nodeThis function does not block and expects the sending process to handle the lifecycle of the command being sent. This maximizes control but minimizes safety and puts things such as timeouts, retries, and response handling in the hand of the calling process.When sending the binary ensure the binary is the encoded Grizzly.ZWave.Commands.ZIPPacket.seq_no = 0x01 {:ok, my_command} = Grizzly.ZWave.Commands.SwitchBinaryGet.new() {:ok, packet} = Grizzly.ZWave.Commands.ZIPPacket.with_zwave_command(my_command, seq_no) binary = Grizzly.ZWave.to_binary(packet) Grizzly.send_binary(node_id, binary)This is helpful when you need very fine grade control of the Z/IP Packet or if you not expecting a response from a Z-Wave network to handle the back and forth between your application and the Z-Wave network. Also, this can be useful for debugging purposes.First check if send_command/4 will provide the functionality that is needed before using this function.After sending a binary packet the calling process will receive messages in the form of:{:grizzly, :binary_response, binary}","ref":"Grizzly.html#send_binary/2","title":"Grizzly.send_binary/2","type":"function"},{"doc":"Send a command to the node via the node id or to Z/IP GatewayTo talk to your controller directly you can pass :gateway as the node id. This is helpful because your controller might not always be the same node id on any given network. This ensures that not matter node id your controller is you will still be able to query it and make it perform Z-Wave functions. There are many Z-Wave functions a controller do. There are helper functions for these functions in Grizzly.Network and Grizzly.Node.","ref":"Grizzly.html#send_command/4","title":"Grizzly.send_command/4","type":"function"},{"doc":"Subscribe to a command event from a Z-Wave device","ref":"Grizzly.html#subscribe_command/1","title":"Grizzly.subscribe_command/1","type":"function"},{"doc":"Subscribe to many events from a Z-Wave device","ref":"Grizzly.html#subscribe_commands/1","title":"Grizzly.subscribe_commands/1","type":"function"},{"doc":"Unsubscribe to an event","ref":"Grizzly.html#unsubscribe_command/1","title":"Grizzly.unsubscribe_command/1","type":"function"},{"doc":"","ref":"Grizzly.html#t:command/0","title":"Grizzly.command/0","type":"type"},{"doc":"","ref":"Grizzly.html#t:command_opt/0","title":"Grizzly.command_opt/0","type":"type"},{"doc":"A custom handler for the command.See Grizzly.CommandHandler behaviour for more documentation.","ref":"Grizzly.html#t:handler/0","title":"Grizzly.handler/0","type":"type"},{"doc":"","ref":"Grizzly.html#t:node_id/0","title":"Grizzly.node_id/0","type":"type"},{"doc":"The response from sending a Z-Wave commandWhen everything is okay the response will be {:ok, Grizzly.Report{}}. For documentation about a report see Grizzly.Report module.When there are errors the response will be in the pattern of {:error, reason}.Three reasons that Grizzly supports for all commands are :nack_response, :update_firmware, and :including.A :nack_response normally means that the Z-Wave node that you were trying to send a command to is unreachable and did not receive your command at all. This could mean that the Z-Wave network is overloaded and you should reissue the command, the device is too far from the controller, or the device is no longer part of the Z-Wave network.Grizzly by default will try a command 3 times before sending returning a :nack_response. This is configurable via the :retries command option in the Grizzly.send_command/4 function. This is useful if you are going to have a known spike in Z-Wave traffic.In you receive the reason for the error to be :including that means the controller is in an inclusion state and your command will be dropped if we tried to send it. So we won't allow sending a Z-Wave command during an inclusion. It's best to wait and try again once your application is done trying to include.","ref":"Grizzly.html#t:send_command_response/0","title":"Grizzly.send_command_response/0","type":"type"},{"doc":"","ref":"Grizzly.html#t:seq_number/0","title":"Grizzly.seq_number/0","type":"type"},{"doc":"Behaviour for how commands should handle incoming Z-Wave messages","ref":"Grizzly.CommandHandler.html","title":"Grizzly.CommandHandler","type":"behaviour"},{"doc":"","ref":"Grizzly.CommandHandler.html#c:handle_ack/1","title":"Grizzly.CommandHandler.handle_ack/1","type":"callback"},{"doc":"","ref":"Grizzly.CommandHandler.html#c:handle_command/2","title":"Grizzly.CommandHandler.handle_command/2","type":"callback"},{"doc":"","ref":"Grizzly.CommandHandler.html#c:init/1","title":"Grizzly.CommandHandler.init/1","type":"callback"},{"doc":"","ref":"Grizzly.CommandHandler.html#t:handle_response/0","title":"Grizzly.CommandHandler.handle_response/0","type":"type"},{"doc":"This handler is useful for most set commands that only needs to be acknowledged","ref":"Grizzly.CommandHandlers.AckResponse.html","title":"Grizzly.CommandHandlers.AckResponse","type":"module"},{"doc":"Handler for working with reports that could take many report frames to completeThis handler will handle aggregating the responses into one report command for ease of consumption by callers.","ref":"Grizzly.CommandHandlers.AggregateReport.html","title":"Grizzly.CommandHandlers.AggregateReport","type":"module"},{"doc":"Callback implementation for Grizzly.CommandHandler.handle_ack/1.","ref":"Grizzly.CommandHandlers.AggregateReport.html#handle_ack/1","title":"Grizzly.CommandHandlers.AggregateReport.handle_ack/1","type":"function"},{"doc":"Callback implementation for Grizzly.CommandHandler.handle_command/2.","ref":"Grizzly.CommandHandlers.AggregateReport.html#handle_command/2","title":"Grizzly.CommandHandlers.AggregateReport.handle_command/2","type":"function"},{"doc":"Callback implementation for Grizzly.CommandHandler.init/1.","ref":"Grizzly.CommandHandlers.AggregateReport.html#init/1","title":"Grizzly.CommandHandlers.AggregateReport.init/1","type":"function"},{"doc":"","ref":"Grizzly.CommandHandlers.AggregateReport.html#t:opt/0","title":"Grizzly.CommandHandlers.AggregateReport.opt/0","type":"type"},{"doc":"","ref":"Grizzly.CommandHandlers.AggregateReport.html#t:state/0","title":"Grizzly.CommandHandlers.AggregateReport.state/0","type":"type"},{"doc":"This handle is useful for when you want to wait for a particular report from the Z-Wave network. Most GET commands can use this handler.","ref":"Grizzly.CommandHandlers.WaitReport.html","title":"Grizzly.CommandHandlers.WaitReport","type":"module"},{"doc":"Callback implementation for Grizzly.CommandHandler.handle_ack/1.","ref":"Grizzly.CommandHandlers.WaitReport.html#handle_ack/1","title":"Grizzly.CommandHandlers.WaitReport.handle_ack/1","type":"function"},{"doc":"Callback implementation for Grizzly.CommandHandler.handle_command/2.","ref":"Grizzly.CommandHandlers.WaitReport.html#handle_command/2","title":"Grizzly.CommandHandlers.WaitReport.handle_command/2","type":"function"},{"doc":"Callback implementation for Grizzly.CommandHandler.init/1.","ref":"Grizzly.CommandHandlers.WaitReport.html#init/1","title":"Grizzly.CommandHandlers.WaitReport.init/1","type":"function"},{"doc":"","ref":"Grizzly.CommandHandlers.WaitReport.html#t:opt/0","title":"Grizzly.CommandHandlers.WaitReport.opt/0","type":"type"},{"doc":"","ref":"Grizzly.CommandHandlers.WaitReport.html#t:state/0","title":"Grizzly.CommandHandlers.WaitReport.state/0","type":"type"},{"doc":"Behaviour for handling incoming commands during the firmware update processWhen you initialize a firmware update process you can pass the :handler option to the function which can either be the a pid (defaults to caller pid) or a module that implements this behaviour.The report this callback function will most want to handle is:Grizzly.ZWave.Commands.FirmwareUpdateMDRequestReport It indicates whether the formware update was initiated successfully.Grizzly.ZWave.Commands.FirmwareUpdateMDStatusReport It is sent by the target device once the firmware update completes, successfully or in failure.The callback might also want to be aware of:Grizzly.ZWave.Commands.FirmwareUpdateMDGet It is sent by the target device when it wants more firmware image fragmentsGrizzly.ZWave.Commands.FirmwareMDReport It might be sent by the target device during the upgrade to modify the maximum fragment size.Grizzly.ZWave.Commands.FirmwareUpdateActivationReport It is sent by the target device in response to an activation request and gives the activation status.","ref":"Grizzly.FirmwareUpdateHandler.html","title":"Grizzly.FirmwareUpdateHandler","type":"behaviour"},{"doc":"","ref":"Grizzly.FirmwareUpdateHandler.html#c:handle_command/2","title":"Grizzly.FirmwareUpdateHandler.handle_command/2","type":"callback"},{"doc":"Module for upgrading firmware on target devices.Required options:manufacturer_id - The unique id indentifying the manufacturer of the target devicefirmware_id - The id of the current firmwareOther options:device_id - Node id of the device to be updated. Defaults to 1 (controller)firmware_target - The firwmare target id. Defaults to 0 (the ZWave chip)max_fragment_size - The maximum number of bytes that will be transmitted at a time. Defaults to 2048.hardware_version - The current hardware version of the device to be updated. Defaults to 0.activation_may_be_delayed? - Whether it is permitted for the device may delay the actual firmware update. Defaults to false.handler - The process that will receive callbacks. Defaults to the caller.any()The firmware update process is as follows:Grizzly sends a firmware_md_get command to the target device to get the manufacturer_id, hardware_id, max_fragment size, among other info needed to specify a firmware update request. The info is returned via a firmware_md_report command.Grizzly uses this info to send a firmware_update_md_request command to the target device, telling it to initiate the image uploading process. The checksum of the entire firmware image is added to the request. The target device says yeah or nay via a firmware_update_md_request_report command.If the target device agrees to have its firmware updated, it next sends a first firmware_update_md_get command to Grizzly asking for a number_of_reports (a bunch of firmware image fragment uploads) starting at fragment report_number.Grizzly responds by sending the requested series of firmware_update_md_report commands to the target device, each one containing a firmware image fragment, with a checksum for the command.Once a series of uploads is completed, the target device either asks for more fragments via another firmware_update_md_get command, or it sends a firmware_update_md_status_report command either to cancel the yet incomplete upload (bad command checksums!), or to announce that the update has completed either successfully (with some info about what happens next) or in failure (invalid overall image checksum!).As part of a successful firmware_update_md_status_report command, the target device tells Grizzly whether the new firmware needs to be activated. If it does, Grizzly would then be expected to send a firmware_update_activation_set command which success is reported by the target device via a firmware_update_activation_report command.","ref":"Grizzly.FirmwareUpdates.html","title":"Grizzly.FirmwareUpdates","type":"module"},{"doc":"","ref":"Grizzly.FirmwareUpdates.html#firmware_image_fragment_count/0","title":"Grizzly.FirmwareUpdates.firmware_image_fragment_count/0","type":"function"},{"doc":"","ref":"Grizzly.FirmwareUpdates.html#firmware_update_running?/0","title":"Grizzly.FirmwareUpdates.firmware_update_running?/0","type":"function"},{"doc":"Starts the firmware update process","ref":"Grizzly.FirmwareUpdates.html#start_firmware_update/2","title":"Grizzly.FirmwareUpdates.start_firmware_update/2","type":"function"},{"doc":"","ref":"Grizzly.FirmwareUpdates.html#t:image_path/0","title":"Grizzly.FirmwareUpdates.image_path/0","type":"type"},{"doc":"","ref":"Grizzly.FirmwareUpdates.html#t:opt/0","title":"Grizzly.FirmwareUpdates.opt/0","type":"type"},{"doc":"Behaviour for handling incoming commands during the inclusion processDuring the inclusion process different Z-Wave commands can be exchanged asynchronously. One way to handle this is by wrapping Grizzly.Inclusions in a GenServer, but that is a lot of work for something Grizzly can provide out of the box.When you initialize an inclusion process you can pass the :handler option to the command-handling function which can either be the a pid (defaults to caller pid) or a module that implements this behaviour.These reports this callback function will want to handle are:Grizzly.ZWave.Commands.NodeAddStatusGrizzly.ZWave.Commands.NodeRemoveStatusGrizzly.ZWave.Commands.NodeAddDSKReportGrizzly.ZWave.Commands.NodeAddKeysReportIf you are not handling S2 devices the last two can be ignored until you are ready to provide support them. The timeout-handling function will want to handle timeouts, particularly on state :dsk_requested, if you are handling S2-authenticated devices.","ref":"Grizzly.InclusionHandler.html","title":"Grizzly.InclusionHandler","type":"behaviour"},{"doc":"","ref":"Grizzly.InclusionHandler.html#c:handle_report/2","title":"Grizzly.InclusionHandler.handle_report/2","type":"callback"},{"doc":"","ref":"Grizzly.InclusionHandler.html#c:handle_timeout/2","title":"Grizzly.InclusionHandler.handle_timeout/2","type":"callback"},{"doc":"Module for adding and removing Z-Wave nodesIn Z-Wave the term &quot;inclusions&quot; means two things:Adding a new Z-Wave device to the Z-Wave NetworkRemoving a Z-Wave device to the Z-Wave NetworkIn practice though it is more common to speak about adding a Z-Wave node in the context of &quot;including&quot; and removing an Z-Wave mode in the context of &quot;excluding.&quot; This module provides functionality for working will all contexts of inclusion, both adding and removing.Adding a Z-Wave Node (including)When adding a device that does not required any security authentication is as simple as calling Grizzly.Inclusions.add_node/0.iex&gt; Grizzly.Inclusions.add_node() :okAfter starting the inclusion on the controller, which the above function does, you can then put your device into inclusion as well. From here the new device and your controller will communicate and if all goes well you should receive a message in the form of {:grizzly, :inclusion, NodeAddStatus} where the the NodeAddStatus is a Z-Wave command the contains information about the inclusion status (status, node id, supported command classes, security levels, etc.). See Grizzly.ZWave.Commands.NodeAddStatus for more information about the values in that command. For example:defmodule MyInclusionServer do use GenServer require Logger alias Grizzly.Inclusions alias Grizzly.ZWave.Command def start_link(_) do GenServer.start_link(__MODULE__, nil) end def add_node(pid) do GenServer.call(pid, :add_node) end def init(_) do {:ok, nil} end def handle_call(:add_node, _from, state) do :ok = Inclusions.add_node() {:reply, :ok, state} end def handle_info({:grizzly, :inclusion, report}, state) do case Command.param!(report.command, :status) do :done -&gt; node_id = Command.param!(report.command, :node_id) Logger.info(&quot;Node added with id: &quot; &lt;&gt; node_id) :failed -&gt; Logger.warn(&quot;Adding node failed :(&quot;) :security_failed -&gt; node_id = Command.param!(report.command, :node_id) Logger.warn(&quot;Node added with id: &quot; &lt;&gt; node_id &lt;&gt; &quot;but the security failed&quot;) end {:noreply, state} end endStop Adding a NodeIf you need you need to stop trying to add a node to the Z-Wave network you can use the Grizzly.Inclusions.remove_node/0 function.This should stop the controller from trying to add a node and return it to a normal functions state.SecurityThere are five security levels in Z-Wave: unsecured, S0, S2 unauthenticated, S2 authenticated, and S2 access control. The first 2 requires nothing special from the calling process to able to use, as the controller and the including node will figure out which security scheme to use.S2The process of adding an S2 device is a little more involved. The process is the same up until right after you put the including node into the inclusion mode. At that point including will request security keys, which really means it tells you which S2 security scheme it supports. You then use the Grizzly.Inclusions.grant_keys/1 function to pass a list of allowed security schemes.After that the node will response with a NodeAddDSKReport where it reports the DSK and something called the :dsk_input_length. If the input length is 0, that means it is trying to do S2 unauthenticated inclusion. You can just call Grizzly.Inclusions.set_input_dsk/0 function and the rest of the inclusion process should continue until complete.If the :dsk_input_length has number, normally will be 2 that means the including device is requesting a 5 digit digit pin that is normally found on a label somewhere on the physical device it.From here you can call Grizzly.Inclusions.set_input_dsk/1 with the 5 digit integer as the argument. The inclusion process should continue until complete.Removing a Z-Wave Node (excluding)To remove a Z-Wave node from the network the Grizzly.Inclusions.remove_node/0 will start an inclusion process for removing a Z-Wave node. After calling this function you can place your device into the inclusion (normally the same way you included the device is the way the device is excluded) mode. At the end of the exclusion the NodeRemoveStatus command is received and can be inspected for success of failure.Removed Node ID 0?Any Z-Wave controller can excluded a device from another controller. In practice this means your Z-Wave controller can make a device &quot;forget&quot; the controller it is currently attached to. Most the time Z-Wave products will have you excluded your device and then included just to make sure the including node isn't connected to another Z-Wave controller.When this happens you will a successful NodeRemoveStatusReport but the node id will be 0. This is consider successful and most the time intend.Stopping Remove Node ProcessTo stop the removal inclusion process on your controller you can call the Grizzly.Inclusions.remove_node_stop/0 function.Inclusion HandlerTo tie into the inclusion process we default to sending messages to the calling process. However, there is a better way to tie into this system.When starting any inclusion process you can pass the :handler option which can be either another pid or a module that implements the Grizzly.InclusionHandler behaviour, or a tuple with the module and callback arguments.A basic implementation might look like:defmodule MyApp.InclusionHandler do @behaviour Grizzly.InclusionHandler require Logger def handle_report(report, opts) do Logger.info(&quot;Got command: &quot; &lt;&gt; report.command.name &lt;&gt; &quot; with callback arguments &quot; &lt;&gt; inspect opts) :ok end endThis is recommended for applications using Grizzly over a GenServer that wraps Grizzly.Inclusions.","ref":"Grizzly.Inclusions.html","title":"Grizzly.Inclusions","type":"module"},{"doc":"Start the process to add a Z-Wave node to the network","ref":"Grizzly.Inclusions.html#add_node/1","title":"Grizzly.Inclusions.add_node/1","type":"function"},{"doc":"Stop an add node inclusion process","ref":"Grizzly.Inclusions.html#add_node_stop/0","title":"Grizzly.Inclusions.add_node_stop/0","type":"function"},{"doc":"Tell the inclusion process which keys to use during the inclusion processDuring S2 inclusion the node being included with send a DSKAddKeysReport to request which keys it can use to included securely. This function is useful for passing back to the node which keys it is allowed to use and depending on that answer the including node might request more information.","ref":"Grizzly.Inclusions.html#grant_keys/1","title":"Grizzly.Inclusions.grant_keys/1","type":"function"},{"doc":"Check to see if there is an inclusion process running","ref":"Grizzly.Inclusions.html#inclusion_running?/0","title":"Grizzly.Inclusions.inclusion_running?/0","type":"function"},{"doc":"Start learn mode on the controller","ref":"Grizzly.Inclusions.html#learn_mode/1","title":"Grizzly.Inclusions.learn_mode/1","type":"function"},{"doc":"Stop learn mode on the controller","ref":"Grizzly.Inclusions.html#learn_mode_stop/0","title":"Grizzly.Inclusions.learn_mode_stop/0","type":"function"},{"doc":"Start the process to remove a Z-Wave node from the network","ref":"Grizzly.Inclusions.html#remove_node/1","title":"Grizzly.Inclusions.remove_node/1","type":"function"},{"doc":"Stop a remove node inclusion process","ref":"Grizzly.Inclusions.html#remove_node_stop/0","title":"Grizzly.Inclusions.remove_node_stop/0","type":"function"},{"doc":"Tell the inclusion process what the input DSK isIf the NodeAddDSKReport's :input_dsk_length is 0 you can just call this function without any arguments:Grizzly.Inclusions.set_input_dsk()If you are doing :s2_authenticated or :s2_access_control the NodeAddDSKReport will probably ask for input DSK length of 2. This means it is expecting a 2 byte (16 bit) number, which is normally a 5 digit pin located somewhere on the node that is being added. After locating the pin and you can pass it as an argument like so:{:ok, dsk} = Grizzly.ZWave.DSK.parse(&quot;12345&quot;) Grizzly.Inclusions.set_input_dsk(dsk)","ref":"Grizzly.Inclusions.html#set_input_dsk/1","title":"Grizzly.Inclusions.set_input_dsk/1","type":"function"},{"doc":"Stop the inclusion runner","ref":"Grizzly.Inclusions.html#stop/0","title":"Grizzly.Inclusions.stop/0","type":"function"},{"doc":"","ref":"Grizzly.Inclusions.html#t:opt/0","title":"Grizzly.Inclusions.opt/0","type":"type"},{"doc":"Indicator handling for Grizzly when an indicator event is triggeredSee Grizzly.Supervisor for configuring the dispatcher that Grizzly should use during runtime.","ref":"Grizzly.Indicator.html","title":"Grizzly.Indicator","type":"module"},{"doc":"Handles an event from BEAMNotify","ref":"Grizzly.Indicator.html#handle_event/3","title":"Grizzly.Indicator.handle_event/3","type":"function"},{"doc":"","ref":"Grizzly.Indicator.html#t:dispatcher/0","title":"Grizzly.Indicator.dispatcher/0","type":"type"},{"doc":"","ref":"Grizzly.Indicator.html#t:event/0","title":"Grizzly.Indicator.event/0","type":"type"},{"doc":"Module for working with the Z-Wave network","ref":"Grizzly.Network.html","title":"Grizzly.Network","type":"module"},{"doc":"Delete a node from the network's provisioning list via the node's DSKOptions:node_id - If your controller is part of another controller's network you might want to issue network commands to that controller. By default this option will chose your controller.","ref":"Grizzly.Network.html#delete_node_provisioning/2","title":"Grizzly.Network.delete_node_provisioning/2","type":"function"},{"doc":"Get a list of node ids from the networkJust because a node id might be in the list does not mean the node is on the network. A device might have been reset or unpaired from the controller with out the controller knowing. However, in most use cases this shouldn't be an issue.Options:node_id - If your controller is part of another controller's network you might want to issue network commands to that controller. By default this option will chose your controller.","ref":"Grizzly.Network.html#get_node_ids/1","title":"Grizzly.Network.get_node_ids/1","type":"function"},{"doc":"Get the nodes provisioning list information via the node's DSKOptions:node_id - If your controller is part of another controller's network you might want to issue network commands to that controller. By default this option will chose your controller.","ref":"Grizzly.Network.html#get_node_provisioning/2","title":"Grizzly.Network.get_node_provisioning/2","type":"function"},{"doc":"List all the nodes on the provisioning listOptions:node_id - If your controller is part of another controller's network you might want to issue network commands to that controller. By default this option will chose your controller.","ref":"Grizzly.Network.html#list_node_provisionings/2","title":"Grizzly.Network.list_node_provisionings/2","type":"function"},{"doc":"Remove a (presumably) failed nodeOptions:node_id - If your controller is part of another controller's network you might want to issue network commands to that controller. By default this option will chose your controller.","ref":"Grizzly.Network.html#remove_failed_node/1","title":"Grizzly.Network.remove_failed_node/1","type":"function"},{"doc":"Request a network update (network healing)Options:node_id - If your controller is part of another controller's network you might want to issue network commands to that controller. By default this option will chose your controller.","ref":"Grizzly.Network.html#request_network_update/1","title":"Grizzly.Network.request_network_update/1","type":"function"},{"doc":"Reset the Z-Wave controllerThis command takes a few seconds to run.Options:node_id - If your controller is part of another controller's network you might want to issue network commands to that controller. By default this option will chose your controller.","ref":"Grizzly.Network.html#reset_controller/1","title":"Grizzly.Network.reset_controller/1","type":"function"},{"doc":"A node to the network provisioning listOptions:node_id - If your controller is part of another controller's network you might want to issue network commands to that controller. By default this option will chose your controller.","ref":"Grizzly.Network.html#set_node_provisioning/3","title":"Grizzly.Network.set_node_provisioning/3","type":"function"},{"doc":"","ref":"Grizzly.Network.html#t:opt/0","title":"Grizzly.Network.opt/0","type":"type"},{"doc":"Options for when you want to reset the device:notify - if the flag is set to true this will try to notify any node that is part of the lifeline association group (default true)","ref":"Grizzly.Network.html#t:reset_opt/0","title":"Grizzly.Network.reset_opt/0","type":"type"},{"doc":"Functions for working directly with a Z-Wave node","ref":"Grizzly.Node.html","title":"Grizzly.Node","type":"module"},{"doc":"Get a node's dsk.The response to this command is the DSKReport commandSending this command with :gateway will always go to your Z-Wave controller","ref":"Grizzly.Node.html#get_dsk/3","title":"Grizzly.Node.get_dsk/3","type":"function"},{"doc":"Get the information for a node by its idThe response to this command is the NodeInfoCacheReport command","ref":"Grizzly.Node.html#get_info/2","title":"Grizzly.Node.get_info/2","type":"function"},{"doc":"Set lifeline association for the nodeThe lifeline associated is used to report events that happen at the Z-Wave device level back to the Z-Wave controller. For example, if you turn on a light and want to be notified, the device will need to have it's lifeline association set.Opts::controller_id - the idea of the main controller to send lifeline reports to (defaults to 1):extra_node_ids - any extra nodes to set add to the association group","ref":"Grizzly.Node.html#set_lifeline_association/2","title":"Grizzly.Node.set_lifeline_association/2","type":"function"},{"doc":"","ref":"Grizzly.Node.html#t:id/0","title":"Grizzly.Node.id/0","type":"type"},{"doc":"Options to use when getting device info.:force_update - By default there is a cache managed by zipgateway that tracks the device information. Sometimes that can get out of date, so you can pass [force_update: true] to force the cache to update the device info. By default this is false","ref":"Grizzly.Node.html#t:info_opt/0","title":"Grizzly.Node.info_opt/0","type":"type"},{"doc":"","ref":"Grizzly.Node.html#t:lifeline_opts/0","title":"Grizzly.Node.lifeline_opts/0","type":"type"},{"doc":"Reports from Z-Wave commandsWhen you send a command in Z-Wave you will receive a report back.When Things Go WellThere are two primary reports that are returned when sending a command.The first is :command report and the second is an :ack_response report. These both will have a status of :complete.Normally, an :ack_response report is returned when you set a value on a device. This means the device received the command and is processing it, not that the device has already processed it. You might have to go read the value back after setting it if you want to make the device ran the set based command.A :command report type is returned often after reading a value from a device. This report will have its :command field filled with a Z-Wave command.case Grizzly.send_command(node_id, command, command_args, command_opts) do {:ok, %Grizzly.Report{status: :complete, type: :command} = report} -&gt; # do something withe report.command {:ok, %Grizzly.Report{status: :complete, type: :ack_response}} -&gt; # do whatever endQueued CommandsWhen sending a command to a device that sleeping, normally battery powered devices, the command will be queued internally. The command will still be considered :inflight as it has not reached the device yet. You know when a command has been queued when the report's :status field is :inflight and the :type field is :queued_delayed. Fields to help you manage queued commands are :command_ref, :queued_delay, and :node_idDuring the command's queued lifetime the system sends pings back to the caller to ensure that the low level connection is still established. This also provides an updated delayed time before the device wakes up.case Grizzly.send_command(node_id, command, command_args, command_opts) do {:ok, %Grizzly.Report{status: :inflight, type: :queued_delay}} -&gt; # the command was just queued endOnce the command has been queued the calling process will receive messages about the queued command like so:{:grizzly, :report, %Report{}}This report can take two forms. One for a completed queued command and one for a queued ping.def handle_info({:grizzly, :report, report}, state) do case report do %Grizzly.Report{status: :inflight, type: :queued_ping} -&gt; # handle the ping if you want # an updated queue delay will be found in the :queued_delay # field of the report %Grizzly.Report{status: :complete, type: :command, queued: true} -&gt; # here if the :queued field is marked has true and the report is # complete that will indicate a command has made it to the sleeping # device and the device has received the command %Grizzly.Report{status: :complete, type: :timeout, queued: true} -&gt; # The woke up and the controller sent the command but for reason # the command&#39;s processing timed out end endTimeoutsIf sending the command times out you will get a command with the :type of :timeoutcase Grizzly.send_command(node_id, command, command_args, command_opts) do {:ok, %Grizzly.Report{status: :complete, type: :timeout}} -&gt; # handle the timeout endThe reason why this is considered okay is because the command that was sent was valid and we were able to establish a connect to the desired device but it just did not provide any report back.Full ExampleThe below example shows the various ways one might match after calling Grizzly.send_command/4.case Grizzly.send_command(node_id, command, command_args, command_opts) do {:ok, %Grizzly.Report{status: :complete, type: :command} = report} -&gt; handle_complete_report(report) {:ok, %Grizzly.Report{status: :complete, type: :ack_response} = report} -&gt; handle_complete_report(report) {:ok, %Grizzly.Report{status: :complete, type: :timeout} = report} -&gt; handle_timeout(report) {:ok, %Grizzly.Report{status: :inflight, type: :queued} = report} -&gt; handle_queued_command(report) endnote: the handle_* functions will need to implemented and are only used in the example for illustration purposes","ref":"Grizzly.Report.html","title":"Grizzly.Report","type":"module"},{"doc":"Make a new Grizzly.Report","ref":"Grizzly.Report.html#new/4","title":"Grizzly.Report.new/4","type":"function"},{"doc":"","ref":"Grizzly.Report.html#t:opt/0","title":"Grizzly.Report.opt/0","type":"type"},{"doc":"The RSSI value between each device that command had to route through to get to the destination nodeIf the value is :not_available that means data for that hop in not available or a hope did not take place. To see the nodes that the command was routed through see the :last_working_route field of the transmission stats.","ref":"Grizzly.Report.html#t:rssi_value/0","title":"Grizzly.Report.rssi_value/0","type":"type"},{"doc":"","ref":"Grizzly.Report.html#t:status/0","title":"Grizzly.Report.status/0","type":"type"},{"doc":"All the data for the status and type of a report.Fields:status - this indicates if the report is complete, inflight, or timed out:type - this indicates if the report is contains a command or information about being queued.:command - if the status is :complete and the type is :command then this field will contain a Z-Wave command in the report.:transmission_stats - provides transmission stats for the command that was sent:queued_delay - the delay time remaining if the report type is :queued_delay or :queued_ping:command_ref - a reference to the command. This is mostly useful for tracking queued commands:node_id - the node the report is responding from:queued - this flag marks if the command was ever queued before completing","ref":"Grizzly.Report.html#t:t/0","title":"Grizzly.Report.t/0","type":"type"},{"doc":"The various transmission stats that are provide by the Z-Wave network when sending a command.:transmit_channel - the RF channel the command was transmitted on:ack_channel - the RF channel the acknowledgement report was transmitted on:rssi - a 5 tuple that contains RSSI values for each hop in the Z-Wave network:last_working_route - this contains a 4 tuple that shows what nodes the Z-Wave command was routed through to the destination node. Also this contains the speed by which the Z-Wave command was transmitted to the destination:transmission_time - the length of time until the reception of an acknowledgement in milliseconds:route_changed - this indicates if the route was changed for the current transmission","ref":"Grizzly.Report.html#t:transmission_stat/0","title":"Grizzly.Report.transmission_stat/0","type":"type"},{"doc":"","ref":"Grizzly.Report.html#t:transmit_speed/0","title":"Grizzly.Report.transmit_speed/0","type":"type"},{"doc":"","ref":"Grizzly.Report.html#t:type/0","title":"Grizzly.Report.type/0","type":"type"},{"doc":"Supervisor for running the Grizzly runtime.The Grizzly runtime handles command processing, command error isolation, management of adding and removing devices, management of firmware updates, and managing the underlining zipgateway binary.If you are just using all the default options you can add the supervisor to your application's supervision tree like so:children = [ Grizzly.Supervisor ]The default configuration will look for the Z-Wave controller on the serial device /dev/ttyUSB0, however if you are using a different serial device you can configure this.children = [ {Grizzly.Supervisor, [serial_port: &lt;serial_port&gt;]} ]Grizzly will try to run and manage the zipgateway binary for you. If don't want Grizzly to do this you can configure Grizzly to not run zipgateway.children = [ {Grizzly.Supervisor, [run_zipgateway: false]} ]See the type docs for Grizzly.Supervisor.arg() to learn more about the various configuration options.","ref":"Grizzly.Supervisor.html","title":"Grizzly.Supervisor","type":"module"},{"doc":"Returns a specification to start this module under a supervisor.See Supervisor.","ref":"Grizzly.Supervisor.html#child_spec/1","title":"Grizzly.Supervisor.child_spec/1","type":"function"},{"doc":"Start the Grizzly.Supervisor","ref":"Grizzly.Supervisor.html#start_link/1","title":"Grizzly.Supervisor.start_link/1","type":"function"},{"doc":"Arguments for running Grizzly.Supervisor:run_zipgateway - boolean flag to set if Grizzly should be running and supervising the zipgateway binary. This is useful if you have local zipgateway running prior to Grizzly running. Default true.:serial_port - The serial the Z-Wave controller is is connected to. Defaults to &quot;/dev/ttyUSB0&quot;:zipgateway_binary - the path the zipgateway binary. Defaults to &quot;/usr/sbin/zipgateway:zipgateway_config_path - the path write the zipgateway config file. Default to &quot;/tmp/zipgateway.cfg&quot;:on_ready - Module, function, args to run after Grizzly can establish that zipgateway is up and running. If not passed nothing will be called. Defaults to nil.:transport - a module that implements the Grizzly.Transport behaviour. Defaults to Grizzly.Transports.DTLS:zipgateway_port - the port number of the Z/IP Gateway server. Defaults 41230.:manufacturer_id - the manufacturer id given to you by the Z-Wave Alliance:hardware_version - the hardware version of the hub:product_id - the product id of your hub:product_type - the type of product the controller is:serial_log - path to out but the serial log, useful for advanced debugging:tun_script - a path to a custom tun script if the default one does not work for your system:port - port for zipgateway to run its server one. Defaults to 41230:lan_ip - the IP address of the LAN network. That is the network between the controlling machine and the Z-Wave network. Defaults to the default Z/IP LAN ip.:pan_ip - the IP for the Z-Wave private network. That is the devices IP addresses. Defaults to the default Z/IP Gateway PAN ip.:inclusion_handler - a module that implements the Grizzly.InclusionHandler behaviour. This is optional.:firmware_update_handler - a module that implements the Grizzly.FirmwareUpdateHandler behaviour. This is optional.:unsolicited_destination - configure the ip address and port number for the unsolicited destination server.:unsolicited_data_path - A path to the directory where the unsolicited server should persist data (defaults to /root):database_file - zipgateway &gt;= 7.14.2 uses an sqlite database to store information about the Z-Wave network. This will default to &quot;/data/zipgateway.db&quot;.:eeprom_file - zipgateway &lt; 7.14.2 uses an eeprom file to store information about the Z-Wave network. This will default to &quot;/data/zipeeprom.dat&quot;.:indicator_handler - A function to run when an Grizzly.Indicator.event() is received from zipgateway. The function should accept an event and return :ok.:power_level - A tuple where the first item is the normal TX power level and the second item is the measured 0dBm power configuration For the most part the defaults should work out of the box. However, theserial_port` argument is the most likely argument that will need to be passed in has it is very much hardware dependent.","ref":"Grizzly.Supervisor.html#t:arg/0","title":"Grizzly.Supervisor.arg/0","type":"type"},{"doc":"Commands for working with devices that support the Switch Binary command class","ref":"Grizzly.SwitchBinary.html","title":"Grizzly.SwitchBinary","type":"module"},{"doc":"Request the current state of the switchThis command will return a report() in response.","ref":"Grizzly.SwitchBinary.html#get/2","title":"Grizzly.SwitchBinary.get/2","type":"function"},{"doc":"Set the target value of the binary switchDevices that support version 2 of the switch binary command class and optionally be passed a duration that specifies the duration of the transition from the current value to the target value.","ref":"Grizzly.SwitchBinary.html#set/3","title":"Grizzly.SwitchBinary.set/3","type":"function"},{"doc":"The report received after requesting the state fo the switch using the get/1 function.","ref":"Grizzly.SwitchBinary.html#t:report/0","title":"Grizzly.SwitchBinary.report/0","type":"type"},{"doc":"Optional parameters used when setting the switch state:duration - the duration that the transition from current state to target state should take (version 2).","ref":"Grizzly.SwitchBinary.html#t:set_opt/0","title":"Grizzly.SwitchBinary.set_opt/0","type":"type"},{"doc":"The value the switch's state can be set to","ref":"Grizzly.SwitchBinary.html#t:set_value/0","title":"Grizzly.SwitchBinary.set_value/0","type":"type"},{"doc":"Module that tracks the commands that are sent and received by GrizzlyThe trace will hold in memory the last 300 messages. If you want to generate a log file of the trace records you use Grizzly.Trace.dump/1.The log format is:timestamp source destination sequence_number command_name command_parametersIf you want to list the records that are currently being held in memory you can use Grizzly.Trace.list/0.If you want to start traces from a fresh start you can call Grizzly.Trace.clear/0.","ref":"Grizzly.Trace.html","title":"Grizzly.Trace","type":"module"},{"doc":"Returns a specification to start this module under a supervisor.See Supervisor.","ref":"Grizzly.Trace.html#child_spec/1","title":"Grizzly.Trace.child_spec/1","type":"function"},{"doc":"Force clear the records from the trace","ref":"Grizzly.Trace.html#clear/0","title":"Grizzly.Trace.clear/0","type":"function"},{"doc":"Dump the trace records into a file","ref":"Grizzly.Trace.html#dump/1","title":"Grizzly.Trace.dump/1","type":"function"},{"doc":"List all the records currently being traced","ref":"Grizzly.Trace.html#list/0","title":"Grizzly.Trace.list/0","type":"function"},{"doc":"Log the trace information","ref":"Grizzly.Trace.html#log/2","title":"Grizzly.Trace.log/2","type":"function"},{"doc":"Start the trace server","ref":"Grizzly.Trace.html#start_link/1","title":"Grizzly.Trace.start_link/1","type":"function"},{"doc":"","ref":"Grizzly.Trace.html#t:dest/0","title":"Grizzly.Trace.dest/0","type":"type"},{"doc":"","ref":"Grizzly.Trace.html#t:log_opt/0","title":"Grizzly.Trace.log_opt/0","type":"type"},{"doc":"","ref":"Grizzly.Trace.html#t:src/0","title":"Grizzly.Trace.src/0","type":"type"},{"doc":"Data structure for a single item in the trace log","ref":"Grizzly.Trace.Record.html","title":"Grizzly.Trace.Record","type":"module"},{"doc":"Make a new Grizzly.Record.t() from a binary stringOptions::src - the src as a string:dest - the dest as a string","ref":"Grizzly.Trace.Record.html#new/2","title":"Grizzly.Trace.Record.new/2","type":"function"},{"doc":"Turn a record into the string format","ref":"Grizzly.Trace.Record.html#to_string/1","title":"Grizzly.Trace.Record.to_string/1","type":"function"},{"doc":"","ref":"Grizzly.Trace.Record.html#t:opt/0","title":"Grizzly.Trace.Record.opt/0","type":"type"},{"doc":"","ref":"Grizzly.Trace.Record.html#t:t/0","title":"Grizzly.Trace.Record.t/0","type":"type"},{"doc":"Behaviour and functions for communicating to zipgateway","ref":"Grizzly.Transport.html","title":"Grizzly.Transport","type":"behaviour"},{"doc":"Accept a new connection","ref":"Grizzly.Transport.html#accept/1","title":"Grizzly.Transport.accept/1","type":"function"},{"doc":"","ref":"Grizzly.Transport.html#c:accept/1","title":"Grizzly.Transport.accept/1","type":"callback"},{"doc":"Get the assign value for the field","ref":"Grizzly.Transport.html#assign/3","title":"Grizzly.Transport.assign/3","type":"function"},{"doc":"Update the assigns with this field and value","ref":"Grizzly.Transport.html#assigns/3","title":"Grizzly.Transport.assigns/3","type":"function"},{"doc":"","ref":"Grizzly.Transport.html#c:close/1","title":"Grizzly.Transport.close/1","type":"callback"},{"doc":"Preform the handshake","ref":"Grizzly.Transport.html#handshake/1","title":"Grizzly.Transport.handshake/1","type":"function"},{"doc":"","ref":"Grizzly.Transport.html#c:handshake/1","title":"Grizzly.Transport.handshake/1","type":"callback"},{"doc":"Listen using a transport","ref":"Grizzly.Transport.html#listen/1","title":"Grizzly.Transport.listen/1","type":"function"},{"doc":"","ref":"Grizzly.Transport.html#c:listen/1","title":"Grizzly.Transport.listen/1","type":"callback"},{"doc":"Make a new Grizzly.TransportIf need to optionally assign some priv data you can map that into this function.","ref":"Grizzly.Transport.html#new/2","title":"Grizzly.Transport.new/2","type":"function"},{"doc":"","ref":"Grizzly.Transport.html#c:open/1","title":"Grizzly.Transport.open/1","type":"callback"},{"doc":"Open the transport","ref":"Grizzly.Transport.html#open/2","title":"Grizzly.Transport.open/2","type":"function"},{"doc":"","ref":"Grizzly.Transport.html#c:parse_response/2","title":"Grizzly.Transport.parse_response/2","type":"callback"},{"doc":"Parse the response for the transport","ref":"Grizzly.Transport.html#parse_response/3","title":"Grizzly.Transport.parse_response/3","type":"function"},{"doc":"Send binary data using a transport","ref":"Grizzly.Transport.html#send/3","title":"Grizzly.Transport.send/3","type":"function"},{"doc":"","ref":"Grizzly.Transport.html#c:send/3","title":"Grizzly.Transport.send/3","type":"callback"},{"doc":"","ref":"Grizzly.Transport.html#t:args/0","title":"Grizzly.Transport.args/0","type":"type"},{"doc":"After starting a server options can be passed back to the caller so that the caller can do any other work it might seem fit.Options::strategy - this informs the caller if the transport needs to wait for connects to accept or if the socket can just process incoming messages. If the strategy is :accept that is to mean the socket is okay to start accepting new connections.","ref":"Grizzly.Transport.html#t:listen_option/0","title":"Grizzly.Transport.listen_option/0","type":"type"},{"doc":"","ref":"Grizzly.Transport.html#t:parse_opt/0","title":"Grizzly.Transport.parse_opt/0","type":"type"},{"doc":"","ref":"Grizzly.Transport.html#t:socket/0","title":"Grizzly.Transport.socket/0","type":"type"},{"doc":"","ref":"Grizzly.Transport.html#t:t/0","title":"Grizzly.Transport.t/0","type":"opaque"},{"doc":"The response from parse response","ref":"Grizzly.Transport.Response.html","title":"Grizzly.Transport.Response","type":"module"},{"doc":"","ref":"Grizzly.Transport.Response.html#t:t/0","title":"Grizzly.Transport.Response.t/0","type":"type"},{"doc":"DTLS implementation of the Grizzly.Transport behaviour","ref":"Grizzly.Transports.DTLS.html","title":"Grizzly.Transports.DTLS","type":"module"},{"doc":"Grizzly transport implementation for UDP","ref":"Grizzly.Transports.UDP.html","title":"Grizzly.Transports.UDP","type":"module"},{"doc":"Module for Z-Wave protocol specific functionality and information","ref":"Grizzly.ZWave.html","title":"Grizzly.ZWave","type":"module"},{"doc":"","ref":"Grizzly.ZWave.html#from_binary/1","title":"Grizzly.ZWave.from_binary/1","type":"function"},{"doc":"","ref":"Grizzly.ZWave.html#to_binary/1","title":"Grizzly.ZWave.to_binary/1","type":"function"},{"doc":"","ref":"Grizzly.ZWave.html#t:node_id/0","title":"Grizzly.ZWave.node_id/0","type":"type"},{"doc":"","ref":"Grizzly.ZWave.html#t:seq_number/0","title":"Grizzly.ZWave.seq_number/0","type":"type"},{"doc":"CRC for Z-Wave commandsSome commands will need to use CRC for checking checksums. This module exposes CRC functions to be able to run those checks.","ref":"Grizzly.ZWave.CRC.html","title":"Grizzly.ZWave.CRC","type":"module"},{"doc":"CRC-16/AUG-CCITT","ref":"Grizzly.ZWave.CRC.html#crc16_aug_ccitt/1","title":"Grizzly.ZWave.CRC.crc16_aug_ccitt/1","type":"function"},{"doc":"","ref":"Grizzly.ZWave.CRC.html#t:uint16/0","title":"Grizzly.ZWave.CRC.uint16/0","type":"type"},{"doc":"Data struct and behaviour for working with Z-Wave commands","ref":"Grizzly.ZWave.Command.html","title":"Grizzly.ZWave.Command","type":"behaviour"},{"doc":"Decode the binary string of command params","ref":"Grizzly.ZWave.Command.html#c:decode_params/1","title":"Grizzly.ZWave.Command.decode_params/1","type":"callback"},{"doc":"","ref":"Grizzly.ZWave.Command.html#encode_params/1","title":"Grizzly.ZWave.Command.encode_params/1","type":"function"},{"doc":"Encode the command parameters","ref":"Grizzly.ZWave.Command.html#c:encode_params/1","title":"Grizzly.ZWave.Command.encode_params/1","type":"callback"},{"doc":"Make a new Command.t() from the params providedParam validation should take place here.","ref":"Grizzly.ZWave.Command.html#c:new/1","title":"Grizzly.ZWave.Command.new/1","type":"callback"},{"doc":"Get the command param value out the params list","ref":"Grizzly.ZWave.Command.html#param/3","title":"Grizzly.ZWave.Command.param/3","type":"function"},{"doc":"Just like param/3 but will raise if the the param is not in the param list","ref":"Grizzly.ZWave.Command.html#param!/2","title":"Grizzly.ZWave.Command.param!/2","type":"function"},{"doc":"Put the param value into the params list, updating pervious value if there is one","ref":"Grizzly.ZWave.Command.html#put_param/3","title":"Grizzly.ZWave.Command.put_param/3","type":"function"},{"doc":"Encode the Command.t() into it's binary representation","ref":"Grizzly.ZWave.Command.html#to_binary/1","title":"Grizzly.ZWave.Command.to_binary/1","type":"function"},{"doc":"","ref":"Grizzly.ZWave.Command.html#t:delay_seconds/0","title":"Grizzly.ZWave.Command.delay_seconds/0","type":"type"},{"doc":"","ref":"Grizzly.ZWave.Command.html#t:params/0","title":"Grizzly.ZWave.Command.params/0","type":"type"},{"doc":"","ref":"Grizzly.ZWave.Command.html#t:t/0","title":"Grizzly.ZWave.Command.t/0","type":"type"},{"doc":"Behaviour for a command class implementation","ref":"Grizzly.ZWave.CommandClass.html","title":"Grizzly.ZWave.CommandClass","type":"behaviour"},{"doc":"Get the byte for the command class","ref":"Grizzly.ZWave.CommandClass.html#c:byte/0","title":"Grizzly.ZWave.CommandClass.byte/0","type":"callback"},{"doc":"Get the name of the command class","ref":"Grizzly.ZWave.CommandClass.html#c:name/0","title":"Grizzly.ZWave.CommandClass.name/0","type":"callback"},{"doc":"A module that implements this behaviour","ref":"Grizzly.ZWave.CommandClass.html#t:t/0","title":"Grizzly.ZWave.CommandClass.t/0","type":"type"},{"doc":"","ref":"Grizzly.ZWave.CommandClasses.html","title":"Grizzly.ZWave.CommandClasses","type":"module"},{"doc":"Turn the binary representation that is outlined in the Network-Protocol specs","ref":"Grizzly.ZWave.CommandClasses.html#command_class_list_from_binary/1","title":"Grizzly.ZWave.CommandClasses.command_class_list_from_binary/1","type":"function"},{"doc":"Turn the list of command classes into the binary representation outlined in the Network-Protocol command class specification.TODO: add more details","ref":"Grizzly.ZWave.CommandClasses.html#command_class_list_to_binary/1","title":"Grizzly.ZWave.CommandClasses.command_class_list_to_binary/1","type":"function"},{"doc":"Try to parse the byte into a command class","ref":"Grizzly.ZWave.CommandClasses.html#from_byte/1","title":"Grizzly.ZWave.CommandClasses.from_byte/1","type":"function"},{"doc":"","ref":"Grizzly.ZWave.CommandClasses.html#maybe_concat_command_classes/3","title":"Grizzly.ZWave.CommandClasses.maybe_concat_command_classes/3","type":"function"},{"doc":"Get the byte representation of the command class","ref":"Grizzly.ZWave.CommandClasses.html#to_byte/1","title":"Grizzly.ZWave.CommandClasses.to_byte/1","type":"function"},{"doc":"","ref":"Grizzly.ZWave.CommandClasses.html#t:command_class/0","title":"Grizzly.ZWave.CommandClasses.command_class/0","type":"type"},{"doc":"Alarm Command Class","ref":"Grizzly.ZWave.CommandClasses.Alarm.html","title":"Grizzly.ZWave.CommandClasses.Alarm","type":"module"},{"doc":"&quot;Antitheft&quot; Command ClassThis Command Class is used to lock (and possibly unlock) a node.","ref":"Grizzly.ZWave.CommandClasses.Antitheft.html","title":"Grizzly.ZWave.CommandClasses.Antitheft","type":"module"},{"doc":"","ref":"Grizzly.ZWave.CommandClasses.Antitheft.html#state_from_bit/1","title":"Grizzly.ZWave.CommandClasses.Antitheft.state_from_bit/1","type":"function"},{"doc":"","ref":"Grizzly.ZWave.CommandClasses.Antitheft.html#state_to_bit/1","title":"Grizzly.ZWave.CommandClasses.Antitheft.state_to_bit/1","type":"function"},{"doc":"","ref":"Grizzly.ZWave.CommandClasses.Antitheft.html#status_from_byte/1","title":"Grizzly.ZWave.CommandClasses.Antitheft.status_from_byte/1","type":"function"},{"doc":"","ref":"Grizzly.ZWave.CommandClasses.Antitheft.html#status_to_byte/1","title":"Grizzly.ZWave.CommandClasses.Antitheft.status_to_byte/1","type":"function"},{"doc":"","ref":"Grizzly.ZWave.CommandClasses.Antitheft.html#validate_magic_code_or_hint/1","title":"Grizzly.ZWave.CommandClasses.Antitheft.validate_magic_code_or_hint/1","type":"function"},{"doc":"","ref":"Grizzly.ZWave.CommandClasses.Antitheft.html#t:lock_state/0","title":"Grizzly.ZWave.CommandClasses.Antitheft.lock_state/0","type":"type"},{"doc":"","ref":"Grizzly.ZWave.CommandClasses.Antitheft.html#t:status/0","title":"Grizzly.ZWave.CommandClasses.Antitheft.status/0","type":"type"},{"doc":"&quot;AntitheftUnlock&quot; Command ClassThis Command Class is used to unlock a device that has been locked by the Anti-theft Command Class.","ref":"Grizzly.ZWave.CommandClasses.AntitheftUnlock.html","title":"Grizzly.ZWave.CommandClasses.AntitheftUnlock","type":"module"},{"doc":"","ref":"Grizzly.ZWave.CommandClasses.AntitheftUnlock.html#state_from_bit/1","title":"Grizzly.ZWave.CommandClasses.AntitheftUnlock.state_from_bit/1","type":"function"},{"doc":"","ref":"Grizzly.ZWave.CommandClasses.AntitheftUnlock.html#state_to_bit/1","title":"Grizzly.ZWave.CommandClasses.AntitheftUnlock.state_to_bit/1","type":"function"},{"doc":"","ref":"Grizzly.ZWave.CommandClasses.AntitheftUnlock.html#validate_hint/1","title":"Grizzly.ZWave.CommandClasses.AntitheftUnlock.validate_hint/1","type":"function"},{"doc":"","ref":"Grizzly.ZWave.CommandClasses.AntitheftUnlock.html#validate_magic_code/1","title":"Grizzly.ZWave.CommandClasses.AntitheftUnlock.validate_magic_code/1","type":"function"},{"doc":"","ref":"Grizzly.ZWave.CommandClasses.AntitheftUnlock.html#t:state/0","title":"Grizzly.ZWave.CommandClasses.AntitheftUnlock.state/0","type":"type"},{"doc":"&quot;ApplicationStatus&quot; Command ClassThis command class is used by devices to report an exceptional status for a received command request (try later or rejected.)","ref":"Grizzly.ZWave.CommandClasses.ApplicationStatus.html","title":"Grizzly.ZWave.CommandClasses.ApplicationStatus","type":"module"},{"doc":"","ref":"Grizzly.ZWave.CommandClasses.ApplicationStatus.html#status_from_byte/1","title":"Grizzly.ZWave.CommandClasses.ApplicationStatus.status_from_byte/1","type":"function"},{"doc":"","ref":"Grizzly.ZWave.CommandClasses.ApplicationStatus.html#status_to_byte/1","title":"Grizzly.ZWave.CommandClasses.ApplicationStatus.status_to_byte/1","type":"function"},{"doc":"","ref":"Grizzly.ZWave.CommandClasses.ApplicationStatus.html#t:status/0","title":"Grizzly.ZWave.CommandClasses.ApplicationStatus.status/0","type":"type"},{"doc":"Association Command ClassThis command class provides commands for associating Z-Wave nodes together that are the same network. That means when some event happens on Z-Wave node A it can send messages to another node on the network node B.","ref":"Grizzly.ZWave.CommandClasses.Association.html","title":"Grizzly.ZWave.CommandClasses.Association","type":"module"},{"doc":"&quot;AssociationGroupInfo&quot; Command ClassThis command class allows a node to advertise the capabilities of each association group supported by a given application resource.","ref":"Grizzly.ZWave.CommandClasses.AssociationGroupInfo.html","title":"Grizzly.ZWave.CommandClasses.AssociationGroupInfo","type":"module"},{"doc":"&quot;Basic&quot; Command ClassSupports getting and setting the on/off state of a device","ref":"Grizzly.ZWave.CommandClasses.Basic.html","title":"Grizzly.ZWave.CommandClasses.Basic","type":"module"},{"doc":"&quot;Battery&quot; Command ClassThis command class is used to get the battery level.","ref":"Grizzly.ZWave.CommandClasses.Battery.html","title":"Grizzly.ZWave.CommandClasses.Battery","type":"module"},{"doc":"&quot;Crc16Encap&quot; Command ClassThe CRC-16 Encapsulation Command Class is used to encapsulate a command with an additional CRC-16 checksum to ensure integrity of the payload.","ref":"Grizzly.ZWave.CommandClasses.CRC16Encap.html","title":"Grizzly.ZWave.CommandClasses.CRC16Encap","type":"module"},{"doc":"&quot;CentralScene&quot; Command ClassThe Central Scene Command Class is used to communicate central scene activations to a central controller","ref":"Grizzly.ZWave.CommandClasses.CentralScene.html","title":"Grizzly.ZWave.CommandClasses.CentralScene","type":"module"},{"doc":"","ref":"Grizzly.ZWave.CommandClasses.CentralScene.html#boolean_to_bit/1","title":"Grizzly.ZWave.CommandClasses.CentralScene.boolean_to_bit/1","type":"function"},{"doc":"","ref":"Grizzly.ZWave.CommandClasses.CentralScene.html#key_attribute_from_bit_index/2","title":"Grizzly.ZWave.CommandClasses.CentralScene.key_attribute_from_bit_index/2","type":"function"},{"doc":"","ref":"Grizzly.ZWave.CommandClasses.CentralScene.html#key_attribute_from_byte/1","title":"Grizzly.ZWave.CommandClasses.CentralScene.key_attribute_from_byte/1","type":"function"},{"doc":"","ref":"Grizzly.ZWave.CommandClasses.CentralScene.html#key_attribute_to_bit_index/1","title":"Grizzly.ZWave.CommandClasses.CentralScene.key_attribute_to_bit_index/1","type":"function"},{"doc":"","ref":"Grizzly.ZWave.CommandClasses.CentralScene.html#key_attribute_to_byte/1","title":"Grizzly.ZWave.CommandClasses.CentralScene.key_attribute_to_byte/1","type":"function"},{"doc":"","ref":"Grizzly.ZWave.CommandClasses.CentralScene.html#validate_supported_key_attributes/3","title":"Grizzly.ZWave.CommandClasses.CentralScene.validate_supported_key_attributes/3","type":"function"},{"doc":"","ref":"Grizzly.ZWave.CommandClasses.CentralScene.html#t:key_attribute/0","title":"Grizzly.ZWave.CommandClasses.CentralScene.key_attribute/0","type":"type"},{"doc":"","ref":"Grizzly.ZWave.CommandClasses.CentralScene.html#t:key_attributes/0","title":"Grizzly.ZWave.CommandClasses.CentralScene.key_attributes/0","type":"type"},{"doc":"&quot;Clock&quot; Command ClassThe Clock Command Class is used to implement a simple clock functionality.","ref":"Grizzly.ZWave.CommandClasses.Clock.html","title":"Grizzly.ZWave.CommandClasses.Clock","type":"module"},{"doc":"","ref":"Grizzly.ZWave.CommandClasses.Clock.html#decode_weekday/1","title":"Grizzly.ZWave.CommandClasses.Clock.decode_weekday/1","type":"function"},{"doc":"","ref":"Grizzly.ZWave.CommandClasses.Clock.html#encode_weekday/1","title":"Grizzly.ZWave.CommandClasses.Clock.encode_weekday/1","type":"function"},{"doc":"","ref":"Grizzly.ZWave.CommandClasses.Clock.html#t:weekday/0","title":"Grizzly.ZWave.CommandClasses.Clock.weekday/0","type":"type"},{"doc":"Configuration command classThis command class is used to configure manufacturer specific configuration parameters","ref":"Grizzly.ZWave.CommandClasses.Configuration.html","title":"Grizzly.ZWave.CommandClasses.Configuration","type":"module"},{"doc":"","ref":"Grizzly.ZWave.CommandClasses.Configuration.html#boolean_from_bit/1","title":"Grizzly.ZWave.CommandClasses.Configuration.boolean_from_bit/1","type":"function"},{"doc":"","ref":"Grizzly.ZWave.CommandClasses.Configuration.html#boolean_to_bit/1","title":"Grizzly.ZWave.CommandClasses.Configuration.boolean_to_bit/1","type":"function"},{"doc":"","ref":"Grizzly.ZWave.CommandClasses.Configuration.html#format_from_byte/1","title":"Grizzly.ZWave.CommandClasses.Configuration.format_from_byte/1","type":"function"},{"doc":"","ref":"Grizzly.ZWave.CommandClasses.Configuration.html#format_to_byte/1","title":"Grizzly.ZWave.CommandClasses.Configuration.format_to_byte/1","type":"function"},{"doc":"","ref":"Grizzly.ZWave.CommandClasses.Configuration.html#validate_size/1","title":"Grizzly.ZWave.CommandClasses.Configuration.validate_size/1","type":"function"},{"doc":"","ref":"Grizzly.ZWave.CommandClasses.Configuration.html#t:format/0","title":"Grizzly.ZWave.CommandClasses.Configuration.format/0","type":"type"},{"doc":"&quot;DeviceResetLocally&quot; Command ClassThe Device Reset Locally Command Class is used to notify central controllers that a Z-Wave device is resetting its network specific parameters.","ref":"Grizzly.ZWave.CommandClasses.DeviceResetLocally.html","title":"Grizzly.ZWave.CommandClasses.DeviceResetLocally","type":"module"},{"doc":"DoorLock Command ClassThis command class provides commands that are used to operate and configure door lock devices","ref":"Grizzly.ZWave.CommandClasses.DoorLock.html","title":"Grizzly.ZWave.CommandClasses.DoorLock","type":"module"},{"doc":"","ref":"Grizzly.ZWave.CommandClasses.DoorLock.html#door_handles_from_bitmask/1","title":"Grizzly.ZWave.CommandClasses.DoorLock.door_handles_from_bitmask/1","type":"function"},{"doc":"","ref":"Grizzly.ZWave.CommandClasses.DoorLock.html#door_handles_to_bitmask/1","title":"Grizzly.ZWave.CommandClasses.DoorLock.door_handles_to_bitmask/1","type":"function"},{"doc":"","ref":"Grizzly.ZWave.CommandClasses.DoorLock.html#mode_from_byte/1","title":"Grizzly.ZWave.CommandClasses.DoorLock.mode_from_byte/1","type":"function"},{"doc":"","ref":"Grizzly.ZWave.CommandClasses.DoorLock.html#mode_to_byte/1","title":"Grizzly.ZWave.CommandClasses.DoorLock.mode_to_byte/1","type":"function"},{"doc":"","ref":"Grizzly.ZWave.CommandClasses.DoorLock.html#operation_type_from_byte/1","title":"Grizzly.ZWave.CommandClasses.DoorLock.operation_type_from_byte/1","type":"function"},{"doc":"","ref":"Grizzly.ZWave.CommandClasses.DoorLock.html#operation_type_to_byte/1","title":"Grizzly.ZWave.CommandClasses.DoorLock.operation_type_to_byte/1","type":"function"},{"doc":"","ref":"Grizzly.ZWave.CommandClasses.DoorLock.html#to_minutes_and_seconds/1","title":"Grizzly.ZWave.CommandClasses.DoorLock.to_minutes_and_seconds/1","type":"function"},{"doc":"","ref":"Grizzly.ZWave.CommandClasses.DoorLock.html#t:door_components/0","title":"Grizzly.ZWave.CommandClasses.DoorLock.door_components/0","type":"type"},{"doc":"","ref":"Grizzly.ZWave.CommandClasses.DoorLock.html#t:mode/0","title":"Grizzly.ZWave.CommandClasses.DoorLock.mode/0","type":"type"},{"doc":"","ref":"Grizzly.ZWave.CommandClasses.DoorLock.html#t:operation_type/0","title":"Grizzly.ZWave.CommandClasses.DoorLock.operation_type/0","type":"type"},{"doc":"The Firmware Update Meta Data Command Class may be used to transfer a firmware image to a Z-Wave device.","ref":"Grizzly.ZWave.CommandClasses.FirmwareUpdateMD.html","title":"Grizzly.ZWave.CommandClasses.FirmwareUpdateMD","type":"module"},{"doc":"Hail Command ClassThis command class is used for a device to notify an application that the device has some type of information or change that the application can read. This command class is obsolete as of 2017-10-02. This is application and device specific.","ref":"Grizzly.ZWave.CommandClasses.Hail.html","title":"Grizzly.ZWave.CommandClasses.Hail","type":"module"},{"doc":"&quot;Indicator&quot; Command ClassThe Indicator Command Class is used to help end users to monitor the operation or condition of the application provided by a supporting node.","ref":"Grizzly.ZWave.CommandClasses.Indicator.html","title":"Grizzly.ZWave.CommandClasses.Indicator","type":"module"},{"doc":"","ref":"Grizzly.ZWave.CommandClasses.Indicator.html#indicator_id_from_byte/1","title":"Grizzly.ZWave.CommandClasses.Indicator.indicator_id_from_byte/1","type":"function"},{"doc":"","ref":"Grizzly.ZWave.CommandClasses.Indicator.html#indicator_id_to_byte/1","title":"Grizzly.ZWave.CommandClasses.Indicator.indicator_id_to_byte/1","type":"function"},{"doc":"","ref":"Grizzly.ZWave.CommandClasses.Indicator.html#property_id_from_byte/1","title":"Grizzly.ZWave.CommandClasses.Indicator.property_id_from_byte/1","type":"function"},{"doc":"","ref":"Grizzly.ZWave.CommandClasses.Indicator.html#property_id_to_byte/1","title":"Grizzly.ZWave.CommandClasses.Indicator.property_id_to_byte/1","type":"function"},{"doc":"","ref":"Grizzly.ZWave.CommandClasses.Indicator.html#value_from_byte/2","title":"Grizzly.ZWave.CommandClasses.Indicator.value_from_byte/2","type":"function"},{"doc":"","ref":"Grizzly.ZWave.CommandClasses.Indicator.html#value_to_byte/2","title":"Grizzly.ZWave.CommandClasses.Indicator.value_to_byte/2","type":"function"},{"doc":"","ref":"Grizzly.ZWave.CommandClasses.Indicator.html#t:indicator_id/0","title":"Grizzly.ZWave.CommandClasses.Indicator.indicator_id/0","type":"type"},{"doc":"","ref":"Grizzly.ZWave.CommandClasses.Indicator.html#t:property_id/0","title":"Grizzly.ZWave.CommandClasses.Indicator.property_id/0","type":"type"},{"doc":"","ref":"Grizzly.ZWave.CommandClasses.Indicator.html#t:resource/0","title":"Grizzly.ZWave.CommandClasses.Indicator.resource/0","type":"type"},{"doc":"","ref":"Grizzly.ZWave.CommandClasses.Indicator.html#t:value/0","title":"Grizzly.ZWave.CommandClasses.Indicator.value/0","type":"type"},{"doc":"ManufacturerSpecific Command ClassThis command class is used to advertise manufacturer information","ref":"Grizzly.ZWave.CommandClasses.ManufacturerSpecific.html","title":"Grizzly.ZWave.CommandClasses.ManufacturerSpecific","type":"module"},{"doc":"&quot;Meter&quot; Command ClassThe Meter Command Class is used to advertise instantaneous and accumulated numerical readings.","ref":"Grizzly.ZWave.CommandClasses.Meter.html","title":"Grizzly.ZWave.CommandClasses.Meter","type":"module"},{"doc":"&quot;MultiChannel&quot; Command ClassThe Multi Channel command class is used to address one or more End Points in a Multi Channel device.","ref":"Grizzly.ZWave.CommandClasses.MultiChannel.html","title":"Grizzly.ZWave.CommandClasses.MultiChannel","type":"module"},{"doc":"","ref":"Grizzly.ZWave.CommandClasses.MultiChannel.html#decode_generic_device_class/1","title":"Grizzly.ZWave.CommandClasses.MultiChannel.decode_generic_device_class/1","type":"function"},{"doc":"","ref":"Grizzly.ZWave.CommandClasses.MultiChannel.html#decode_specific_device_class/2","title":"Grizzly.ZWave.CommandClasses.MultiChannel.decode_specific_device_class/2","type":"function"},{"doc":"","ref":"Grizzly.ZWave.CommandClasses.MultiChannel.html#t:end_point/0","title":"Grizzly.ZWave.CommandClasses.MultiChannel.end_point/0","type":"type"},{"doc":"&quot;MultiChannelAssociation&quot; Command ClassThe Multi Channel Association Command Class is used to manage associations to Multi Channel End Point destinations as well as to NodeID destinations.","ref":"Grizzly.ZWave.CommandClasses.MultiChannelAssociation.html","title":"Grizzly.ZWave.CommandClasses.MultiChannelAssociation","type":"module"},{"doc":"","ref":"Grizzly.ZWave.CommandClasses.MultiChannelAssociation.html#decode_nodes_and_node_endpoints/1","title":"Grizzly.ZWave.CommandClasses.MultiChannelAssociation.decode_nodes_and_node_endpoints/1","type":"function"},{"doc":"","ref":"Grizzly.ZWave.CommandClasses.MultiChannelAssociation.html#encode_node_endpoints/1","title":"Grizzly.ZWave.CommandClasses.MultiChannelAssociation.encode_node_endpoints/1","type":"function"},{"doc":"","ref":"Grizzly.ZWave.CommandClasses.MultiChannelAssociation.html#t:node_endpoint/0","title":"Grizzly.ZWave.CommandClasses.MultiChannelAssociation.node_endpoint/0","type":"type"},{"doc":"&quot;MultiCommand&quot; Command ClassThe Multi Command Command Class is used to bundle multiple commands in one encapsulation Command.","ref":"Grizzly.ZWave.CommandClasses.MultiCommand.html","title":"Grizzly.ZWave.CommandClasses.MultiCommand","type":"module"},{"doc":"Command class for working with Z-Wave network updates and resetting the controller back to the factor defaults","ref":"Grizzly.ZWave.CommandClasses.NetworkManagementBasicNode.html","title":"Grizzly.ZWave.CommandClasses.NetworkManagementBasicNode","type":"module"},{"doc":"","ref":"Grizzly.ZWave.CommandClasses.NetworkManagementBasicNode.html#add_mode_from_bit/1","title":"Grizzly.ZWave.CommandClasses.NetworkManagementBasicNode.add_mode_from_bit/1","type":"function"},{"doc":"","ref":"Grizzly.ZWave.CommandClasses.NetworkManagementBasicNode.html#add_mode_to_byte/1","title":"Grizzly.ZWave.CommandClasses.NetworkManagementBasicNode.add_mode_to_byte/1","type":"function"},{"doc":"","ref":"Grizzly.ZWave.CommandClasses.NetworkManagementBasicNode.html#network_update_request_status_from_byte/1","title":"Grizzly.ZWave.CommandClasses.NetworkManagementBasicNode.network_update_request_status_from_byte/1","type":"function"},{"doc":"","ref":"Grizzly.ZWave.CommandClasses.NetworkManagementBasicNode.html#network_update_request_status_to_byte/1","title":"Grizzly.ZWave.CommandClasses.NetworkManagementBasicNode.network_update_request_status_to_byte/1","type":"function"},{"doc":"","ref":"Grizzly.ZWave.CommandClasses.NetworkManagementBasicNode.html#t:add_mode/0","title":"Grizzly.ZWave.CommandClasses.NetworkManagementBasicNode.add_mode/0","type":"type"},{"doc":"","ref":"Grizzly.ZWave.CommandClasses.NetworkManagementBasicNode.html#t:network_update_request_status/0","title":"Grizzly.ZWave.CommandClasses.NetworkManagementBasicNode.network_update_request_status/0","type":"type"},{"doc":"Network Management Inclusion Command ClassThis command class provides the commands for adding and removing Z-Wave nodes to the Z-Wave network","ref":"Grizzly.ZWave.CommandClasses.NetworkManagementInclusion.html","title":"Grizzly.ZWave.CommandClasses.NetworkManagementInclusion","type":"module"},{"doc":"&quot;NetworkManagementInstallationMaintenance&quot; Command ClassThe Network Management Installation and Maintenance Command Class is used to access statistical data.","ref":"Grizzly.ZWave.CommandClasses.NetworkManagementInstallationMaintenance.html","title":"Grizzly.ZWave.CommandClasses.NetworkManagementInstallationMaintenance","type":"module"},{"doc":"","ref":"Grizzly.ZWave.CommandClasses.NetworkManagementInstallationMaintenance.html#repeaters_from_bytes/1","title":"Grizzly.ZWave.CommandClasses.NetworkManagementInstallationMaintenance.repeaters_from_bytes/1","type":"function"},{"doc":"","ref":"Grizzly.ZWave.CommandClasses.NetworkManagementInstallationMaintenance.html#repeaters_to_bytes/1","title":"Grizzly.ZWave.CommandClasses.NetworkManagementInstallationMaintenance.repeaters_to_bytes/1","type":"function"},{"doc":"","ref":"Grizzly.ZWave.CommandClasses.NetworkManagementInstallationMaintenance.html#route_type_from_byte/1","title":"Grizzly.ZWave.CommandClasses.NetworkManagementInstallationMaintenance.route_type_from_byte/1","type":"function"},{"doc":"","ref":"Grizzly.ZWave.CommandClasses.NetworkManagementInstallationMaintenance.html#route_type_to_byte/1","title":"Grizzly.ZWave.CommandClasses.NetworkManagementInstallationMaintenance.route_type_to_byte/1","type":"function"},{"doc":"","ref":"Grizzly.ZWave.CommandClasses.NetworkManagementInstallationMaintenance.html#rssi_from_byte/1","title":"Grizzly.ZWave.CommandClasses.NetworkManagementInstallationMaintenance.rssi_from_byte/1","type":"function"},{"doc":"","ref":"Grizzly.ZWave.CommandClasses.NetworkManagementInstallationMaintenance.html#rssi_to_byte/1","title":"Grizzly.ZWave.CommandClasses.NetworkManagementInstallationMaintenance.rssi_to_byte/1","type":"function"},{"doc":"","ref":"Grizzly.ZWave.CommandClasses.NetworkManagementInstallationMaintenance.html#speed_from_byte/1","title":"Grizzly.ZWave.CommandClasses.NetworkManagementInstallationMaintenance.speed_from_byte/1","type":"function"},{"doc":"","ref":"Grizzly.ZWave.CommandClasses.NetworkManagementInstallationMaintenance.html#speed_to_byte/1","title":"Grizzly.ZWave.CommandClasses.NetworkManagementInstallationMaintenance.speed_to_byte/1","type":"function"},{"doc":"","ref":"Grizzly.ZWave.CommandClasses.NetworkManagementInstallationMaintenance.html#statistics_from_binary/1","title":"Grizzly.ZWave.CommandClasses.NetworkManagementInstallationMaintenance.statistics_from_binary/1","type":"function"},{"doc":"","ref":"Grizzly.ZWave.CommandClasses.NetworkManagementInstallationMaintenance.html#statistics_to_binary/1","title":"Grizzly.ZWave.CommandClasses.NetworkManagementInstallationMaintenance.statistics_to_binary/1","type":"function"},{"doc":"","ref":"Grizzly.ZWave.CommandClasses.NetworkManagementInstallationMaintenance.html#t:neighbor/0","title":"Grizzly.ZWave.CommandClasses.NetworkManagementInstallationMaintenance.neighbor/0","type":"type"},{"doc":"","ref":"Grizzly.ZWave.CommandClasses.NetworkManagementInstallationMaintenance.html#t:neighbor_param/0","title":"Grizzly.ZWave.CommandClasses.NetworkManagementInstallationMaintenance.neighbor_param/0","type":"type"},{"doc":"","ref":"Grizzly.ZWave.CommandClasses.NetworkManagementInstallationMaintenance.html#t:route_type/0","title":"Grizzly.ZWave.CommandClasses.NetworkManagementInstallationMaintenance.route_type/0","type":"type"},{"doc":"","ref":"Grizzly.ZWave.CommandClasses.NetworkManagementInstallationMaintenance.html#t:rssi/0","title":"Grizzly.ZWave.CommandClasses.NetworkManagementInstallationMaintenance.rssi/0","type":"type"},{"doc":"","ref":"Grizzly.ZWave.CommandClasses.NetworkManagementInstallationMaintenance.html#t:speed/0","title":"Grizzly.ZWave.CommandClasses.NetworkManagementInstallationMaintenance.speed/0","type":"type"},{"doc":"","ref":"Grizzly.ZWave.CommandClasses.NetworkManagementInstallationMaintenance.html#t:statistic/0","title":"Grizzly.ZWave.CommandClasses.NetworkManagementInstallationMaintenance.statistic/0","type":"type"},{"doc":"","ref":"Grizzly.ZWave.CommandClasses.NetworkManagementInstallationMaintenance.html#t:statistics/0","title":"Grizzly.ZWave.CommandClasses.NetworkManagementInstallationMaintenance.statistics/0","type":"type"},{"doc":"Network Management Proxy Command ClassThis command class is used to report information about the Z-Wave nodes on the network such has node ids, supported command classes and their security support, multi channel end points (version 2 only), and basic, generic, and specific device classes.","ref":"Grizzly.ZWave.CommandClasses.NetworkManagementProxy.html","title":"Grizzly.ZWave.CommandClasses.NetworkManagementProxy","type":"module"},{"doc":"&quot;NoOperation&quot; Command ClassSupports the :no_operation command which does nothing other than confirming that the device is responsive.","ref":"Grizzly.ZWave.CommandClasses.NoOperation.html","title":"Grizzly.ZWave.CommandClasses.NoOperation","type":"module"},{"doc":"&quot;NodeNaming&quot; Command ClassThe Node Naming (and Location) Command Class is used to assign a name and a location text string to a supporting node.","ref":"Grizzly.ZWave.CommandClasses.NodeNaming.html","title":"Grizzly.ZWave.CommandClasses.NodeNaming","type":"module"},{"doc":"","ref":"Grizzly.ZWave.CommandClasses.NodeNaming.html#encoding_from_byte/1","title":"Grizzly.ZWave.CommandClasses.NodeNaming.encoding_from_byte/1","type":"function"},{"doc":"","ref":"Grizzly.ZWave.CommandClasses.NodeNaming.html#encoding_to_byte/1","title":"Grizzly.ZWave.CommandClasses.NodeNaming.encoding_to_byte/1","type":"function"},{"doc":"NodeProvisioning Command ClassThe Node Provisioning command class is used to manage a list of unique nodes, called the &quot;Node Provisioning List&quot;, in SmartStart controller or gateway.","ref":"Grizzly.ZWave.CommandClasses.NodeProvisioning.html","title":"Grizzly.ZWave.CommandClasses.NodeProvisioning","type":"module"},{"doc":"","ref":"Grizzly.ZWave.CommandClasses.NodeProvisioning.html#encode_meta_extensions/1","title":"Grizzly.ZWave.CommandClasses.NodeProvisioning.encode_meta_extensions/1","type":"function"},{"doc":"Get the DSK from a raw binaryIf the binary is empty this will return {:ok, nil}.","ref":"Grizzly.ZWave.CommandClasses.NodeProvisioning.html#optional_binary_to_dsk/1","title":"Grizzly.ZWave.CommandClasses.NodeProvisioning.optional_binary_to_dsk/1","type":"function"},{"doc":"Get the binary representation of the dskIf the DSK is nil then this will return an empty binary.","ref":"Grizzly.ZWave.CommandClasses.NodeProvisioning.html#optional_dsk_to_binary/1","title":"Grizzly.ZWave.CommandClasses.NodeProvisioning.optional_dsk_to_binary/1","type":"function"},{"doc":"&quot;Powerlevel&quot; Command ClassThe Powerlevel Command Class defines RF transmit power controlling Commands useful when installing or testing a network. The Commands makes it possible for supporting controllers to set/get the RF transmit power level of a node and test specific links between nodes with a specific RF transmit power level.","ref":"Grizzly.ZWave.CommandClasses.Powerlevel.html","title":"Grizzly.ZWave.CommandClasses.Powerlevel","type":"module"},{"doc":"","ref":"Grizzly.ZWave.CommandClasses.Powerlevel.html#power_level_from_byte/1","title":"Grizzly.ZWave.CommandClasses.Powerlevel.power_level_from_byte/1","type":"function"},{"doc":"","ref":"Grizzly.ZWave.CommandClasses.Powerlevel.html#power_level_to_byte/1","title":"Grizzly.ZWave.CommandClasses.Powerlevel.power_level_to_byte/1","type":"function"},{"doc":"","ref":"Grizzly.ZWave.CommandClasses.Powerlevel.html#status_of_operation_from_byte/1","title":"Grizzly.ZWave.CommandClasses.Powerlevel.status_of_operation_from_byte/1","type":"function"},{"doc":"","ref":"Grizzly.ZWave.CommandClasses.Powerlevel.html#status_of_operation_to_byte/1","title":"Grizzly.ZWave.CommandClasses.Powerlevel.status_of_operation_to_byte/1","type":"function"},{"doc":"","ref":"Grizzly.ZWave.CommandClasses.Powerlevel.html#t:power_level/0","title":"Grizzly.ZWave.CommandClasses.Powerlevel.power_level/0","type":"type"},{"doc":"","ref":"Grizzly.ZWave.CommandClasses.Powerlevel.html#t:status_of_operation/0","title":"Grizzly.ZWave.CommandClasses.Powerlevel.status_of_operation/0","type":"type"},{"doc":"&quot;SceneActivation&quot; Command ClassThe Scene Activation Command Class used for launching scenes in a number of actuator nodes","ref":"Grizzly.ZWave.CommandClasses.SceneActivation.html","title":"Grizzly.ZWave.CommandClasses.SceneActivation","type":"module"},{"doc":"&quot;SceneActuatorConf&quot; Command ClassThe Scene Actuator Configuration Command Class is used to configure scenes settings for a node supporting an actuator Command Class, e.g. a multilevel switch, binary switch etc.","ref":"Grizzly.ZWave.CommandClasses.SceneActuatorConf.html","title":"Grizzly.ZWave.CommandClasses.SceneActuatorConf","type":"module"},{"doc":"","ref":"Grizzly.ZWave.CommandClasses.SceneActuatorConf.html#dimming_duration_from_byte/1","title":"Grizzly.ZWave.CommandClasses.SceneActuatorConf.dimming_duration_from_byte/1","type":"function"},{"doc":"","ref":"Grizzly.ZWave.CommandClasses.SceneActuatorConf.html#dimming_duration_to_byte/1","title":"Grizzly.ZWave.CommandClasses.SceneActuatorConf.dimming_duration_to_byte/1","type":"function"},{"doc":"","ref":"Grizzly.ZWave.CommandClasses.SceneActuatorConf.html#level_from_byte/1","title":"Grizzly.ZWave.CommandClasses.SceneActuatorConf.level_from_byte/1","type":"function"},{"doc":"","ref":"Grizzly.ZWave.CommandClasses.SceneActuatorConf.html#level_to_byte/1","title":"Grizzly.ZWave.CommandClasses.SceneActuatorConf.level_to_byte/1","type":"function"},{"doc":"","ref":"Grizzly.ZWave.CommandClasses.SceneActuatorConf.html#t:dimming_duration/0","title":"Grizzly.ZWave.CommandClasses.SceneActuatorConf.dimming_duration/0","type":"type"},{"doc":"","ref":"Grizzly.ZWave.CommandClasses.SceneActuatorConf.html#t:level/0","title":"Grizzly.ZWave.CommandClasses.SceneActuatorConf.level/0","type":"type"},{"doc":"Deprecated command class for triggered/not triggered sensors.","ref":"Grizzly.ZWave.CommandClasses.SensorBinary.html","title":"Grizzly.ZWave.CommandClasses.SensorBinary","type":"module"},{"doc":"","ref":"Grizzly.ZWave.CommandClasses.SensorBinary.html#decode_type/1","title":"Grizzly.ZWave.CommandClasses.SensorBinary.decode_type/1","type":"function"},{"doc":"","ref":"Grizzly.ZWave.CommandClasses.SensorBinary.html#encode_type/1","title":"Grizzly.ZWave.CommandClasses.SensorBinary.encode_type/1","type":"function"},{"doc":"","ref":"Grizzly.ZWave.CommandClasses.SensorBinary.html#t:sensor_type/0","title":"Grizzly.ZWave.CommandClasses.SensorBinary.sensor_type/0","type":"type"},{"doc":"&quot;SensorMultilevel&quot; Command ClassThe Multilevel Sensor Command Class is used to advertise numerical sensor readings.","ref":"Grizzly.ZWave.CommandClasses.SensorMultilevel.html","title":"Grizzly.ZWave.CommandClasses.SensorMultilevel","type":"module"},{"doc":"","ref":"Grizzly.ZWave.CommandClasses.SensorMultilevel.html#decode_sensor_type/1","title":"Grizzly.ZWave.CommandClasses.SensorMultilevel.decode_sensor_type/1","type":"function"},{"doc":"","ref":"Grizzly.ZWave.CommandClasses.SensorMultilevel.html#decode_sensor_types/1","title":"Grizzly.ZWave.CommandClasses.SensorMultilevel.decode_sensor_types/1","type":"function"},{"doc":"","ref":"Grizzly.ZWave.CommandClasses.SensorMultilevel.html#encode_sensor_type/1","title":"Grizzly.ZWave.CommandClasses.SensorMultilevel.encode_sensor_type/1","type":"function"},{"doc":"","ref":"Grizzly.ZWave.CommandClasses.SensorMultilevel.html#encode_sensor_types/1","title":"Grizzly.ZWave.CommandClasses.SensorMultilevel.encode_sensor_types/1","type":"function"},{"doc":"The Supervision Command Class allows a sending node to request application-level delivery confirmation from a receiving node.","ref":"Grizzly.ZWave.CommandClasses.Supervision.html","title":"Grizzly.ZWave.CommandClasses.Supervision","type":"module"},{"doc":"Switch Binary Command ClassThis command class provides command work with switches that are either on or off.","ref":"Grizzly.ZWave.CommandClasses.SwitchBinary.html","title":"Grizzly.ZWave.CommandClasses.SwitchBinary","type":"module"},{"doc":"Multilevel Switch Command ClassThis command class provides commands that work with multilevel switches.","ref":"Grizzly.ZWave.CommandClasses.SwitchMultilevel.html","title":"Grizzly.ZWave.CommandClasses.SwitchMultilevel","type":"module"},{"doc":"&quot;ThermostatFanMode&quot; Command ClassWhat type of commands does this command class support?","ref":"Grizzly.ZWave.CommandClasses.ThermostatFanMode.html","title":"Grizzly.ZWave.CommandClasses.ThermostatFanMode","type":"module"},{"doc":"","ref":"Grizzly.ZWave.CommandClasses.ThermostatFanMode.html#decode_mode/1","title":"Grizzly.ZWave.CommandClasses.ThermostatFanMode.decode_mode/1","type":"function"},{"doc":"","ref":"Grizzly.ZWave.CommandClasses.ThermostatFanMode.html#encode_mode/1","title":"Grizzly.ZWave.CommandClasses.ThermostatFanMode.encode_mode/1","type":"function"},{"doc":"","ref":"Grizzly.ZWave.CommandClasses.ThermostatFanMode.html#t:mode/0","title":"Grizzly.ZWave.CommandClasses.ThermostatFanMode.mode/0","type":"type"},{"doc":"&quot;ThermostatFanState&quot; Command ClassThe Thermostat Fan State Command Class is used to obtain the fan operating state of the thermostat.","ref":"Grizzly.ZWave.CommandClasses.ThermostatFanState.html","title":"Grizzly.ZWave.CommandClasses.ThermostatFanState","type":"module"},{"doc":"","ref":"Grizzly.ZWave.CommandClasses.ThermostatFanState.html#decode_state/1","title":"Grizzly.ZWave.CommandClasses.ThermostatFanState.decode_state/1","type":"function"},{"doc":"","ref":"Grizzly.ZWave.CommandClasses.ThermostatFanState.html#encode_state/1","title":"Grizzly.ZWave.CommandClasses.ThermostatFanState.encode_state/1","type":"function"},{"doc":"","ref":"Grizzly.ZWave.CommandClasses.ThermostatFanState.html#t:state/0","title":"Grizzly.ZWave.CommandClasses.ThermostatFanState.state/0","type":"type"},{"doc":"&quot;ThermostatMode&quot; Command ClassThe Thermostat Mode Command Class is used to control which mode a thermostat operates.","ref":"Grizzly.ZWave.CommandClasses.ThermostatMode.html","title":"Grizzly.ZWave.CommandClasses.ThermostatMode","type":"module"},{"doc":"","ref":"Grizzly.ZWave.CommandClasses.ThermostatMode.html#decode_mode/1","title":"Grizzly.ZWave.CommandClasses.ThermostatMode.decode_mode/1","type":"function"},{"doc":"","ref":"Grizzly.ZWave.CommandClasses.ThermostatMode.html#encode_mode/1","title":"Grizzly.ZWave.CommandClasses.ThermostatMode.encode_mode/1","type":"function"},{"doc":"","ref":"Grizzly.ZWave.CommandClasses.ThermostatMode.html#t:mode/0","title":"Grizzly.ZWave.CommandClasses.ThermostatMode.mode/0","type":"type"},{"doc":"&quot;ThermostatOperatingState&quot; Command ClassThe Thermostat Operating State Command Class is used to obtain the operating state of the thermostat.","ref":"Grizzly.ZWave.CommandClasses.ThermostatOperatingState.html","title":"Grizzly.ZWave.CommandClasses.ThermostatOperatingState","type":"module"},{"doc":"","ref":"Grizzly.ZWave.CommandClasses.ThermostatOperatingState.html#decode_state/1","title":"Grizzly.ZWave.CommandClasses.ThermostatOperatingState.decode_state/1","type":"function"},{"doc":"","ref":"Grizzly.ZWave.CommandClasses.ThermostatOperatingState.html#encode_state/1","title":"Grizzly.ZWave.CommandClasses.ThermostatOperatingState.encode_state/1","type":"function"},{"doc":"","ref":"Grizzly.ZWave.CommandClasses.ThermostatOperatingState.html#t:state/0","title":"Grizzly.ZWave.CommandClasses.ThermostatOperatingState.state/0","type":"type"},{"doc":"&quot;ThermostatSetback&quot; Command ClassThe Thermostat Setback Command Class is used to change the current state of a non-schedule setback thermostat.","ref":"Grizzly.ZWave.CommandClasses.ThermostatSetback.html","title":"Grizzly.ZWave.CommandClasses.ThermostatSetback","type":"module"},{"doc":"","ref":"Grizzly.ZWave.CommandClasses.ThermostatSetback.html#decode_state/1","title":"Grizzly.ZWave.CommandClasses.ThermostatSetback.decode_state/1","type":"function"},{"doc":"","ref":"Grizzly.ZWave.CommandClasses.ThermostatSetback.html#decode_type/1","title":"Grizzly.ZWave.CommandClasses.ThermostatSetback.decode_type/1","type":"function"},{"doc":"","ref":"Grizzly.ZWave.CommandClasses.ThermostatSetback.html#encode_state/1","title":"Grizzly.ZWave.CommandClasses.ThermostatSetback.encode_state/1","type":"function"},{"doc":"","ref":"Grizzly.ZWave.CommandClasses.ThermostatSetback.html#encode_type/1","title":"Grizzly.ZWave.CommandClasses.ThermostatSetback.encode_type/1","type":"function"},{"doc":"","ref":"Grizzly.ZWave.CommandClasses.ThermostatSetback.html#t:state/0","title":"Grizzly.ZWave.CommandClasses.ThermostatSetback.state/0","type":"type"},{"doc":"","ref":"Grizzly.ZWave.CommandClasses.ThermostatSetback.html#t:type/0","title":"Grizzly.ZWave.CommandClasses.ThermostatSetback.type/0","type":"type"},{"doc":"&quot;ThermostatSetpoint&quot; Command Class The Thermostat Setpoint Command Class is used to configure setpoints for the modes supported by a thermostat.What type of commands does this command class support?","ref":"Grizzly.ZWave.CommandClasses.ThermostatSetpoint.html","title":"Grizzly.ZWave.CommandClasses.ThermostatSetpoint","type":"module"},{"doc":"","ref":"Grizzly.ZWave.CommandClasses.ThermostatSetpoint.html#decode_scale/1","title":"Grizzly.ZWave.CommandClasses.ThermostatSetpoint.decode_scale/1","type":"function"},{"doc":"","ref":"Grizzly.ZWave.CommandClasses.ThermostatSetpoint.html#decode_type/1","title":"Grizzly.ZWave.CommandClasses.ThermostatSetpoint.decode_type/1","type":"function"},{"doc":"","ref":"Grizzly.ZWave.CommandClasses.ThermostatSetpoint.html#encode_scale/1","title":"Grizzly.ZWave.CommandClasses.ThermostatSetpoint.encode_scale/1","type":"function"},{"doc":"","ref":"Grizzly.ZWave.CommandClasses.ThermostatSetpoint.html#encode_type/1","title":"Grizzly.ZWave.CommandClasses.ThermostatSetpoint.encode_type/1","type":"function"},{"doc":"","ref":"Grizzly.ZWave.CommandClasses.ThermostatSetpoint.html#t:scale/0","title":"Grizzly.ZWave.CommandClasses.ThermostatSetpoint.scale/0","type":"type"},{"doc":"","ref":"Grizzly.ZWave.CommandClasses.ThermostatSetpoint.html#t:type/0","title":"Grizzly.ZWave.CommandClasses.ThermostatSetpoint.type/0","type":"type"},{"doc":"&quot;Time&quot; Command ClassThe Time Command Class is used to read date and time from a supporting node in a Z-Wave network.","ref":"Grizzly.ZWave.CommandClasses.Time.html","title":"Grizzly.ZWave.CommandClasses.Time","type":"module"},{"doc":"","ref":"Grizzly.ZWave.CommandClasses.Time.html#decode_sign/1","title":"Grizzly.ZWave.CommandClasses.Time.decode_sign/1","type":"function"},{"doc":"","ref":"Grizzly.ZWave.CommandClasses.Time.html#encode_sign/1","title":"Grizzly.ZWave.CommandClasses.Time.encode_sign/1","type":"function"},{"doc":"","ref":"Grizzly.ZWave.CommandClasses.Time.html#t:sign/0","title":"Grizzly.ZWave.CommandClasses.Time.sign/0","type":"type"},{"doc":"&quot;TimeParameters&quot; Command ClassThe Time Parameters Command Class is used to set date and time.","ref":"Grizzly.ZWave.CommandClasses.TimeParameters.html","title":"Grizzly.ZWave.CommandClasses.TimeParameters","type":"module"},{"doc":"Command Class for working with user codes","ref":"Grizzly.ZWave.CommandClasses.UserCode.html","title":"Grizzly.ZWave.CommandClasses.UserCode","type":"module"},{"doc":"","ref":"Grizzly.ZWave.CommandClasses.UserCode.html#user_id_status_from_byte/1","title":"Grizzly.ZWave.CommandClasses.UserCode.user_id_status_from_byte/1","type":"function"},{"doc":"","ref":"Grizzly.ZWave.CommandClasses.UserCode.html#user_id_status_to_byte/1","title":"Grizzly.ZWave.CommandClasses.UserCode.user_id_status_to_byte/1","type":"function"},{"doc":"","ref":"Grizzly.ZWave.CommandClasses.UserCode.html#t:user_id_status/0","title":"Grizzly.ZWave.CommandClasses.UserCode.user_id_status/0","type":"type"},{"doc":"Version Command ClassThis command class is used to get version information about the Z-Wave protocol, command classes, and vendor specific versions","ref":"Grizzly.ZWave.CommandClasses.Version.html","title":"Grizzly.ZWave.CommandClasses.Version","type":"module"},{"doc":"&quot;WakeUp&quot; Command ClassThis command class is used to get and set the wake-up intervals of wake-up devices.","ref":"Grizzly.ZWave.CommandClasses.WakeUp.html","title":"Grizzly.ZWave.CommandClasses.WakeUp","type":"module"},{"doc":"ZIP Command ClassThe Z/IP command class is useful for encapsulating Z-Wave commands to be sent via IP.","ref":"Grizzly.ZWave.CommandClasses.ZIP.html","title":"Grizzly.ZWave.CommandClasses.ZIP","type":"module"},{"doc":"ZIPGateway Command ClassThis command class is used for configuration Z/IP Gateway at runtime","ref":"Grizzly.ZWave.CommandClasses.ZIPGateway.html","title":"Grizzly.ZWave.CommandClasses.ZIPGateway","type":"module"},{"doc":"&quot;ZwaveplusInfo&quot; Command ClassThe Z-Wave Plus Info Command Class is used to differentiate between Z-Wave Plus, Z-Wave for IP and Z-Wave devices.","ref":"Grizzly.ZWave.CommandClasses.ZwaveplusInfo.html","title":"Grizzly.ZWave.CommandClasses.ZwaveplusInfo","type":"module"},{"doc":"","ref":"Grizzly.ZWave.CommandClasses.ZwaveplusInfo.html#node_type_from_byte/1","title":"Grizzly.ZWave.CommandClasses.ZwaveplusInfo.node_type_from_byte/1","type":"function"},{"doc":"","ref":"Grizzly.ZWave.CommandClasses.ZwaveplusInfo.html#node_type_to_byte/1","title":"Grizzly.ZWave.CommandClasses.ZwaveplusInfo.node_type_to_byte/1","type":"function"},{"doc":"","ref":"Grizzly.ZWave.CommandClasses.ZwaveplusInfo.html#role_type_from_byte/1","title":"Grizzly.ZWave.CommandClasses.ZwaveplusInfo.role_type_from_byte/1","type":"function"},{"doc":"","ref":"Grizzly.ZWave.CommandClasses.ZwaveplusInfo.html#role_type_to_byte/1","title":"Grizzly.ZWave.CommandClasses.ZwaveplusInfo.role_type_to_byte/1","type":"function"},{"doc":"","ref":"Grizzly.ZWave.CommandClasses.ZwaveplusInfo.html#t:node_type/0","title":"Grizzly.ZWave.CommandClasses.ZwaveplusInfo.node_type/0","type":"type"},{"doc":"","ref":"Grizzly.ZWave.CommandClasses.ZwaveplusInfo.html#t:role_type/0","title":"Grizzly.ZWave.CommandClasses.ZwaveplusInfo.role_type/0","type":"type"},{"doc":"This command is used to request the supported Notifications for a specified Notification Type.Params::type - a type of notification","ref":"Grizzly.ZWave.Commands.AlarmEventSupportedGet.html","title":"Grizzly.ZWave.Commands.AlarmEventSupportedGet","type":"module"},{"doc":"","ref":"Grizzly.ZWave.Commands.AlarmEventSupportedGet.html#t:param/0","title":"Grizzly.ZWave.Commands.AlarmEventSupportedGet.param/0","type":"type"},{"doc":"This command is used to advertise supported events/states for a specified Notification Type.Params::type - a Notification type:events - the Notification events supported for that type","ref":"Grizzly.ZWave.Commands.AlarmEventSupportedReport.html","title":"Grizzly.ZWave.Commands.AlarmEventSupportedReport","type":"module"},{"doc":"","ref":"Grizzly.ZWave.Commands.AlarmEventSupportedReport.html#t:param/0","title":"Grizzly.ZWave.Commands.AlarmEventSupportedReport.param/0","type":"type"},{"doc":"This command is used to get the value of an alarm.Params::type - v1 alarm type (required for v1 only):zwave_type - Z-Wave alarm/notification type (required for v2+):zwave_event - Z-Wave event/state (optional)","ref":"Grizzly.ZWave.Commands.AlarmGet.html","title":"Grizzly.ZWave.Commands.AlarmGet","type":"module"},{"doc":"","ref":"Grizzly.ZWave.Commands.AlarmGet.html#t:param/0","title":"Grizzly.ZWave.Commands.AlarmGet.param/0","type":"type"},{"doc":"This command notifies the application of the alarm state (v1, v2) or the notification state (v8).Params::type - the specific alarm type being reported - this different for each application, see device user manual for more details (required):level - the level is device specific, see device user manual for more details (required):zensor_net_node_id - the Zensor net node, if the device is not based off of Zensor Net, then this field is 0 (v2, optional, default 0):zwave_status - if the device alarm status is :enabled or :disabled (v2):zwave_type - part of Grizzly.ZWave.Notifications spec (v2):zwave_event - part of the Grizzly.ZWave.Notifications spec (v2):event_parameters - additional parameters for the event as keyword list, see user manual for more information (v2+, optional, default [])","ref":"Grizzly.ZWave.Commands.AlarmReport.html","title":"Grizzly.ZWave.Commands.AlarmReport","type":"module"},{"doc":"","ref":"Grizzly.ZWave.Commands.AlarmReport.html#t:param/0","title":"Grizzly.ZWave.Commands.AlarmReport.param/0","type":"type"},{"doc":"This command is used to enable or disable the unsolicited transmission of a specific Notification/Alarm Type.Params::zwave_type - the type of alarm, e.g. :home_security:status - the status of the alarm, either :enabled or :disabled","ref":"Grizzly.ZWave.Commands.AlarmSet.html","title":"Grizzly.ZWave.Commands.AlarmSet","type":"module"},{"doc":"","ref":"Grizzly.ZWave.Commands.AlarmSet.html#t:param/0","title":"Grizzly.ZWave.Commands.AlarmSet.param/0","type":"type"},{"doc":"This command is used to request supported Alarm/Notification Types.Params: -none-","ref":"Grizzly.ZWave.Commands.AlarmTypeSupportedGet.html","title":"Grizzly.ZWave.Commands.AlarmTypeSupportedGet","type":"module"},{"doc":"This command is used to advertise supported Alarm/Notification Types. Versions 2+ are supported.Params::types - the types of alarms supported by the device","ref":"Grizzly.ZWave.Commands.AlarmTypeSupportedReport.html","title":"Grizzly.ZWave.Commands.AlarmTypeSupportedReport","type":"module"},{"doc":"","ref":"Grizzly.ZWave.Commands.AlarmTypeSupportedReport.html#t:param/0","title":"Grizzly.ZWave.Commands.AlarmTypeSupportedReport.param/0","type":"type"},{"doc":"This command is used to request the locked/unlocked state of a supporting node.Params: - none -","ref":"Grizzly.ZWave.Commands.AntitheftGet.html","title":"Grizzly.ZWave.Commands.AntitheftGet","type":"module"},{"doc":"This command is used to advertise the lock/unlock state of a supporting node.Params::status - the antitheft status of the device, one of :protection_disabled_unlocked , :protection_enabled_locked_fully_functional, :protection_enabled_locked_restricted (required v2+):manufacturer_id - This field describes the Z-Wave Manufacturer ID of the company’s product that has locked the node (required v2+):antitheft_hint - This field is used as a 1 to 10 byte identifier or key value to help retriving the Magic Code (required v2+):locking_entity_id - This field MUST specify a unique Z-Wave Alliance identifier for the entity that has locked the node (required v3 only)","ref":"Grizzly.ZWave.Commands.AntitheftReport.html","title":"Grizzly.ZWave.Commands.AntitheftReport","type":"module"},{"doc":"","ref":"Grizzly.ZWave.Commands.AntitheftReport.html#t:param/0","title":"Grizzly.ZWave.Commands.AntitheftReport.param/0","type":"type"},{"doc":"This command is used to lock or unlock a node.Params::state - This field MUST indicate the desired :locked or :unlocked state for the receiving node (required v2+):magic_code - This field contains the 1 to 10 byte Magic Code used to lock or unlock the node (required v2+):manufacturer_id - This field describes the Z-Wave Manufacturer ID of the company’s product that has locked the node (required v2+):antitheft_hint - This field is used as a 1 to 10 byte identifier or key value to help retriving the Magic Code (required v2+):locking_entity_id - This field MUST specify a unique Z-Wave Alliance identifier for the entity that has locked the node (required v3)","ref":"Grizzly.ZWave.Commands.AntitheftSet.html","title":"Grizzly.ZWave.Commands.AntitheftSet","type":"module"},{"doc":"","ref":"Grizzly.ZWave.Commands.AntitheftSet.html#t:param/0","title":"Grizzly.ZWave.Commands.AntitheftSet.param/0","type":"type"},{"doc":"This command is used to request the locked/unlocked state of the node.Params: - none -","ref":"Grizzly.ZWave.Commands.AntitheftUnlockGet.html","title":"Grizzly.ZWave.Commands.AntitheftUnlockGet","type":"module"},{"doc":"This command is used to advertise the current locked/unlocked state of the node with some additional information.Params::state - This field MUST indicate the current :locked/:unlocked state of the device (required):restricted - This boolean field indicates whether the node currently runs in restricted mode (required):manufacturer_id - This field describes the Z-Wave Manufacturer ID of the company’s product that has locked the node (required):antitheft_hint - This field is used as a 1 to 10 byte identifier or key value to help retriving the Magic Code (required):locking_entity_id - This field specifies a unique Z-Wave Alliance identifier for the entity that has locked the node (required)","ref":"Grizzly.ZWave.Commands.AntitheftUnlockReport.html","title":"Grizzly.ZWave.Commands.AntitheftUnlockReport","type":"module"},{"doc":"","ref":"Grizzly.ZWave.Commands.AntitheftUnlockReport.html#t:param/0","title":"Grizzly.ZWave.Commands.AntitheftUnlockReport.param/0","type":"type"},{"doc":"This command is used to unlock a node that is currently locked.Params::magic_code - This field contains the Magic Code used to unlock the node.","ref":"Grizzly.ZWave.Commands.AntitheftUnlockSet.html","title":"Grizzly.ZWave.Commands.AntitheftUnlockSet","type":"module"},{"doc":"","ref":"Grizzly.ZWave.Commands.AntitheftUnlockSet.html#t:param/0","title":"Grizzly.ZWave.Commands.AntitheftUnlockSet.param/0","type":"type"},{"doc":"The Application Busy Command used to instruct a node that the node that it is trying to communicate with is busy and is unable to service the request right now.Params::status - The status field can have the following values: :try_again_later, :try_again_after_wait, :request_queued (required):wait_time - The wait time field indicates the number of seconds a node should wait before retrying the request (required)","ref":"Grizzly.ZWave.Commands.ApplicationBusy.html","title":"Grizzly.ZWave.Commands.ApplicationBusy","type":"module"},{"doc":"","ref":"Grizzly.ZWave.Commands.ApplicationBusy.html#t:param/0","title":"Grizzly.ZWave.Commands.ApplicationBusy.param/0","type":"type"},{"doc":"Get the node information frame of for the Z/IP Gateway controllerParams: -none-","ref":"Grizzly.ZWave.Commands.ApplicationNodeInfoGet.html","title":"Grizzly.ZWave.Commands.ApplicationNodeInfoGet","type":"module"},{"doc":"Reports the Application Node Info with regards to the command classes that are supportedParams::command_classes - list of command classes","ref":"Grizzly.ZWave.Commands.ApplicationNodeInfoReport.html","title":"Grizzly.ZWave.Commands.ApplicationNodeInfoReport","type":"module"},{"doc":"","ref":"Grizzly.ZWave.Commands.ApplicationNodeInfoReport.html#t:param/0","title":"Grizzly.ZWave.Commands.ApplicationNodeInfoReport.param/0","type":"type"},{"doc":"","ref":"Grizzly.ZWave.Commands.ApplicationNodeInfoReport.html#t:tagged_command_classes/0","title":"Grizzly.ZWave.Commands.ApplicationNodeInfoReport.tagged_command_classes/0","type":"type"},{"doc":"This command is used to instruct a node that the command was rejected by the application in the receiving node.Params: - none -","ref":"Grizzly.ZWave.Commands.ApplicationRejectedRequest.html","title":"Grizzly.ZWave.Commands.ApplicationRejectedRequest","type":"module"},{"doc":"Get the current destinations for the association groupThis should be respond to with a Grizzly.ZWave.Commands.AssociationReportParams::grouping_identifier - the group to request a report about (required)","ref":"Grizzly.ZWave.Commands.AssociationGet.html","title":"Grizzly.ZWave.Commands.AssociationGet","type":"module"},{"doc":"","ref":"Grizzly.ZWave.Commands.AssociationGet.html#t:param/0","title":"Grizzly.ZWave.Commands.AssociationGet.param/0","type":"type"},{"doc":"This command is used to request the commands that are sent via a given association group.Params::allow_cache - This field indicates that a Z-Wave Gateway device is allowed to intercept the request and return a cached response on behalf of the specified target. (required):group_id - The group identifier (required)","ref":"Grizzly.ZWave.Commands.AssociationGroupCommandListGet.html","title":"Grizzly.ZWave.Commands.AssociationGroupCommandListGet","type":"module"},{"doc":"","ref":"Grizzly.ZWave.Commands.AssociationGroupCommandListGet.html#t:param/0","title":"Grizzly.ZWave.Commands.AssociationGroupCommandListGet.param/0","type":"type"},{"doc":"This command is used to advertise the commands that are sent via an actual association group.Params::group_id - the group identifier:commands - lists of commands","ref":"Grizzly.ZWave.Commands.AssociationGroupCommandListReport.html","title":"Grizzly.ZWave.Commands.AssociationGroupCommandListReport","type":"module"},{"doc":"","ref":"Grizzly.ZWave.Commands.AssociationGroupCommandListReport.html#t:param/0","title":"Grizzly.ZWave.Commands.AssociationGroupCommandListReport.param/0","type":"type"},{"doc":"This command is used to request the properties of one or more association group.Params::refresh_cache - Whether to refresh cached info:all - Get info on all assocation groups:group_id - get info on this association group (required if all is false)","ref":"Grizzly.ZWave.Commands.AssociationGroupInfoGet.html","title":"Grizzly.ZWave.Commands.AssociationGroupInfoGet","type":"module"},{"doc":"","ref":"Grizzly.ZWave.Commands.AssociationGroupInfoGet.html#t:param/0","title":"Grizzly.ZWave.Commands.AssociationGroupInfoGet.param/0","type":"type"},{"doc":"This command is used to advertise the properties of one or more association groups.Params::dynamic - whether the group info is subject to be changed by the device:groups_info - a list of group info:list_mode - a boolean if the report should be in list mode. In some cases this needs to be forced, like if you are reporting one group but the get query requested list mode. If you are reporting more than one group then this parameter is optional as it will know that more than one group can only be reported with list mode true. If you don't set this option to true when reporting one group then this will default to false.","ref":"Grizzly.ZWave.Commands.AssociationGroupInfoReport.html","title":"Grizzly.ZWave.Commands.AssociationGroupInfoReport","type":"module"},{"doc":"","ref":"Grizzly.ZWave.Commands.AssociationGroupInfoReport.html#t:group_info/0","title":"Grizzly.ZWave.Commands.AssociationGroupInfoReport.group_info/0","type":"type"},{"doc":"","ref":"Grizzly.ZWave.Commands.AssociationGroupInfoReport.html#t:param/0","title":"Grizzly.ZWave.Commands.AssociationGroupInfoReport.param/0","type":"type"},{"doc":"This command is used to query the name of an association group.Params::group_id - the group identifier","ref":"Grizzly.ZWave.Commands.AssociationGroupNameGet.html","title":"Grizzly.ZWave.Commands.AssociationGroupNameGet","type":"module"},{"doc":"","ref":"Grizzly.ZWave.Commands.AssociationGroupNameGet.html#t:param/0","title":"Grizzly.ZWave.Commands.AssociationGroupNameGet.param/0","type":"type"},{"doc":"This command is used to advertise the assigned name of an association group.Params::group_id - the group id:name - the group's name","ref":"Grizzly.ZWave.Commands.AssociationGroupNameReport.html","title":"Grizzly.ZWave.Commands.AssociationGroupNameReport","type":"module"},{"doc":"","ref":"Grizzly.ZWave.Commands.AssociationGroupNameReport.html#t:param/0","title":"Grizzly.ZWave.Commands.AssociationGroupNameReport.param/0","type":"type"},{"doc":"This command is used to request the number of association groups that this node supports.Params: - none -","ref":"Grizzly.ZWave.Commands.AssociationGroupingsGet.html","title":"Grizzly.ZWave.Commands.AssociationGroupingsGet","type":"module"},{"doc":"This command is used to advertise the maximum number of association groups implemented by this node.Params::supported_groupings - the maximum number of association groups","ref":"Grizzly.ZWave.Commands.AssociationGroupingsReport.html","title":"Grizzly.ZWave.Commands.AssociationGroupingsReport","type":"module"},{"doc":"","ref":"Grizzly.ZWave.Commands.AssociationGroupingsReport.html#t:param/0","title":"Grizzly.ZWave.Commands.AssociationGroupingsReport.param/0","type":"type"},{"doc":"This command is used to remove destinations from a given association group.Params::grouping_identifiers - the association grouping identifier (required):nodes - list of nodes to add the grouping identifier (required)","ref":"Grizzly.ZWave.Commands.AssociationRemove.html","title":"Grizzly.ZWave.Commands.AssociationRemove","type":"module"},{"doc":"","ref":"Grizzly.ZWave.Commands.AssociationRemove.html#t:param/0","title":"Grizzly.ZWave.Commands.AssociationRemove.param/0","type":"type"},{"doc":"Report the destinations for the given association groupParams::grouping_identifier - the grouping identifier for the the association group (required):max_nodes_supported - the max number of destinations for the association group (required):reports_to_follow - if the full destination list is too long for one report this field reports the number of follow up reports (optional default 0):nodes - the destination nodes in the association group (required)","ref":"Grizzly.ZWave.Commands.AssociationReport.html","title":"Grizzly.ZWave.Commands.AssociationReport","type":"module"},{"doc":"","ref":"Grizzly.ZWave.Commands.AssociationReport.html#t:param/0","title":"Grizzly.ZWave.Commands.AssociationReport.param/0","type":"type"},{"doc":"Module for the ASSOCIATION_SET commandThe node receiving this command should add the specified node ids to the association group. However, if the association group for the node is full this command is ignored.Params::grouping_identifier - the association grouping identifier (required):nodes - list of nodes to add the grouping identifier (required)","ref":"Grizzly.ZWave.Commands.AssociationSet.html","title":"Grizzly.ZWave.Commands.AssociationSet","type":"module"},{"doc":"","ref":"Grizzly.ZWave.Commands.AssociationSet.html#t:param/0","title":"Grizzly.ZWave.Commands.AssociationSet.param/0","type":"type"},{"doc":"This command allows a portable controller to interactively create associations from a multi-button device to a destination that is out of direct range.Params: -none-","ref":"Grizzly.ZWave.Commands.AssociationSpecificGroupGet.html","title":"Grizzly.ZWave.Commands.AssociationSpecificGroupGet","type":"module"},{"doc":"This command is used to advertise the association group that represents the most recently detected button.Params::group - the association group that represents the most recently detected button","ref":"Grizzly.ZWave.Commands.AssociationSpecificGroupReport.html","title":"Grizzly.ZWave.Commands.AssociationSpecificGroupReport","type":"module"},{"doc":"","ref":"Grizzly.ZWave.Commands.AssociationSpecificGroupReport.html#t:param/0","title":"Grizzly.ZWave.Commands.AssociationSpecificGroupReport.param/0","type":"type"},{"doc":"This module implements the BASIC_GET command form the COMMAND_CLASS_BASIC command classParams: - none","ref":"Grizzly.ZWave.Commands.BasicGet.html","title":"Grizzly.ZWave.Commands.BasicGet","type":"module"},{"doc":"This module implements the BASIC_REPORT command of the COMMAND_CLASS_BASIC command classParams::value - the current value (:on or :off or :unknown):target_value - the target value (:on or :off or :unknown) - v2:duration - the time in seconds needed to reach the Target Value at the actual transition rate - v2","ref":"Grizzly.ZWave.Commands.BasicReport.html","title":"Grizzly.ZWave.Commands.BasicReport","type":"module"},{"doc":"","ref":"Grizzly.ZWave.Commands.BasicReport.html#t:duration/0","title":"Grizzly.ZWave.Commands.BasicReport.duration/0","type":"type"},{"doc":"","ref":"Grizzly.ZWave.Commands.BasicReport.html#t:param/0","title":"Grizzly.ZWave.Commands.BasicReport.param/0","type":"type"},{"doc":"","ref":"Grizzly.ZWave.Commands.BasicReport.html#t:value/0","title":"Grizzly.ZWave.Commands.BasicReport.value/0","type":"type"},{"doc":"This module implements the BASIC_SET command of the COMMAND_CLASS_BASIC command classParams::value - :on or :off","ref":"Grizzly.ZWave.Commands.BasicSet.html","title":"Grizzly.ZWave.Commands.BasicSet","type":"module"},{"doc":"","ref":"Grizzly.ZWave.Commands.BasicSet.html#t:param/0","title":"Grizzly.ZWave.Commands.BasicSet.param/0","type":"type"},{"doc":"This module implements the BATTERY_GET command in the COMMAND_CLASS_BATTERY command class.Params: - none -","ref":"Grizzly.ZWave.Commands.BatteryGet.html","title":"Grizzly.ZWave.Commands.BatteryGet","type":"module"},{"doc":"This module implements the BATTERY_REPORT command of the COMMAND_CLASS_BATTERY command class.Params::level - percent charged - v1:charging_status - whether charging, discharging or maintaining - v2:rechargeable - whether the battery is rechargeable - v2:backup - whether used as a backup source of power - v2:overheating - whether it is overheating - v2:low_fluid - whether the battery fluid is low and should be refilled - v2:replace_recharge - whether the battery needs to be replaced or recharged- v2:disconnected - whether the battery is disconnected nd the node is running on an alternative power source - v2:low_temperature - whether the battery of a device has stopped charging due to low temperature - v3","ref":"Grizzly.ZWave.Commands.BatteryReport.html","title":"Grizzly.ZWave.Commands.BatteryReport","type":"module"},{"doc":"","ref":"Grizzly.ZWave.Commands.BatteryReport.html#t:param/0","title":"Grizzly.ZWave.Commands.BatteryReport.param/0","type":"type"},{"doc":"The CRC-16 Encapsulation Command is used to encapsulate a command with an additional checksum to ensure integrity of the payload.Params::command - the encapsulated Command","ref":"Grizzly.ZWave.Commands.CRC16Encap.html","title":"Grizzly.ZWave.Commands.CRC16Encap","type":"module"},{"doc":"","ref":"Grizzly.ZWave.Commands.CRC16Encap.html#t:param/0","title":"Grizzly.ZWave.Commands.CRC16Encap.param/0","type":"type"},{"doc":"This command is used to query the configuration of optional node capabilities for scene notificationsParams: - none -","ref":"Grizzly.ZWave.Commands.CentralSceneConfigurationGet.html","title":"Grizzly.ZWave.Commands.CentralSceneConfigurationGet","type":"module"},{"doc":"This command is used to advertise the configuration of optional node capabilities for scene notifications.Params::slow_refresh - This boolean field indicates whether the scene launching node must use Slow Refresh.","ref":"Grizzly.ZWave.Commands.CentralSceneConfigurationReport.html","title":"Grizzly.ZWave.Commands.CentralSceneConfigurationReport","type":"module"},{"doc":"This command is used to configure the use of optional node capabilities for scene notifications.Params::slow_refresh - This boolean field indicates whether the scene launching node must use Slow Refresh.","ref":"Grizzly.ZWave.Commands.CentralSceneConfigurationSet.html","title":"Grizzly.ZWave.Commands.CentralSceneConfigurationSet","type":"module"},{"doc":"","ref":"Grizzly.ZWave.Commands.CentralSceneConfigurationSet.html#t:param/0","title":"Grizzly.ZWave.Commands.CentralSceneConfigurationSet.param/0","type":"type"},{"doc":"This command is used to advertise a scene key event.Versions 1 and 2 are obsolete.Params::seq_number - The receiving device uses the sequence number to ignore duplicates. (required):slow_refresh - This flag is used to advertise if the node is sending Key Held Down notifications at a slow rate. (required):key_attribute - This field advertises one or more events detected by the key (required):scene_number - The scene for the key event (required)","ref":"Grizzly.ZWave.Commands.CentralSceneNotification.html","title":"Grizzly.ZWave.Commands.CentralSceneNotification","type":"module"},{"doc":"","ref":"Grizzly.ZWave.Commands.CentralSceneNotification.html#t:param/0","title":"Grizzly.ZWave.Commands.CentralSceneNotification.param/0","type":"type"},{"doc":"This command is used to request the maximum number of scenes that this device supports.Params: - none -","ref":"Grizzly.ZWave.Commands.CentralSceneSupportedGet.html","title":"Grizzly.ZWave.Commands.CentralSceneSupportedGet","type":"module"},{"doc":"This command is used to report the maximum number of supported scenes and the Key Attributes supported for each scene.Versions 1 and 2 are obsolete. Version 3+ fields are required.Params::supported_scenes - This field indicates the maximum number of scenes supported by the requested device. (required):slow_refresh_support - This field indicates whether the node supports the Slow Refresh capability. (required):identical - This field indicates if all scenes are supporting the same Key Attributes (required):bit_mask_bytes - This field advertises the size of each “Supported Key Attributes” field measured in bytes. Must be 1..3. (required):supported_key_attributes - This field advertises the attributes supported by the corresponding scene (required) A list of lists of key attributes where a key attribute is one of :key_pressed_1_time | :key_released | :key_held_down | :key_pressed_2_times | :key_pressed_3_times | :key_pressed_4_times | :key_pressed_5_times. If not identical, the first list of key attributes corresponds to scene 1, the second to scene 2 etc. for each of supported_scenes If identical, only the key attributes of scene 1 are to be listed","ref":"Grizzly.ZWave.Commands.CentralSceneSupportedReport.html","title":"Grizzly.ZWave.Commands.CentralSceneSupportedReport","type":"module"},{"doc":"","ref":"Grizzly.ZWave.Commands.CentralSceneSupportedReport.html#t:param/0","title":"Grizzly.ZWave.Commands.CentralSceneSupportedReport.param/0","type":"type"},{"doc":"This command is used to request the current time set at a supporting node.Params: - none -","ref":"Grizzly.ZWave.Commands.ClockGet.html","title":"Grizzly.ZWave.Commands.ClockGet","type":"module"},{"doc":"This command reports on the current time in a supporting nodeParams::weekday - the day of the week, one of :sunday, :monday, etc. (required):hour - 0..23 (required):minute - 0..59 (required)","ref":"Grizzly.ZWave.Commands.ClockReport.html","title":"Grizzly.ZWave.Commands.ClockReport","type":"module"},{"doc":"","ref":"Grizzly.ZWave.Commands.ClockReport.html#t:param/0","title":"Grizzly.ZWave.Commands.ClockReport.param/0","type":"type"},{"doc":"This command is used to set the current time in a supporting nodeParams::weekday - the day of the week, one of :sunday, :monday, etc. (required):hour - 0..23 (required):minute - 0..59 (required)","ref":"Grizzly.ZWave.Commands.ClockSet.html","title":"Grizzly.ZWave.Commands.ClockSet","type":"module"},{"doc":"","ref":"Grizzly.ZWave.Commands.ClockSet.html#t:param/0","title":"Grizzly.ZWave.Commands.ClockSet.param/0","type":"type"},{"doc":"This command is used to query the value of one or more configuration parameters.Params::offset - This field is used to specify the first parameter in a range of one or more parameters. (required):number_of_parameters - This field is used to specify the number of requested configuration parameters.","ref":"Grizzly.ZWave.Commands.ConfigurationBulkGet.html","title":"Grizzly.ZWave.Commands.ConfigurationBulkGet","type":"module"},{"doc":"","ref":"Grizzly.ZWave.Commands.ConfigurationBulkGet.html#t:param/0","title":"Grizzly.ZWave.Commands.ConfigurationBulkGet.param/0","type":"type"},{"doc":"This command is used to advertise the actual value of one or more advertised parameters.Params::default - This field is used to specify if the default value is to be restored for the specified configuration parameters. Use carefully: Some devices will incorrectly reset ALL configuration values to default. (required):size - This field is used to specify the number of bytes (1, 2 or 4) of the parameter values (required):handshake - This field is used to indicate if a Configuration Bulk Report Command is to be returned when the specified configuration parameters have been stored in non-volatile memory. (required):offset - This field is used to specify the first parameter in a range of one or more parameters. (required):values - These fields carry the values -of the same size)- to be assigned. (required):reports_to_follow - This field gives the number of reports left before all requested configuration parameters values have been transferred (required)","ref":"Grizzly.ZWave.Commands.ConfigurationBulkReport.html","title":"Grizzly.ZWave.Commands.ConfigurationBulkReport","type":"module"},{"doc":"","ref":"Grizzly.ZWave.Commands.ConfigurationBulkReport.html#t:param/0","title":"Grizzly.ZWave.Commands.ConfigurationBulkReport.param/0","type":"type"},{"doc":"This command is used to set the value of one or more configuration parameters.Params::default - This field is used to specify if the default value is to be restored for the specified configuration parameters. Use carefully: Some devices will incorrectly reset ALL configuration values to default. (required):size - This field is used to specify the number of bytes (1, 2 or 4) of the parameter values (required):handshake - This field is used to indicate if a Configuration Bulk Report Command is to be returned when the specified configuration parameters have been stored in non-volatile memory. (required):offset - This field is used to specify the first parameter in a range of one or more parameters. (required):values - These fields carry the values -of the same size)- to be assigned. (required)","ref":"Grizzly.ZWave.Commands.ConfigurationBulkSet.html","title":"Grizzly.ZWave.Commands.ConfigurationBulkSet","type":"module"},{"doc":"","ref":"Grizzly.ZWave.Commands.ConfigurationBulkSet.html#t:param/0","title":"Grizzly.ZWave.Commands.ConfigurationBulkSet.param/0","type":"type"},{"doc":"This command is used to query the value of a configuration parameter.Params::param_number - the requested configuration parameter","ref":"Grizzly.ZWave.Commands.ConfigurationGet.html","title":"Grizzly.ZWave.Commands.ConfigurationGet","type":"module"},{"doc":"","ref":"Grizzly.ZWave.Commands.ConfigurationGet.html#t:param/0","title":"Grizzly.ZWave.Commands.ConfigurationGet.param/0","type":"type"},{"doc":"This command is used to request the properties of a configuration parameter.Params::param_number - This field is used to specify which configuration parameter (required)","ref":"Grizzly.ZWave.Commands.ConfigurationPropertiesGet.html","title":"Grizzly.ZWave.Commands.ConfigurationPropertiesGet","type":"module"},{"doc":"","ref":"Grizzly.ZWave.Commands.ConfigurationPropertiesGet.html#t:param/0","title":"Grizzly.ZWave.Commands.ConfigurationPropertiesGet.param/0","type":"type"},{"doc":"This command is used to advertise the properties of a configuration parameter.Params::param_number - This field is used to specify which configuration parameter (required)read_only - This field is used to indicate if the parameter is read-only. (optional - v4+):altering_capabilities: - This field is used to indicate if the advertised parameter triggers a change in the node’s capabilities. (optional - v4+):format - This field is used to advertise the format of the parameter, one of :signed_integer, :unsigned_integer, :enumerated, :bit_field (required):size - This field is used to advertise the size of the actual parameter, one of 0, 1, 2, 4 The advertised size MUST also apply to the fields “Min Value”, “Max Value”, “Default Value” carried in this command. (required):min_value - This field advertises the minimum value that the actual parameter can assume. If the parameter is “Bit field”, this field MUST be set to 0. (required if size &gt; 0 else omitted):max_value - This field advertises the maximum value that the actual parameter can assume. If the parameter is “Bit field”, each individual supported bit MUST be set to ‘1’, while each un- supported bit of MUST be set to ‘0’. (required if size &gt; 0 else omitted):default_value - This field MUST advertise the default value of the actual parameter (required if size &gt; 0 else omitted):next_param_number - This field advertises the next available (possibly non-sequential) configuration parameter, else 0 (required):advanced - This field is used to indicate if the advertised parameter is to be presented in the “Advanced” parameter section in the controller GUI. (optional - v4+):no_bulk_support - This field is used to advertise if the sending node supports Bulk Commands. (optional - v4+)","ref":"Grizzly.ZWave.Commands.ConfigurationPropertiesReport.html","title":"Grizzly.ZWave.Commands.ConfigurationPropertiesReport","type":"module"},{"doc":"","ref":"Grizzly.ZWave.Commands.ConfigurationPropertiesReport.html#t:param/0","title":"Grizzly.ZWave.Commands.ConfigurationPropertiesReport.param/0","type":"type"},{"doc":"Reports on a configuration parameterParams::size - specifies the size of the configuration parameter (required):value - the value of the parameter (required):param_number - the configuration parameter number reported on (required)SizeThe size of the parameter are the values 1, 2, and 4 which is the number of bytes for the configuration parameter value. This should be provided by the user manual of our device.","ref":"Grizzly.ZWave.Commands.ConfigurationReport.html","title":"Grizzly.ZWave.Commands.ConfigurationReport","type":"module"},{"doc":"","ref":"Grizzly.ZWave.Commands.ConfigurationReport.html#t:param/0","title":"Grizzly.ZWave.Commands.ConfigurationReport.param/0","type":"type"},{"doc":"Set the configuration parameterParams::size - specifies the size of the configuration parameter (required if not resetting to default):value - the value of the parameter, can be set to :default to set the parameter back to the factory default value (required):param_number - the configuration parameter number to set (required)SizeThe size of the parameter are the values 1, 2, and 4 which is the number of bytes for the configuration parameter value. This should be provided by the user manual of our device.Factory reset a paramIf you want to factory reset a configuration parameter you can pass :default as the :value param","ref":"Grizzly.ZWave.Commands.ConfigurationSet.html","title":"Grizzly.ZWave.Commands.ConfigurationSet","type":"module"},{"doc":"","ref":"Grizzly.ZWave.Commands.ConfigurationSet.html#t:param/0","title":"Grizzly.ZWave.Commands.ConfigurationSet.param/0","type":"type"},{"doc":"Request the S2 DSK of a NodeThe response to this command is DSKReportParams::seq_number - the sequence number of the networked command (required):add_mode - some S2 nodes maybe have two different types of DSKs one being added into a Z-Wave network (learn mode) and another for adding other nodes in the network (add mode) (optional default :learn)","ref":"Grizzly.ZWave.Commands.DSKGet.html","title":"Grizzly.ZWave.Commands.DSKGet","type":"module"},{"doc":"","ref":"Grizzly.ZWave.Commands.DSKGet.html#t:param/0","title":"Grizzly.ZWave.Commands.DSKGet.param/0","type":"type"},{"doc":"Report the DSK for the Z-Wave NodeThis command is the response to the Grizzly.ZWave.Commands.DSKGet commandParams::seq_number - the sequence number for the networked command (required):add_mode - the add mode for the DSK see Grizzly.ZWave.CommandClasses.NetworkManagementBasicNode for more information (required):dsk - the DSK string for the node, see Grizzly.ZWave.DSK for more information (required)","ref":"Grizzly.ZWave.Commands.DSKReport.html","title":"Grizzly.ZWave.Commands.DSKReport","type":"module"},{"doc":"","ref":"Grizzly.ZWave.Commands.DSKReport.html#t:param/0","title":"Grizzly.ZWave.Commands.DSKReport.param/0","type":"type"},{"doc":"This command is used to request the current date adjusted according to the local time zone and Daylight Saving Time from a supporting node.Params: - none -","ref":"Grizzly.ZWave.Commands.DateGet.html","title":"Grizzly.ZWave.Commands.DateGet","type":"module"},{"doc":"This command is used to advertise the current date adjusted according to the local time zone and Daylight Saving Time.Params::year - the year (required):month - the month (required):day - the day (required)","ref":"Grizzly.ZWave.Commands.DateReport.html","title":"Grizzly.ZWave.Commands.DateReport","type":"module"},{"doc":"","ref":"Grizzly.ZWave.Commands.DateReport.html#t:param/0","title":"Grizzly.ZWave.Commands.DateReport.param/0","type":"type"},{"doc":"Reset a Node Z-Wave node back to factory default stateThe response to this command should be the Grizzly.ZWave.Commands.DefaultSetComplete command.Params::seq_number - the sequence number of the networked command (required)","ref":"Grizzly.ZWave.Commands.DefaultSet.html","title":"Grizzly.ZWave.Commands.DefaultSet","type":"module"},{"doc":"","ref":"Grizzly.ZWave.Commands.DefaultSet.html#t:param/0","title":"Grizzly.ZWave.Commands.DefaultSet.param/0","type":"type"},{"doc":"Command to indicate the result of a Grizzly.ZWave.Commands.DefaultSet operationParams::seq_number - the sequence number of the networked command (required):status - the status of the default set operation (required)","ref":"Grizzly.ZWave.Commands.DefaultSetComplete.html","title":"Grizzly.ZWave.Commands.DefaultSetComplete","type":"module"},{"doc":"","ref":"Grizzly.ZWave.Commands.DefaultSetComplete.html#status_from_byte/1","title":"Grizzly.ZWave.Commands.DefaultSetComplete.status_from_byte/1","type":"function"},{"doc":"","ref":"Grizzly.ZWave.Commands.DefaultSetComplete.html#status_to_byte/1","title":"Grizzly.ZWave.Commands.DefaultSetComplete.status_to_byte/1","type":"function"},{"doc":"","ref":"Grizzly.ZWave.Commands.DefaultSetComplete.html#t:param/0","title":"Grizzly.ZWave.Commands.DefaultSetComplete.param/0","type":"type"},{"doc":"","ref":"Grizzly.ZWave.Commands.DefaultSetComplete.html#t:status/0","title":"Grizzly.ZWave.Commands.DefaultSetComplete.status/0","type":"type"},{"doc":"The Device Reset Locally Notification Command is used to advertise that the device will be reset to default.Params: -none-","ref":"Grizzly.ZWave.Commands.DeviceResetLocallyNotification.html","title":"Grizzly.ZWave.Commands.DeviceResetLocallyNotification","type":"module"},{"doc":"This command is used to request the Door Lock capabilities of a supporting node.Params: - none -","ref":"Grizzly.ZWave.Commands.DoorLockCapabilitiesGet.html","title":"Grizzly.ZWave.Commands.DoorLockCapabilitiesGet","type":"module"},{"doc":"This command is used to advertise the Door Lock capabilities supported by the sending node.Params::supported_operations - the supported door lock operation types:supported_door_lock_modes - the supported door lock modes:configurable_outside_handles - which outside handles can be enabled and disabled via configuration:configurable_inside_handles - which inside handles can be enabled and disabled via configuration:supported_door_components - the supported door lock components that can be reported on:auto_relock_supported? - whether the auto-relock functionality is supported:hold_and_release_supported? - whether the hold-and-release functionality is supported:twist_assist_supported? - whether the twist assist functionality is supported:block_to_block_supported? - whether the block-to-block functionality is supported","ref":"Grizzly.ZWave.Commands.DoorLockCapabilitiesReport.html","title":"Grizzly.ZWave.Commands.DoorLockCapabilitiesReport","type":"module"},{"doc":"","ref":"Grizzly.ZWave.Commands.DoorLockCapabilitiesReport.html#t:param/0","title":"Grizzly.ZWave.Commands.DoorLockCapabilitiesReport.param/0","type":"type"},{"doc":"This command is used to request the configuration parameters of a door lock device.Params: - none -","ref":"Grizzly.ZWave.Commands.DoorLockConfigurationGet.html","title":"Grizzly.ZWave.Commands.DoorLockConfigurationGet","type":"module"},{"doc":"This command is used to advertise the configuration parameters of a door lock device.Params::operation_type - the operation type at the supporting node. One of :constant_operation and :timed_operation. (required):manual_outside_door_handles - List of outside handles (1..4) that can open locally (required):manual_inside_door_handles - List of inside handles (1..4) that can open locally (required):lock_timeout - The seconds that the supporting node must wait before returning to the secured mode when receiving timed operation modes in a Door Lock Operation Set Command (required):auto_relock_time - The time setting in seconds for auto-relock functionality. (v.4 only):hold_and_release_time - The time setting in seconds for letting the latch retracted after the supporting node’s mode has been changed to unsecured. (v.4 only):twist_assist? - Indicates if the twist assist functionality is enabled. (v.4 only):block_to_block? - Indicates if the block-to-block functionality is enabled. (v.4 only)","ref":"Grizzly.ZWave.Commands.DoorLockConfigurationReport.html","title":"Grizzly.ZWave.Commands.DoorLockConfigurationReport","type":"module"},{"doc":"","ref":"Grizzly.ZWave.Commands.DoorLockConfigurationReport.html#t:param/0","title":"Grizzly.ZWave.Commands.DoorLockConfigurationReport.param/0","type":"type"},{"doc":"This command is used to set the configuration parameters of a door lock device.Params::operation_type - the operation type at the supporting node. One of :constant_operation and :timed_operation. (required):manual_outside_door_handles - List of outside handles (1..4) that can open locally (required):manual_inside_door_handles - List of inside handles (1..4) that can open locally (required):lock_timeout - The seconds that the supporting node must wait before returning to the secured mode when receiving timed operation modes in a Door Lock Operation Set Command (required):auto_relock_time - The time setting in seconds for auto-relock functionality. (v.4 only):hold_and_release_time - The time setting in seconds for letting the latch retracted after the supporting node’s mode has been changed to unsecured. (v.4 only):twist_assist? - Indicates if the twist assist functionality is enabled. (v.4 only):block_to_block? - Indicates if the block-to-block functionality is enabled. (v.4 only)","ref":"Grizzly.ZWave.Commands.DoorLockConfigurationSet.html","title":"Grizzly.ZWave.Commands.DoorLockConfigurationSet","type":"module"},{"doc":"","ref":"Grizzly.ZWave.Commands.DoorLockConfigurationSet.html#t:param/0","title":"Grizzly.ZWave.Commands.DoorLockConfigurationSet.param/0","type":"type"},{"doc":"OperationGet request the door lock operating modeThe response to this command should be Grizzly.ZWave.Commands.OperationReportParams: - none -","ref":"Grizzly.ZWave.Commands.DoorLockOperationGet.html","title":"Grizzly.ZWave.Commands.DoorLockOperationGet","type":"module"},{"doc":"OperationReport is used to advertise the status of a door lockThis is response to the Grizzly.ZWave.Commands.OperationGet command.Params::mode - the door operating lock mode (required):outside_handles_mode - a map of the outside door handles and if they can or cannot open the door locally (optional):inside_handles_mode - a map of the inside door handles and if they can or cannot open the door locally (optional):latch_position - the position of the latch (optional):bolt_position - the position of the bolt (optional):door_state - the state of the door being open or closed (optional):timeout_minutes - how long the door has been unlocked (required):timeout_seconds - how long the door has been unlocked (required):target_mode - the target mode of an ongoing transition or of the most recent transition (optional - v4)duration - the estimated remaining time before the target mode is realized (optional - v4)","ref":"Grizzly.ZWave.Commands.DoorLockOperationReport.html","title":"Grizzly.ZWave.Commands.DoorLockOperationReport","type":"module"},{"doc":"","ref":"Grizzly.ZWave.Commands.DoorLockOperationReport.html#door_condition_to_byte/3","title":"Grizzly.ZWave.Commands.DoorLockOperationReport.door_condition_to_byte/3","type":"function"},{"doc":"","ref":"Grizzly.ZWave.Commands.DoorLockOperationReport.html#door_handles_modes_to_byte/1","title":"Grizzly.ZWave.Commands.DoorLockOperationReport.door_handles_modes_to_byte/1","type":"function"},{"doc":"This param only matters if the door lock says it supports this door component in the CapabilitiesReport.If it isn't support the node receiving this report can ignore.For defaults, if this param isn't provided during when calling new/1, we 0 this field out by setting it to :disabled","ref":"Grizzly.ZWave.Commands.DoorLockOperationReport.html#t:bolt_position/0","title":"Grizzly.ZWave.Commands.DoorLockOperationReport.bolt_position/0","type":"type"},{"doc":"This param only matters if the door lock says it supports this door component in the CapabilitiesReport.If it isn't support the node receiving this report can ignore.For defaults, if this param isn't provided during when calling new/1, we 0 this field out by setting it to :disabled","ref":"Grizzly.ZWave.Commands.DoorLockOperationReport.html#t:door_state/0","title":"Grizzly.ZWave.Commands.DoorLockOperationReport.door_state/0","type":"type"},{"doc":"These modes tell if the handle can open the door locally or not.The door lock does not have to report all or any of these, so the default is to set them all to disabled if they are not specified when building the command.","ref":"Grizzly.ZWave.Commands.DoorLockOperationReport.html#t:handles_mode/0","title":"Grizzly.ZWave.Commands.DoorLockOperationReport.handles_mode/0","type":"type"},{"doc":"This param only matters if the door lock says it supports this door component in the CapabilitiesReport.If it isn't support the node receiving this report can ignore.For defaults, if this param isn't provided during when calling new/1, we 0 this field out by setting it to :disabled","ref":"Grizzly.ZWave.Commands.DoorLockOperationReport.html#t:latch_position/0","title":"Grizzly.ZWave.Commands.DoorLockOperationReport.latch_position/0","type":"type"},{"doc":"","ref":"Grizzly.ZWave.Commands.DoorLockOperationReport.html#t:param/0","title":"Grizzly.ZWave.Commands.DoorLockOperationReport.param/0","type":"type"},{"doc":"","ref":"Grizzly.ZWave.Commands.DoorLockOperationReport.html#t:timeout_minutes/0","title":"Grizzly.ZWave.Commands.DoorLockOperationReport.timeout_minutes/0","type":"type"},{"doc":"","ref":"Grizzly.ZWave.Commands.DoorLockOperationReport.html#t:timeout_seconds/0","title":"Grizzly.ZWave.Commands.DoorLockOperationReport.timeout_seconds/0","type":"type"},{"doc":"OperationSet command allows you to lock or unlock lock devicesParams::mode - the mode of the operation of the lock device","ref":"Grizzly.ZWave.Commands.DoorLockOperationSet.html","title":"Grizzly.ZWave.Commands.DoorLockOperationSet","type":"module"},{"doc":"","ref":"Grizzly.ZWave.Commands.DoorLockOperationSet.html#t:param/0","title":"Grizzly.ZWave.Commands.DoorLockOperationSet.param/0","type":"type"},{"doc":"This command is used to advertise the current list of failing nodes in the network.Params::seq_number - Sequence number:node_ids - The ids of all nodes in the network found to be unresponsive","ref":"Grizzly.ZWave.Commands.FailedNodeListReport.html","title":"Grizzly.ZWave.Commands.FailedNodeListReport","type":"module"},{"doc":"","ref":"Grizzly.ZWave.Commands.FailedNodeListReport.html#t:param/0","title":"Grizzly.ZWave.Commands.FailedNodeListReport.param/0","type":"type"},{"doc":"This command is used to remove a non-responding node. It will only succeed if the controller has already put the node on the failed nodes list.Params::seq_number - the sequence number of the networked command (required):node_id - The id of the node to be removed if failed as presumed (required)","ref":"Grizzly.ZWave.Commands.FailedNodeRemove.html","title":"Grizzly.ZWave.Commands.FailedNodeRemove","type":"module"},{"doc":"","ref":"Grizzly.ZWave.Commands.FailedNodeRemove.html#t:param/0","title":"Grizzly.ZWave.Commands.FailedNodeRemove.param/0","type":"type"},{"doc":"This command reports on the attempted removal of a presumed failed node.Params::node_id - the id of the node which removal for failure was attempted:seq_number - the sequence number of the removal command:status - whether the presumed failed node was removed","ref":"Grizzly.ZWave.Commands.FailedNodeRemoveStatus.html","title":"Grizzly.ZWave.Commands.FailedNodeRemoveStatus","type":"module"},{"doc":"","ref":"Grizzly.ZWave.Commands.FailedNodeRemoveStatus.html#t:param/0","title":"Grizzly.ZWave.Commands.FailedNodeRemoveStatus.param/0","type":"type"},{"doc":"","ref":"Grizzly.ZWave.Commands.FailedNodeRemoveStatus.html#t:status/0","title":"Grizzly.ZWave.Commands.FailedNodeRemoveStatus.status/0","type":"type"},{"doc":"This module implements command FIRMWARE_MD_GET of command class COMMAND_CLASS_FIRMWARE_UPDATE_MD The command requests a FIRMWARE_MD_REPORTParams: -none-","ref":"Grizzly.ZWave.Commands.FirmwareMDGet.html","title":"Grizzly.ZWave.Commands.FirmwareMDGet","type":"module"},{"doc":"The Firmware Meta Data Report Command is used to advertise the status of the current firmware in the device.Params::manufacturer_id - A unique ID identifying the manufacturer of the device:firmware_id - A manufacturer SHOULD assign a unique Firmware ID to each existing product variant.:checksum - The checksum of the firmware image.:upgradable? - Whether the Z-Wave chip is firmware upgradable:max_fragment_size - The maximum number of Data bytes that a device is able to receive at a time:other_firmware_ids - Ids of firmware targets other than the Z-Wave chip. Empty list if the device's only firmware target is the Z-Wave chip:hardware_version - A value which is unique to this particular version of the product:activation_supported? - Whether the node supports subsequent activation after Firmware Update transfer:active_during_transfer? - Whether the supporting node’s Command Classes functionality will continue to function normally during Firmware Update transfer.","ref":"Grizzly.ZWave.Commands.FirmwareMDReport.html","title":"Grizzly.ZWave.Commands.FirmwareMDReport","type":"module"},{"doc":"","ref":"Grizzly.ZWave.Commands.FirmwareMDReport.html#t:param/0","title":"Grizzly.ZWave.Commands.FirmwareMDReport.param/0","type":"type"},{"doc":"This command is used to advertise the result of a firmware update operation initiated by the Firmware Update Activation Set Command.Params:status - The status of activating the updated firmware:manufacturer_id - A unique ID identifying the manufacturer of the device (required):firmware_id - A manufacturer SHOULD assign a unique Firmware ID to each existing product variant. (required):checksum - The checksum of the firmware image. (required):firmware_target - The firmware image to be updated - 0x00 for the ZWave chip, others are defined by the manufacturer (required):hardware_version - The hardware version (version 5)","ref":"Grizzly.ZWave.Commands.FirmwareUpdateActivationReport.html","title":"Grizzly.ZWave.Commands.FirmwareUpdateActivationReport","type":"module"},{"doc":"","ref":"Grizzly.ZWave.Commands.FirmwareUpdateActivationReport.html#decode_status/1","title":"Grizzly.ZWave.Commands.FirmwareUpdateActivationReport.decode_status/1","type":"function"},{"doc":"","ref":"Grizzly.ZWave.Commands.FirmwareUpdateActivationReport.html#t:param/0","title":"Grizzly.ZWave.Commands.FirmwareUpdateActivationReport.param/0","type":"type"},{"doc":"","ref":"Grizzly.ZWave.Commands.FirmwareUpdateActivationReport.html#t:status/0","title":"Grizzly.ZWave.Commands.FirmwareUpdateActivationReport.status/0","type":"type"},{"doc":"This command is used to initiate the programming of a previously transferred firmware image.Params::manufacturer_id - A unique ID identifying the manufacturer of the device (required):firmware_id - A manufacturer SHOULD assign a unique Firmware ID to each existing product variant. (required):checksum - The checksum of the firmware image. (required):firmware_target - The firmware image to be updated - 0x00 for the ZWave chip, others are defined by the manufacturer (required):hardware_version - The hardware version (version 5)","ref":"Grizzly.ZWave.Commands.FirmwareUpdateActivationSet.html","title":"Grizzly.ZWave.Commands.FirmwareUpdateActivationSet","type":"module"},{"doc":"","ref":"Grizzly.ZWave.Commands.FirmwareUpdateActivationSet.html#t:param/0","title":"Grizzly.ZWave.Commands.FirmwareUpdateActivationSet.param/0","type":"type"},{"doc":"The Firmware Update Meta Data Get Command is used to request one or more Firmware Update Meta Data Report Commands.Params::number_of_reports - Number of firmware update md reports to be received in response to this command (required):report_number - The requested report (required)","ref":"Grizzly.ZWave.Commands.FirmwareUpdateMDGet.html","title":"Grizzly.ZWave.Commands.FirmwareUpdateMDGet","type":"module"},{"doc":"","ref":"Grizzly.ZWave.Commands.FirmwareUpdateMDGet.html#t:param/0","title":"Grizzly.ZWave.Commands.FirmwareUpdateMDGet.param/0","type":"type"},{"doc":"The Firmware Update Meta Data Report Command is used to transfer a firmware image fragment.Params::last? - whether this report carries the last firmware image fragment. (required):report_number - indicates the sequence number of the contained firmware fragment (required):data - one firmware image fragment (required):checksum - the checksum for the entire command (minus the checksum bytes) (v3 - optional)","ref":"Grizzly.ZWave.Commands.FirmwareUpdateMDReport.html","title":"Grizzly.ZWave.Commands.FirmwareUpdateMDReport","type":"module"},{"doc":"","ref":"Grizzly.ZWave.Commands.FirmwareUpdateMDReport.html#t:param/0","title":"Grizzly.ZWave.Commands.FirmwareUpdateMDReport.param/0","type":"type"},{"doc":"The Firmware Update Meta Data Request Get Command is used to request that a firmware update be initiated.Params::manufacturer_id - A unique ID identifying the manufacturer of the device (required):firmware_id - A manufacturer SHOULD assign a unique Firmware ID to each existing product variant. (required):checksum - The checksum of the firmware image. (required):firmware_target - The firmware image to be updated - 0x00 for the ZWave chip, others are defined by the manufacturer (v3):fragment_size - The requested number of Data bytes that is to be used for firmware fragments (v3):activation_may_be_delayed? - Whether the receiving node may delay the actual firmware update. (V4):hardware_version - A value which is unique to this particular version of the product. (v5+)","ref":"Grizzly.ZWave.Commands.FirmwareUpdateMDRequestGet.html","title":"Grizzly.ZWave.Commands.FirmwareUpdateMDRequestGet","type":"module"},{"doc":"","ref":"Grizzly.ZWave.Commands.FirmwareUpdateMDRequestGet.html#t:param/0","title":"Grizzly.ZWave.Commands.FirmwareUpdateMDRequestGet.param/0","type":"type"},{"doc":"This command is used to advertise if the firmware update will be initiated.Params::status - the status of the firmware update request, either :ok or an error such as :invalid_manufacturer_or_device_id","ref":"Grizzly.ZWave.Commands.FirmwareUpdateMDRequestReport.html","title":"Grizzly.ZWave.Commands.FirmwareUpdateMDRequestReport","type":"module"},{"doc":"","ref":"Grizzly.ZWave.Commands.FirmwareUpdateMDRequestReport.html#decode_status/1","title":"Grizzly.ZWave.Commands.FirmwareUpdateMDRequestReport.decode_status/1","type":"function"},{"doc":"","ref":"Grizzly.ZWave.Commands.FirmwareUpdateMDRequestReport.html#encode_status/1","title":"Grizzly.ZWave.Commands.FirmwareUpdateMDRequestReport.encode_status/1","type":"function"},{"doc":"","ref":"Grizzly.ZWave.Commands.FirmwareUpdateMDRequestReport.html#t:param/0","title":"Grizzly.ZWave.Commands.FirmwareUpdateMDRequestReport.param/0","type":"type"},{"doc":"","ref":"Grizzly.ZWave.Commands.FirmwareUpdateMDRequestReport.html#t:status/0","title":"Grizzly.ZWave.Commands.FirmwareUpdateMDRequestReport.status/0","type":"type"},{"doc":"This command is used to advertise the firmware update status.Params::status the status of the firmware update:wait_time - the time in seconds that is needed before the receiving node again becomes available","ref":"Grizzly.ZWave.Commands.FirmwareUpdateMDStatusReport.html","title":"Grizzly.ZWave.Commands.FirmwareUpdateMDStatusReport","type":"module"},{"doc":"","ref":"Grizzly.ZWave.Commands.FirmwareUpdateMDStatusReport.html#t:param/0","title":"Grizzly.ZWave.Commands.FirmwareUpdateMDStatusReport.param/0","type":"type"},{"doc":"","ref":"Grizzly.ZWave.Commands.FirmwareUpdateMDStatusReport.html#t:status/0","title":"Grizzly.ZWave.Commands.FirmwareUpdateMDStatusReport.status/0","type":"type"},{"doc":"Send an unsolicited Hail command to other devices on the networkParams: None","ref":"Grizzly.ZWave.Commands.Hail.html","title":"Grizzly.ZWave.Commands.Hail","type":"module"},{"doc":"This command is used to request a detailed description of the appearance and use of an Indicator IDParams::indicator_id - This field is used to specify the actual indicator resource (required)","ref":"Grizzly.ZWave.Commands.IndicatorDescriptionGet.html","title":"Grizzly.ZWave.Commands.IndicatorDescriptionGet","type":"module"},{"doc":"","ref":"Grizzly.ZWave.Commands.IndicatorDescriptionGet.html#t:param/0","title":"Grizzly.ZWave.Commands.IndicatorDescriptionGet.param/0","type":"type"},{"doc":"This command is used to advertise appearance and use of an indicator ID resource.Params::indicator_id - This field is used to specify the actual indicator resource (required):description - This field is used to advertise the appearance and use of the Indicator ID","ref":"Grizzly.ZWave.Commands.IndicatorDescriptionReport.html","title":"Grizzly.ZWave.Commands.IndicatorDescriptionReport","type":"module"},{"doc":"","ref":"Grizzly.ZWave.Commands.IndicatorDescriptionReport.html#t:param/0","title":"Grizzly.ZWave.Commands.IndicatorDescriptionReport.param/0","type":"type"},{"doc":"This command is used to request the state of an indicator.Params::indicator_id - This field is used to specify the actual indicator resource (required for v2)","ref":"Grizzly.ZWave.Commands.IndicatorGet.html","title":"Grizzly.ZWave.Commands.IndicatorGet","type":"module"},{"doc":"","ref":"Grizzly.ZWave.Commands.IndicatorGet.html#t:param/0","title":"Grizzly.ZWave.Commands.IndicatorGet.param/0","type":"type"},{"doc":"This command is used to advertise the state of an indicator resource.Params::indicator_id - This field is used to specify the actual indicator resource (required for v2+):value - Value of the implied property 0x01 of implied indicator resource 0x00. It is added to :resources if the resources field would otherwise be empty. Else ignored. (required v1):resources - Indicator resources (required for v2+ only)","ref":"Grizzly.ZWave.Commands.IndicatorReport.html","title":"Grizzly.ZWave.Commands.IndicatorReport","type":"module"},{"doc":"","ref":"Grizzly.ZWave.Commands.IndicatorReport.html#t:param/0","title":"Grizzly.ZWave.Commands.IndicatorReport.param/0","type":"type"},{"doc":"This command is used to manipulate one or more indicator resources at a supporting node.Params::value - This field is used to enable or disable the indicator resource (required if v1 - optional and ignored otherwise):resources - Indicator objects, each with an indicator id, property id and value (optional, v2+)","ref":"Grizzly.ZWave.Commands.IndicatorSet.html","title":"Grizzly.ZWave.Commands.IndicatorSet","type":"module"},{"doc":"","ref":"Grizzly.ZWave.Commands.IndicatorSet.html#t:param/0","title":"Grizzly.ZWave.Commands.IndicatorSet.param/0","type":"type"},{"doc":"This command is used to request the supported properties of an indicator.Params::indicator_id - This field is used to specify the actual indicator resource (required)","ref":"Grizzly.ZWave.Commands.IndicatorSupportedGet.html","title":"Grizzly.ZWave.Commands.IndicatorSupportedGet","type":"module"},{"doc":"","ref":"Grizzly.ZWave.Commands.IndicatorSupportedGet.html#t:param/0","title":"Grizzly.ZWave.Commands.IndicatorSupportedGet.param/0","type":"type"},{"doc":"This command is used to advertise the supported properties for a given indicator.Params::indicator_id - This field is used to specify the actual indicator resource (required):next_indicator_id - This field is used to advertise if more Indicator IDs are supported after the actual Indicator ID advertised by the Indicator ID field. (optional):property_ids - The ids of the supported properties by the resource (required)","ref":"Grizzly.ZWave.Commands.IndicatorSupportedReport.html","title":"Grizzly.ZWave.Commands.IndicatorSupportedReport","type":"module"},{"doc":"","ref":"Grizzly.ZWave.Commands.IndicatorSupportedReport.html#t:param/0","title":"Grizzly.ZWave.Commands.IndicatorSupportedReport.param/0","type":"type"},{"doc":"This command is used to allow a node to be added to (or removed from) the network. When a node is added to the network, the node is assigned a valid Home ID and NodeID.Params::seq_number - a command sequence number:return_interview_status - This field is used to request that the receiving node returns an additional Learn Mode Set Status Command when the node interview is completed. It is set to either :on or :off. (optional - defaults to :off):mode - The Mode field controls operation to one of :disable, :direct_range_only (immediate range inclusions only), or :allow_routed (accept routed inclusion)","ref":"Grizzly.ZWave.Commands.LearnModeSet.html","title":"Grizzly.ZWave.Commands.LearnModeSet","type":"module"},{"doc":"","ref":"Grizzly.ZWave.Commands.LearnModeSet.html#t:mode/0","title":"Grizzly.ZWave.Commands.LearnModeSet.mode/0","type":"type"},{"doc":"","ref":"Grizzly.ZWave.Commands.LearnModeSet.html#t:param/0","title":"Grizzly.ZWave.Commands.LearnModeSet.param/0","type":"type"},{"doc":"This command is used to indicate the progress of the Learn Mode Set command.Params::seq_number - the command sequence number:status - the outcome of the learn mode, one of :done, :failed or :security_failed:new_node_id - the new node id assigned to the device:granted_keys - indicates which network keys were granted during bootstrapping; a list with :s2_unauthenticated, :s2_authenticated, :s2_access_control and/or :s0 (optional - v2):kex_fail_type - indicates which error occurred in case S2 bootstrapping was not successful; one of :none, :key, :scheme, :curves, :decrypt, :cancel, :auth, :get, :verify or :report -- see Grizzly.ZWave.Security (optional - v2):dsk - the DSK of the including controller that performed S2 bootstrapping to the node (optional - v2)","ref":"Grizzly.ZWave.Commands.LearnModeSetStatus.html","title":"Grizzly.ZWave.Commands.LearnModeSetStatus","type":"module"},{"doc":"","ref":"Grizzly.ZWave.Commands.LearnModeSetStatus.html#t:param/0","title":"Grizzly.ZWave.Commands.LearnModeSetStatus.param/0","type":"type"},{"doc":"","ref":"Grizzly.ZWave.Commands.LearnModeSetStatus.html#t:status/0","title":"Grizzly.ZWave.Commands.LearnModeSetStatus.status/0","type":"type"},{"doc":"Module for the DEVICE_SPECIFIC_GET command of command class COMMAND_CLASS_MANUFACTURER_SPECIFICParams:device_id_type - :oem_factory_default_device_id_type or :serial_number or :pseudo_random (required)","ref":"Grizzly.ZWave.Commands.ManufacturerSpecificDeviceSpecificGet.html","title":"Grizzly.ZWave.Commands.ManufacturerSpecificDeviceSpecificGet","type":"module"},{"doc":"","ref":"Grizzly.ZWave.Commands.ManufacturerSpecificDeviceSpecificGet.html#t:device_id_type/0","title":"Grizzly.ZWave.Commands.ManufacturerSpecificDeviceSpecificGet.device_id_type/0","type":"type"},{"doc":"","ref":"Grizzly.ZWave.Commands.ManufacturerSpecificDeviceSpecificGet.html#t:param/0","title":"Grizzly.ZWave.Commands.ManufacturerSpecificDeviceSpecificGet.param/0","type":"type"},{"doc":"Module for the DEVICE_SPECIFIC_REPORT command of command class COMMAND_CLASS_MANUFACTURER_SPECIFIC Report the manufacturer specific device specific informationParams::device_id_type - the type of device id reported (required):device_id - unique ID for the device id type (required)","ref":"Grizzly.ZWave.Commands.ManufacturerSpecificDeviceSpecificReport.html","title":"Grizzly.ZWave.Commands.ManufacturerSpecificDeviceSpecificReport","type":"module"},{"doc":"","ref":"Grizzly.ZWave.Commands.ManufacturerSpecificDeviceSpecificReport.html#t:device_id/0","title":"Grizzly.ZWave.Commands.ManufacturerSpecificDeviceSpecificReport.device_id/0","type":"type"},{"doc":"","ref":"Grizzly.ZWave.Commands.ManufacturerSpecificDeviceSpecificReport.html#t:device_id_type/0","title":"Grizzly.ZWave.Commands.ManufacturerSpecificDeviceSpecificReport.device_id_type/0","type":"type"},{"doc":"","ref":"Grizzly.ZWave.Commands.ManufacturerSpecificDeviceSpecificReport.html#t:param/0","title":"Grizzly.ZWave.Commands.ManufacturerSpecificDeviceSpecificReport.param/0","type":"type"},{"doc":"Module for the MANUFACTURER_SPECIFIC_GET command of command class COMMAND_CLASS_MANUFACTURER_SPECIFICParams: - none -","ref":"Grizzly.ZWave.Commands.ManufacturerSpecificGet.html","title":"Grizzly.ZWave.Commands.ManufacturerSpecificGet","type":"module"},{"doc":"Module for the MANUFACTURER_SPECIFIC_REPORT command of command class COMMAND_CLASS_MANUFACTURER_SPECIFIC Report the manufacturer specific informationParams::manufacturer_id - unique ID for the manufacturer (required):product_type_id - unique ID for the product type (required):prodcut_id - unique ID for the actual product (required)","ref":"Grizzly.ZWave.Commands.ManufacturerSpecificReport.html","title":"Grizzly.ZWave.Commands.ManufacturerSpecificReport","type":"module"},{"doc":"","ref":"Grizzly.ZWave.Commands.ManufacturerSpecificReport.html#t:param/0","title":"Grizzly.ZWave.Commands.ManufacturerSpecificReport.param/0","type":"type"},{"doc":"This module implements the METER_GET command of the COMMAND_CLASS_METER command class.This command is used to request the current meter reading to a supporting node.Params: - none - (v1)","ref":"Grizzly.ZWave.Commands.MeterGet.html","title":"Grizzly.ZWave.Commands.MeterGet","type":"module"},{"doc":"This module implements the command METER_REPORT of the COMMAND_CLASS_METER command class.This command is used to advertise the current meter reading at the sending node.Params::meter_type - the type of metering physical unit being reported (required):scale - the unit used (required):value - the value being reported (required)","ref":"Grizzly.ZWave.Commands.MeterReport.html","title":"Grizzly.ZWave.Commands.MeterReport","type":"module"},{"doc":"","ref":"Grizzly.ZWave.Commands.MeterReport.html#t:meter_scale/0","title":"Grizzly.ZWave.Commands.MeterReport.meter_scale/0","type":"type"},{"doc":"","ref":"Grizzly.ZWave.Commands.MeterReport.html#t:meter_type/0","title":"Grizzly.ZWave.Commands.MeterReport.meter_type/0","type":"type"},{"doc":"","ref":"Grizzly.ZWave.Commands.MeterReport.html#t:param/0","title":"Grizzly.ZWave.Commands.MeterReport.param/0","type":"type"},{"doc":"This command is used to query the members of an Aggregated End Point.Params::aggregated_end_point - an aggregated end point","ref":"Grizzly.ZWave.Commands.MultiChannelAggregatedMembersGet.html","title":"Grizzly.ZWave.Commands.MultiChannelAggregatedMembersGet","type":"module"},{"doc":"","ref":"Grizzly.ZWave.Commands.MultiChannelAggregatedMembersGet.html#t:param/0","title":"Grizzly.ZWave.Commands.MultiChannelAggregatedMembersGet.param/0","type":"type"},{"doc":"This command is used to advertise the members of an Aggregated End Point.Params::aggregated_end_point - an aggregated end_point (required):members - the lists of end points member of the aggregated end point (required, can be an empty list)","ref":"Grizzly.ZWave.Commands.MultiChannelAggregatedMembersReport.html","title":"Grizzly.ZWave.Commands.MultiChannelAggregatedMembersReport","type":"module"},{"doc":"","ref":"Grizzly.ZWave.Commands.MultiChannelAggregatedMembersReport.html#t:param/0","title":"Grizzly.ZWave.Commands.MultiChannelAggregatedMembersReport.param/0","type":"type"},{"doc":"This command is used to request the current destinations of a given association group.Params::grouping_identifier - the actual association group","ref":"Grizzly.ZWave.Commands.MultiChannelAssociationGet.html","title":"Grizzly.ZWave.Commands.MultiChannelAssociationGet","type":"module"},{"doc":"","ref":"Grizzly.ZWave.Commands.MultiChannelAssociationGet.html#t:param/0","title":"Grizzly.ZWave.Commands.MultiChannelAssociationGet.param/0","type":"type"},{"doc":"This command is used to request the number of association groups that this node supports.Params: -none-","ref":"Grizzly.ZWave.Commands.MultiChannelAssociationGroupingsGet.html","title":"Grizzly.ZWave.Commands.MultiChannelAssociationGroupingsGet","type":"module"},{"doc":"This command is used to advertise the maximum number of association groups implemented by this node.Params::supported_groupings - the maximum number of association groups","ref":"Grizzly.ZWave.Commands.MultiChannelAssociationGroupingsReport.html","title":"Grizzly.ZWave.Commands.MultiChannelAssociationGroupingsReport","type":"module"},{"doc":"","ref":"Grizzly.ZWave.Commands.MultiChannelAssociationGroupingsReport.html#t:param/0","title":"Grizzly.ZWave.Commands.MultiChannelAssociationGroupingsReport.param/0","type":"type"},{"doc":"This command is used to remove NodeID and End Point destinations from a given association group. The destinations MAY be a mix of NodeID destinations and End Point destinations.Params::grouping_identifier - the association grouping identifier (required):nodes - list of nodes to add the grouping identifier (required):node_endpoints - Endpoints of multichannel nodes","ref":"Grizzly.ZWave.Commands.MultiChannelAssociationRemove.html","title":"Grizzly.ZWave.Commands.MultiChannelAssociationRemove","type":"module"},{"doc":"","ref":"Grizzly.ZWave.Commands.MultiChannelAssociationRemove.html#t:param/0","title":"Grizzly.ZWave.Commands.MultiChannelAssociationRemove.param/0","type":"type"},{"doc":"This command is used to advertise the current destinations for a given association group.Params::grouping_identifier - the association grouping identifier (required):max_nodes_supported - the maximum number of destinations supported by the advertised association group. Each destination may be a NodeID destination or an End Point destination.:reports_to_follow - if the full destination list is too long for one report this field reports the number of follow up reports (optional default `0`):nodes - list of nodes to add the grouping identifier (required):node_endpoints - Endpoints of multichannel nodes","ref":"Grizzly.ZWave.Commands.MultiChannelAssociationReport.html","title":"Grizzly.ZWave.Commands.MultiChannelAssociationReport","type":"module"},{"doc":"","ref":"Grizzly.ZWave.Commands.MultiChannelAssociationReport.html#t:param/0","title":"Grizzly.ZWave.Commands.MultiChannelAssociationReport.param/0","type":"type"},{"doc":"This command is used to request that one or more destinations are added to a given association group. The destinations MAY be a mix of NodeID destinations and End Point destinations.Params::grouping_identifier - the association grouping identifier (required):nodes - list of nodes to add the grouping identifier (required):node_endpoints - Endpoints of multichannel nodes","ref":"Grizzly.ZWave.Commands.MultiChannelAssociationSet.html","title":"Grizzly.ZWave.Commands.MultiChannelAssociationSet","type":"module"},{"doc":"","ref":"Grizzly.ZWave.Commands.MultiChannelAssociationSet.html#t:param/0","title":"Grizzly.ZWave.Commands.MultiChannelAssociationSet.param/0","type":"type"},{"doc":"This command is used to query the non-secure Command Class capabilities of an End Point.Params::end_point - an end point (required)","ref":"Grizzly.ZWave.Commands.MultiChannelCapabilityGet.html","title":"Grizzly.ZWave.Commands.MultiChannelCapabilityGet","type":"module"},{"doc":"","ref":"Grizzly.ZWave.Commands.MultiChannelCapabilityGet.html#t:param/0","title":"Grizzly.ZWave.Commands.MultiChannelCapabilityGet.param/0","type":"type"},{"doc":"This command is used to advertise the Generic and Specific Device Class and the supported command classes of an End Point.Params::end_point - the end point capabilities are being reported about (required):dynamic? - whether the end point is dynamic (required - true or false):generic_device_class - the generic device class for the end point (required):specific_device_class - the specific device class for the end point (required):command_classes - the command classes supported by the end point (required)","ref":"Grizzly.ZWave.Commands.MultiChannelCapabilityReport.html","title":"Grizzly.ZWave.Commands.MultiChannelCapabilityReport","type":"module"},{"doc":"","ref":"Grizzly.ZWave.Commands.MultiChannelCapabilityReport.html#t:param/0","title":"Grizzly.ZWave.Commands.MultiChannelCapabilityReport.param/0","type":"type"},{"doc":"This command is used to encapsulate commands to or from a Multi Channel End Point.Params::source_end_point - the originating End Point (defaults to 0 - if 0, destination_end_point must be non-zero).:bit_address? - whether the End Point is bit-masked, or as-is (defaults to false):destination_end_point - the destination End Point. (defaults to 0 - - if 0, source_end_point must be non-zero):command_class - the command class of the command sent (required):command - the name of the command (required):parameters - the command parameters (required)","ref":"Grizzly.ZWave.Commands.MultiChannelCommandEncapsulation.html","title":"Grizzly.ZWave.Commands.MultiChannelCommandEncapsulation","type":"module"},{"doc":"","ref":"Grizzly.ZWave.Commands.MultiChannelCommandEncapsulation.html#t:param/0","title":"Grizzly.ZWave.Commands.MultiChannelCommandEncapsulation.param/0","type":"type"},{"doc":"This command is used to request End Points having a specific Generic or Specific Device Class in End Points.Params::generic_device_class - a generic device class (required):specific_device_class - a specific device class (required)","ref":"Grizzly.ZWave.Commands.MultiChannelEndpointFind.html","title":"Grizzly.ZWave.Commands.MultiChannelEndpointFind","type":"module"},{"doc":"","ref":"Grizzly.ZWave.Commands.MultiChannelEndpointFind.html#t:param/0","title":"Grizzly.ZWave.Commands.MultiChannelEndpointFind.param/0","type":"type"},{"doc":"This command is used to advertise End Points that implement a given combination of Generic and Specific Device Classes.Params::reports_to_follow - the number of reports to follow (required):generic_device_class - a generic device class (required):specific_device_class - a specific device class (required):end_points - the list of End Point identifier(s) that matches the advertised Generic and Specific Device Class values. (required)","ref":"Grizzly.ZWave.Commands.MultiChannelEndpointFindReport.html","title":"Grizzly.ZWave.Commands.MultiChannelEndpointFindReport","type":"module"},{"doc":"","ref":"Grizzly.ZWave.Commands.MultiChannelEndpointFindReport.html#t:end_point/0","title":"Grizzly.ZWave.Commands.MultiChannelEndpointFindReport.end_point/0","type":"type"},{"doc":"","ref":"Grizzly.ZWave.Commands.MultiChannelEndpointFindReport.html#t:param/0","title":"Grizzly.ZWave.Commands.MultiChannelEndpointFindReport.param/0","type":"type"},{"doc":"This command is used to query the number of End Points implemented by the receiving node.Params: - none","ref":"Grizzly.ZWave.Commands.MultiChannelEndpointGet.html","title":"Grizzly.ZWave.Commands.MultiChannelEndpointGet","type":"module"},{"doc":"This command is used to advertise the number of End Points implemented by the sending node.Params::dynamic - whether the node implements a dynamic number of End Points (required):identical - whether all end points have identical capabilities (required):endpoints - the number of endpoints (required):aggregated_endpoints - the number of Aggregated End Points implemented by this node (optional - v4)","ref":"Grizzly.ZWave.Commands.MultiChannelEndpointReport.html","title":"Grizzly.ZWave.Commands.MultiChannelEndpointReport","type":"module"},{"doc":"","ref":"Grizzly.ZWave.Commands.MultiChannelEndpointReport.html#t:param/0","title":"Grizzly.ZWave.Commands.MultiChannelEndpointReport.param/0","type":"type"},{"doc":"The Multi Command Encapsulated Command used to contain multiple Commands.Params::commands - the commands encapsulated in this one","ref":"Grizzly.ZWave.Commands.MultiCommandEncapsulated.html","title":"Grizzly.ZWave.Commands.MultiCommandEncapsulated","type":"module"},{"doc":"","ref":"Grizzly.ZWave.Commands.MultiCommandEncapsulated.html#t:param/0","title":"Grizzly.ZWave.Commands.MultiCommandEncapsulated.param/0","type":"type"},{"doc":"This command is used to request network topology updates from the SUC/SIS node.Params::seq_number - a sequence number for the commands (required)","ref":"Grizzly.ZWave.Commands.NetworkUpdateRequest.html","title":"Grizzly.ZWave.Commands.NetworkUpdateRequest","type":"module"},{"doc":"","ref":"Grizzly.ZWave.Commands.NetworkUpdateRequest.html#t:param/0","title":"Grizzly.ZWave.Commands.NetworkUpdateRequest.param/0","type":"type"},{"doc":"This command is used to indicate if the Network Update Request command execution has completed successfully or not.Params::seq_number - the sequence number of the update network request command (required):status - the status of the Network Update process (required)","ref":"Grizzly.ZWave.Commands.NetworkUpdateRequestStatus.html","title":"Grizzly.ZWave.Commands.NetworkUpdateRequestStatus","type":"module"},{"doc":"","ref":"Grizzly.ZWave.Commands.NetworkUpdateRequestStatus.html#t:param/0","title":"Grizzly.ZWave.Commands.NetworkUpdateRequestStatus.param/0","type":"type"},{"doc":"This commands does nothing other than test if the node is respondingParams: - none -","ref":"Grizzly.ZWave.Commands.NoOperation.html","title":"Grizzly.ZWave.Commands.NoOperation","type":"module"},{"doc":"Command for NODE_ADDParams::seq_number - the sequence number for the network command (required):mode - the inclusion mode (optional default :node_add_any_s2):tx_opts - the transmission options (optional default :explore)If your controller does not support the NETWORK_MANAGEMENT_INCLUSION version 2, you will ned to pass :node_add_any as the :mode parameter.This command should return the NodeAddStatus report after inclusion is complete","ref":"Grizzly.ZWave.Commands.NodeAdd.html","title":"Grizzly.ZWave.Commands.NodeAdd","type":"module"},{"doc":"","ref":"Grizzly.ZWave.Commands.NodeAdd.html#decode_mode/1","title":"Grizzly.ZWave.Commands.NodeAdd.decode_mode/1","type":"function"},{"doc":"","ref":"Grizzly.ZWave.Commands.NodeAdd.html#decode_tx_opt/1","title":"Grizzly.ZWave.Commands.NodeAdd.decode_tx_opt/1","type":"function"},{"doc":"","ref":"Grizzly.ZWave.Commands.NodeAdd.html#encode_mode/1","title":"Grizzly.ZWave.Commands.NodeAdd.encode_mode/1","type":"function"},{"doc":"","ref":"Grizzly.ZWave.Commands.NodeAdd.html#encode_tx_opt/1","title":"Grizzly.ZWave.Commands.NodeAdd.encode_tx_opt/1","type":"function"},{"doc":"","ref":"Grizzly.ZWave.Commands.NodeAdd.html#t:mode/0","title":"Grizzly.ZWave.Commands.NodeAdd.mode/0","type":"type"},{"doc":"","ref":"Grizzly.ZWave.Commands.NodeAdd.html#t:param/0","title":"Grizzly.ZWave.Commands.NodeAdd.param/0","type":"type"},{"doc":"","ref":"Grizzly.ZWave.Commands.NodeAdd.html#t:tx_opt/0","title":"Grizzly.ZWave.Commands.NodeAdd.tx_opt/0","type":"type"},{"doc":"The Z-Wave Command NODE_ADD_DSK_REPORTThis report is used by the including controller to ask for the DSK for the device that is being included.Params:seq_number - sequence number for the command (required):input_dsk_length - the required number of bytes must be in the :dsk field to be authenticated (optional default: 0):dsk - the DSK for the device see Grizzly.ZWave.DSK for more information (required)The :input_dsk_length field can be set to 0 if not provided. That means that device does not require any user input to the DSK set command to authenticate the device. This case is normal when :s2_unauthenticated or client side authentication has been given.","ref":"Grizzly.ZWave.Commands.NodeAddDSKReport.html","title":"Grizzly.ZWave.Commands.NodeAddDSKReport","type":"module"},{"doc":"","ref":"Grizzly.ZWave.Commands.NodeAddDSKReport.html#validate_and_ensure_input_dsk_length/1","title":"Grizzly.ZWave.Commands.NodeAddDSKReport.validate_and_ensure_input_dsk_length/1","type":"function"},{"doc":"","ref":"Grizzly.ZWave.Commands.NodeAddDSKReport.html#t:param/0","title":"Grizzly.ZWave.Commands.NodeAddDSKReport.param/0","type":"type"},{"doc":"Command to set the DSK for a including nodeParams::seq_number - the sequence number for the command (required):accept - the including controller accepts the inclusion process and should proceed with adding the including node (required)input_dsk_length - the length of the DSK provided (required)input_dsk - the DSK pin for the including node (required)","ref":"Grizzly.ZWave.Commands.NodeAddDSKSet.html","title":"Grizzly.ZWave.Commands.NodeAddDSKSet","type":"module"},{"doc":"","ref":"Grizzly.ZWave.Commands.NodeAddDSKSet.html#t:param/0","title":"Grizzly.ZWave.Commands.NodeAddDSKSet.param/0","type":"type"},{"doc":"Command to report the security keys requested by an including node if that node is participating in S2 bootstrapping.Params::seq_number - the sequence number of the command (required):csa - if the including node is doing client side authentication (require):requested_keys - a list of requested security keys see Grizzly.ZWave.Security for more information. (required)","ref":"Grizzly.ZWave.Commands.NodeAddKeysReport.html","title":"Grizzly.ZWave.Commands.NodeAddKeysReport","type":"module"},{"doc":"","ref":"Grizzly.ZWave.Commands.NodeAddKeysReport.html#decode_csa/1","title":"Grizzly.ZWave.Commands.NodeAddKeysReport.decode_csa/1","type":"function"},{"doc":"","ref":"Grizzly.ZWave.Commands.NodeAddKeysReport.html#decode_requested_keys/1","title":"Grizzly.ZWave.Commands.NodeAddKeysReport.decode_requested_keys/1","type":"function"},{"doc":"","ref":"Grizzly.ZWave.Commands.NodeAddKeysReport.html#encode_csa/1","title":"Grizzly.ZWave.Commands.NodeAddKeysReport.encode_csa/1","type":"function"},{"doc":"","ref":"Grizzly.ZWave.Commands.NodeAddKeysReport.html#encode_requested_keys/1","title":"Grizzly.ZWave.Commands.NodeAddKeysReport.encode_requested_keys/1","type":"function"},{"doc":"Command used to grant the security keys to the including node if the including node requested keys.This normally only needs to happen during the S2 bootstrapping process.Params::seq_number - the sequence number (required):csa - if the including node requested client side authentication, then setting this to true will allow for that node to preform CSA (required):granted_keys - the keys the including controller is granting to the including device, see Grizzly.ZWave.Security for more information (required)","ref":"Grizzly.ZWave.Commands.NodeAddKeysSet.html","title":"Grizzly.ZWave.Commands.NodeAddKeysSet","type":"module"},{"doc":"","ref":"Grizzly.ZWave.Commands.NodeAddKeysSet.html#decode_accepted/1","title":"Grizzly.ZWave.Commands.NodeAddKeysSet.decode_accepted/1","type":"function"},{"doc":"","ref":"Grizzly.ZWave.Commands.NodeAddKeysSet.html#decode_csa/1","title":"Grizzly.ZWave.Commands.NodeAddKeysSet.decode_csa/1","type":"function"},{"doc":"","ref":"Grizzly.ZWave.Commands.NodeAddKeysSet.html#decode_granted_keys/1","title":"Grizzly.ZWave.Commands.NodeAddKeysSet.decode_granted_keys/1","type":"function"},{"doc":"","ref":"Grizzly.ZWave.Commands.NodeAddKeysSet.html#encode_accepted/1","title":"Grizzly.ZWave.Commands.NodeAddKeysSet.encode_accepted/1","type":"function"},{"doc":"","ref":"Grizzly.ZWave.Commands.NodeAddKeysSet.html#encode_csa/1","title":"Grizzly.ZWave.Commands.NodeAddKeysSet.encode_csa/1","type":"function"},{"doc":"","ref":"Grizzly.ZWave.Commands.NodeAddKeysSet.html#encode_granted_keys/1","title":"Grizzly.ZWave.Commands.NodeAddKeysSet.encode_granted_keys/1","type":"function"},{"doc":"Command for NODE_ADD_STATUSThis command is normally the report from adding a node to the Z-Wave networkParams::seq_number - the sequence number of the inclusion command:status - the status of the inclusion:node_id - the new id of the new Z-Wave node:listening? - if the node is a listening node or not:basic_device_class - the Z-Wave basic device class:generic_device_class - the Z-Wave generic device class:specific_device_class - the Z-Wave specific device class:command_classes - a list of the command class the device supports, tagged by their security level used only if the device was included securely:granted_keys - the security keys granted during S2 inclusion (optional):kex_fail_type - the error that occurred in the S2 bootstrapping (optional):input_dsk - the device DSK","ref":"Grizzly.ZWave.Commands.NodeAddStatus.html","title":"Grizzly.ZWave.Commands.NodeAddStatus","type":"module"},{"doc":"","ref":"Grizzly.ZWave.Commands.NodeAddStatus.html#decode_status/1","title":"Grizzly.ZWave.Commands.NodeAddStatus.decode_status/1","type":"function"},{"doc":"","ref":"Grizzly.ZWave.Commands.NodeAddStatus.html#encode_listening_bit/1","title":"Grizzly.ZWave.Commands.NodeAddStatus.encode_listening_bit/1","type":"function"},{"doc":"","ref":"Grizzly.ZWave.Commands.NodeAddStatus.html#encode_status/1","title":"Grizzly.ZWave.Commands.NodeAddStatus.encode_status/1","type":"function"},{"doc":"","ref":"Grizzly.ZWave.Commands.NodeAddStatus.html#t:param/0","title":"Grizzly.ZWave.Commands.NodeAddStatus.param/0","type":"type"},{"doc":"","ref":"Grizzly.ZWave.Commands.NodeAddStatus.html#t:status/0","title":"Grizzly.ZWave.Commands.NodeAddStatus.status/0","type":"type"},{"doc":"","ref":"Grizzly.ZWave.Commands.NodeAddStatus.html#t:tagged_command_classes/0","title":"Grizzly.ZWave.Commands.NodeAddStatus.tagged_command_classes/0","type":"type"},{"doc":"Report the cached node informationThis command is normally used to respond to the NodeInfoCacheGet commandParams::seq_number - the sequence number of the network command, normally from from the NodeInfoCacheGet command (required):status - the status fo the node information (required):age - the age of the cache data. A number that is expressed 2 ^ n minutes (required):listening? - if the node is listening node or sleeping node (required):command_classes - a list of lists of command classes tagged by security attributes (optional default empty list):basic_device_class - the basic device class (required):generic_device_class - the generic device class (required):specific_device_class - the specific device class (required)","ref":"Grizzly.ZWave.Commands.NodeInfoCacheReport.html","title":"Grizzly.ZWave.Commands.NodeInfoCacheReport","type":"module"},{"doc":"","ref":"Grizzly.ZWave.Commands.NodeInfoCacheReport.html#bit_to_bool/1","title":"Grizzly.ZWave.Commands.NodeInfoCacheReport.bit_to_bool/1","type":"function"},{"doc":"","ref":"Grizzly.ZWave.Commands.NodeInfoCacheReport.html#decode_command_classes/1","title":"Grizzly.ZWave.Commands.NodeInfoCacheReport.decode_command_classes/1","type":"function"},{"doc":"","ref":"Grizzly.ZWave.Commands.NodeInfoCacheReport.html#decode_status/1","title":"Grizzly.ZWave.Commands.NodeInfoCacheReport.decode_status/1","type":"function"},{"doc":"","ref":"Grizzly.ZWave.Commands.NodeInfoCacheReport.html#encode_command_classes/1","title":"Grizzly.ZWave.Commands.NodeInfoCacheReport.encode_command_classes/1","type":"function"},{"doc":"","ref":"Grizzly.ZWave.Commands.NodeInfoCacheReport.html#encode_listening?/1","title":"Grizzly.ZWave.Commands.NodeInfoCacheReport.encode_listening?/1","type":"function"},{"doc":"","ref":"Grizzly.ZWave.Commands.NodeInfoCacheReport.html#encode_optional_functionality_byte/1","title":"Grizzly.ZWave.Commands.NodeInfoCacheReport.encode_optional_functionality_byte/1","type":"function"},{"doc":"","ref":"Grizzly.ZWave.Commands.NodeInfoCacheReport.html#encode_status/1","title":"Grizzly.ZWave.Commands.NodeInfoCacheReport.encode_status/1","type":"function"},{"doc":"","ref":"Grizzly.ZWave.Commands.NodeInfoCacheReport.html#t:param/0","title":"Grizzly.ZWave.Commands.NodeInfoCacheReport.param/0","type":"type"},{"doc":"The status of the refresh of the node information cacheStatus::ok - the requested node id could found and up-to-date information is returned:not_responding - the requested node id could be found but fresh information could not be retrieved:unknown - the node id is unknown","ref":"Grizzly.ZWave.Commands.NodeInfoCacheReport.html#t:status/0","title":"Grizzly.ZWave.Commands.NodeInfoCacheReport.status/0","type":"type"},{"doc":"","ref":"Grizzly.ZWave.Commands.NodeInfoCacheReport.html#t:tagged_command_classes/0","title":"Grizzly.ZWave.Commands.NodeInfoCacheReport.tagged_command_classes/0","type":"type"},{"doc":"Get the node information that is cached on another deviceThis is useful for getting the command classes and device classesWhen sending this command the Z-Wave network should send back a NodeInfoCachedReport command.Params: :seq_number - the sequence number for the networked command (required) :max_age - the max age of the node info frame give in 2^n minutes see section on cached minutes below for more information (optional) :node_id - the node id that that node information is being requested for (required)Cached MinutesThis Z-Wave network will cache node information to perverse bandwidth and provides access to node information about sleeping nodes.When sending the NodeInfoCachedGet command we can specify the max age of the cached data. If the cached data is older than the :max_age param the Z-Wave network will try to refresh the cache and send back the most updated information.The values for the :max_age parameter are numbers from 1 to 14. This number will be 2 ^ number minutes. So if you pass the number 4 the receiving Z-Wave device will consider that 16 minutes.Two other options are :infinite and :force_update. Where :infinite means that the cache will not be freshed regardless of how old the data is and where :force_update means that no matter the age of the cached node data the cache will attempt to be updated.We default to 10 which 1024 minutes, or just a little over 1 day. This default is chosen to limit bandwidth usage. Also, the data found in the report is fairly static, so there isn't a pressing need to update the cache to often.","ref":"Grizzly.ZWave.Commands.NodeInfoCachedGet.html","title":"Grizzly.ZWave.Commands.NodeInfoCachedGet","type":"module"},{"doc":"","ref":"Grizzly.ZWave.Commands.NodeInfoCachedGet.html#decode_max_age/1","title":"Grizzly.ZWave.Commands.NodeInfoCachedGet.decode_max_age/1","type":"function"},{"doc":"","ref":"Grizzly.ZWave.Commands.NodeInfoCachedGet.html#encode_max_age/1","title":"Grizzly.ZWave.Commands.NodeInfoCachedGet.encode_max_age/1","type":"function"},{"doc":"","ref":"Grizzly.ZWave.Commands.NodeInfoCachedGet.html#t:max_age/0","title":"Grizzly.ZWave.Commands.NodeInfoCachedGet.max_age/0","type":"type"},{"doc":"","ref":"Grizzly.ZWave.Commands.NodeInfoCachedGet.html#t:param/0","title":"Grizzly.ZWave.Commands.NodeInfoCachedGet.param/0","type":"type"},{"doc":"Module for the NODE_LIST_GET commandParams::seq_number - the sequence number for the command (required)","ref":"Grizzly.ZWave.Commands.NodeListGet.html","title":"Grizzly.ZWave.Commands.NodeListGet","type":"module"},{"doc":"","ref":"Grizzly.ZWave.Commands.NodeListGet.html#t:param/0","title":"Grizzly.ZWave.Commands.NodeListGet.param/0","type":"type"},{"doc":"The NODE_LIST_REPORT command","ref":"Grizzly.ZWave.Commands.NodeListReport.html","title":"Grizzly.ZWave.Commands.NodeListReport","type":"module"},{"doc":"","ref":"Grizzly.ZWave.Commands.NodeListReport.html#decode_controller_id/1","title":"Grizzly.ZWave.Commands.NodeListReport.decode_controller_id/1","type":"function"},{"doc":"","ref":"Grizzly.ZWave.Commands.NodeListReport.html#decode_node_ids/1","title":"Grizzly.ZWave.Commands.NodeListReport.decode_node_ids/1","type":"function"},{"doc":"","ref":"Grizzly.ZWave.Commands.NodeListReport.html#decode_status/1","title":"Grizzly.ZWave.Commands.NodeListReport.decode_status/1","type":"function"},{"doc":"","ref":"Grizzly.ZWave.Commands.NodeListReport.html#encode_controller_id/1","title":"Grizzly.ZWave.Commands.NodeListReport.encode_controller_id/1","type":"function"},{"doc":"","ref":"Grizzly.ZWave.Commands.NodeListReport.html#encode_node_ids/1","title":"Grizzly.ZWave.Commands.NodeListReport.encode_node_ids/1","type":"function"},{"doc":"","ref":"Grizzly.ZWave.Commands.NodeListReport.html#encode_status/1","title":"Grizzly.ZWave.Commands.NodeListReport.encode_status/1","type":"function"},{"doc":"This command is used to request the stored location from a node.Params: - none -","ref":"Grizzly.ZWave.Commands.NodeLocationGet.html","title":"Grizzly.ZWave.Commands.NodeLocationGet","type":"module"},{"doc":"This command is used to advertize the location of the receiving node.Params::encoding - one of :ascii, :extended_ascii, :utf_16:location - a string location for the node","ref":"Grizzly.ZWave.Commands.NodeLocationReport.html","title":"Grizzly.ZWave.Commands.NodeLocationReport","type":"module"},{"doc":"","ref":"Grizzly.ZWave.Commands.NodeLocationReport.html#t:param/0","title":"Grizzly.ZWave.Commands.NodeLocationReport.param/0","type":"type"},{"doc":"This command is used to set the location of the receiving node.Params::encoding - one of :ascii, :extended_ascii, :utf_16:location - a string location for the node","ref":"Grizzly.ZWave.Commands.NodeLocationSet.html","title":"Grizzly.ZWave.Commands.NodeLocationSet","type":"module"},{"doc":"","ref":"Grizzly.ZWave.Commands.NodeLocationSet.html#t:param/0","title":"Grizzly.ZWave.Commands.NodeLocationSet.param/0","type":"type"},{"doc":"This command is used to request the stored name from a node.Params: - none -","ref":"Grizzly.ZWave.Commands.NodeNameGet.html","title":"Grizzly.ZWave.Commands.NodeNameGet","type":"module"},{"doc":"This command is used to advertize the name of the receiving node.Params::encoding - one of :ascii, :extended_ascii, :utf_16:name - a string name for the node","ref":"Grizzly.ZWave.Commands.NodeNameReport.html","title":"Grizzly.ZWave.Commands.NodeNameReport","type":"module"},{"doc":"","ref":"Grizzly.ZWave.Commands.NodeNameReport.html#t:param/0","title":"Grizzly.ZWave.Commands.NodeNameReport.param/0","type":"type"},{"doc":"This command is used to set the name of the receiving node.Params::encoding - one of :ascii, :extended_ascii, :utf_16:name - a string name for the node","ref":"Grizzly.ZWave.Commands.NodeNameSet.html","title":"Grizzly.ZWave.Commands.NodeNameSet","type":"module"},{"doc":"","ref":"Grizzly.ZWave.Commands.NodeNameSet.html#t:param/0","title":"Grizzly.ZWave.Commands.NodeNameSet.param/0","type":"type"},{"doc":"Node Provisioning Delete CommandThis command is useful for deleting Z-Wave nodes from the node provisioning list.After deleting a Z-Wave node entry from the node provisioning list you will still have run excluded the node from the Z-Wave network.Params::seq_number - the sequence number for the network command (required):dsk - the DSK string of the node to delete, please see Grizzly.ZWave.DSK for more information (required)","ref":"Grizzly.ZWave.Commands.NodeProvisioningDelete.html","title":"Grizzly.ZWave.Commands.NodeProvisioningDelete","type":"module"},{"doc":"","ref":"Grizzly.ZWave.Commands.NodeProvisioningDelete.html#t:param/0","title":"Grizzly.ZWave.Commands.NodeProvisioningDelete.param/0","type":"type"},{"doc":"This module implements command COMMAND_NODE_PROVISIONING_GET of the COMMAND_CLASS_NODE_PROVISIONING command classThis command is used to request the metadata information associated to an entry in the node Provisioning ListParams::seq_number - the sequence number of the networked command (required):dsk - the Grizzly.ZWave.DSK.t() for the entry being requested (required)","ref":"Grizzly.ZWave.Commands.NodeProvisioningGet.html","title":"Grizzly.ZWave.Commands.NodeProvisioningGet","type":"module"},{"doc":"","ref":"Grizzly.ZWave.Commands.NodeProvisioningGet.html#t:param/0","title":"Grizzly.ZWave.Commands.NodeProvisioningGet.param/0","type":"type"},{"doc":"Module for working with the NODE_PROVISIONING_LIST_ITERATION_GET commandThis command is used to read the entire the provisioning list.Params::seq_number - the network command sequence number (required):remaining_counter - indicates the remaining amount of entries in the Provisioning List, not provided if starting (optional)","ref":"Grizzly.ZWave.Commands.NodeProvisioningListIterationGet.html","title":"Grizzly.ZWave.Commands.NodeProvisioningListIterationGet","type":"module"},{"doc":"","ref":"Grizzly.ZWave.Commands.NodeProvisioningListIterationGet.html#t:param/0","title":"Grizzly.ZWave.Commands.NodeProvisioningListIterationGet.param/0","type":"type"},{"doc":"Module for working with the NODE_PROVISIONING_LIST_ITERATION_REPORT commandThis command is used to advertise the contents of an entry in the Provisioning List of the sending node.Params::seq_number - the network command sequence number (required):remaining_count - indicates the remaining amount of entries in the Provisioning List:dsk - a Grizzly.ZWave.DSK.t() for the device (optional):meta_extensions - a list of Grizzly.ZWave.SmartStart.MetaExtension.t() (optional default [])","ref":"Grizzly.ZWave.Commands.NodeProvisioningListIterationReport.html","title":"Grizzly.ZWave.Commands.NodeProvisioningListIterationReport","type":"module"},{"doc":"","ref":"Grizzly.ZWave.Commands.NodeProvisioningListIterationReport.html#t:param/0","title":"Grizzly.ZWave.Commands.NodeProvisioningListIterationReport.param/0","type":"type"},{"doc":"Module for working with the NODE_PROVISIONING_REPORT commandThis command is used to advertise the contents of an entry in the node Provisioning List of the sending nodeParams::seq_number - the network command sequence number (required):dsk - a DSK string for the device see Grizzly.ZWave.DSK for more more information (optional):meta_extensions - a list of Grizzly.ZWave.SmartStart.MetaExtension.t() (optional default [])","ref":"Grizzly.ZWave.Commands.NodeProvisioningReport.html","title":"Grizzly.ZWave.Commands.NodeProvisioningReport","type":"module"},{"doc":"","ref":"Grizzly.ZWave.Commands.NodeProvisioningReport.html#t:param/0","title":"Grizzly.ZWave.Commands.NodeProvisioningReport.param/0","type":"type"},{"doc":"Module for working with the NODE_PROVISIONING_SET commandThis command adds a node to the node provisioning list.Params::seq_number - the network command sequence number (required):dsk - a DSK string for the device see Grizzly.ZWave.DSK for more more information (required):meta_extensions - a list of Grizzly.ZWave.SmartStart.MetaExtension.t() (optional default [])","ref":"Grizzly.ZWave.Commands.NodeProvisioningSet.html","title":"Grizzly.ZWave.Commands.NodeProvisioningSet","type":"module"},{"doc":"","ref":"Grizzly.ZWave.Commands.NodeProvisioningSet.html#t:param/0","title":"Grizzly.ZWave.Commands.NodeProvisioningSet.param/0","type":"type"},{"doc":"Z-Wave command NODE_REMOVEThis command is useful for removing Z-Wave devices from the Z-Wave networkThis response to this command should be a Grizzly.ZWave.Commands.NodeRemoveStatusParams::seq_number - the sequence number for the network command (required):mode - the mode for the remove node process (optional default :remove_node_any)","ref":"Grizzly.ZWave.Commands.NodeRemove.html","title":"Grizzly.ZWave.Commands.NodeRemove","type":"module"},{"doc":"","ref":"Grizzly.ZWave.Commands.NodeRemove.html#decode_mode/1","title":"Grizzly.ZWave.Commands.NodeRemove.decode_mode/1","type":"function"},{"doc":"","ref":"Grizzly.ZWave.Commands.NodeRemove.html#encode_mode/1","title":"Grizzly.ZWave.Commands.NodeRemove.encode_mode/1","type":"function"},{"doc":"","ref":"Grizzly.ZWave.Commands.NodeRemove.html#t:mode/0","title":"Grizzly.ZWave.Commands.NodeRemove.mode/0","type":"type"},{"doc":"Z-Wave command for NODE_REMOVE_STATUSThis command is useful to respond to a Grizzly.ZWave.Commands.NodeRemove command.Params::seq_number - the sequence number from the original node remove command:status - the status of the result of the node removal:node_id the node id of the removed nodeAll the parameters are required","ref":"Grizzly.ZWave.Commands.NodeRemoveStatus.html","title":"Grizzly.ZWave.Commands.NodeRemoveStatus","type":"module"},{"doc":"","ref":"Grizzly.ZWave.Commands.NodeRemoveStatus.html#decode_status/1","title":"Grizzly.ZWave.Commands.NodeRemoveStatus.decode_status/1","type":"function"},{"doc":"","ref":"Grizzly.ZWave.Commands.NodeRemoveStatus.html#encode_status/1","title":"Grizzly.ZWave.Commands.NodeRemoveStatus.encode_status/1","type":"function"},{"doc":"","ref":"Grizzly.ZWave.Commands.NodeRemoveStatus.html#t:status/0","title":"Grizzly.ZWave.Commands.NodeRemoveStatus.status/0","type":"type"},{"doc":"This command is used to request the current power level value.Params: - none -","ref":"Grizzly.ZWave.Commands.PowerlevelGet.html","title":"Grizzly.ZWave.Commands.PowerlevelGet","type":"module"},{"doc":"This command is used to advertise the current power level.Params::power_level - This field indicates the power level value that the receiving node MUST set.:timeout - The time in seconds the node should keep the Power level before resetting to normalPower level.","ref":"Grizzly.ZWave.Commands.PowerlevelReport.html","title":"Grizzly.ZWave.Commands.PowerlevelReport","type":"module"},{"doc":"","ref":"Grizzly.ZWave.Commands.PowerlevelReport.html#t:param/0","title":"Grizzly.ZWave.Commands.PowerlevelReport.param/0","type":"type"},{"doc":"This command is used to set the power level indicator value, which should be used by the node when transmitting RF, and the timeout for this power level indicator value before returning the power level defined by the application.Params::power_level - This field indicates the power level value that the receiving node MUST set.:timeout - The time in seconds the node should keep the Power level before resetting to normalPower level.","ref":"Grizzly.ZWave.Commands.PowerlevelSet.html","title":"Grizzly.ZWave.Commands.PowerlevelSet","type":"module"},{"doc":"","ref":"Grizzly.ZWave.Commands.PowerlevelSet.html#t:param/0","title":"Grizzly.ZWave.Commands.PowerlevelSet.param/0","type":"type"},{"doc":"This command is used to request the result of the latest Powerlevel Test.Params: -none-","ref":"Grizzly.ZWave.Commands.PowerlevelTestNodeGet.html","title":"Grizzly.ZWave.Commands.PowerlevelTestNodeGet","type":"module"},{"doc":"This command is used to report the latest result of a test frame transmission started by the Powerlevel Test Node Set Command.Params::test_node_id - The id of the node that received the test frames.:test_frame_count - The number of test frames transmitted to the test node:status_of_operation The result of the last test","ref":"Grizzly.ZWave.Commands.PowerlevelTestNodeReport.html","title":"Grizzly.ZWave.Commands.PowerlevelTestNodeReport","type":"module"},{"doc":"","ref":"Grizzly.ZWave.Commands.PowerlevelTestNodeReport.html#t:param/0","title":"Grizzly.ZWave.Commands.PowerlevelTestNodeReport.param/0","type":"type"},{"doc":"This command is used to instruct the destination node to transmit a number of test frames to the specified NodeID with the RF power level specified. After the test frame transmissions the RF power level is reset to normal and the result (number of acknowledged test frames) is saved for subsequent read-back. The result of the test may be requested with a Powerlevel Test Node Get Command.Params::test_node_id - The id of the node that should receive the test frames.:power_level - The power level indicator value to use in the test frame transmission.:test_frame_count - The number of test frames to transmit to the test node","ref":"Grizzly.ZWave.Commands.PowerlevelTestNodeSet.html","title":"Grizzly.ZWave.Commands.PowerlevelTestNodeSet","type":"module"},{"doc":"","ref":"Grizzly.ZWave.Commands.PowerlevelTestNodeSet.html#t:param/0","title":"Grizzly.ZWave.Commands.PowerlevelTestNodeSet.param/0","type":"type"},{"doc":"This command is used to query the current network route from a node for a given destination.Params::node_id - the node destination for which the current network route is requested (required)","ref":"Grizzly.ZWave.Commands.PriorityRouteGet.html","title":"Grizzly.ZWave.Commands.PriorityRouteGet","type":"module"},{"doc":"","ref":"Grizzly.ZWave.Commands.PriorityRouteGet.html#t:param/0","title":"Grizzly.ZWave.Commands.PriorityRouteGet.param/0","type":"type"},{"doc":"This command is used to advertise the current network route in use for an actual destination NodeID.Params::node_id - the NodeID destination for which the current network route is requested (required):type - the route type (required):repeaters - node ids of repeaters for the route (required):speed - speed used for the route (required)","ref":"Grizzly.ZWave.Commands.PriorityRouteReport.html","title":"Grizzly.ZWave.Commands.PriorityRouteReport","type":"module"},{"doc":"","ref":"Grizzly.ZWave.Commands.PriorityRouteReport.html#t:param/0","title":"Grizzly.ZWave.Commands.PriorityRouteReport.param/0","type":"type"},{"doc":"This command is used to query the measured RSSI on the Z-Wave network from a node.Params: -none-","ref":"Grizzly.ZWave.Commands.RssiGet.html","title":"Grizzly.ZWave.Commands.RssiGet","type":"module"},{"doc":"This command is used to advertise the measured RSSI on the Z-Wave network for each used channel.Params::channels - Each carries the measured RSSI value for the channel","ref":"Grizzly.ZWave.Commands.RssiReport.html","title":"Grizzly.ZWave.Commands.RssiReport","type":"module"},{"doc":"","ref":"Grizzly.ZWave.Commands.RssiReport.html#t:param/0","title":"Grizzly.ZWave.Commands.RssiReport.param/0","type":"type"},{"doc":"S2 Resynchronization EventThis event is defined in zipgateway, but doesn't seem to be officially documented yet. From zipgateway:SOS_EVENT_REASON_UNANSWERED means that a Nonce Report with Singlecast-out-of-Sync (SOS) = 1 has been received at an unexpected time and no response was sent. A Nonce Report SOS is considered expected and no SOS_EVENT_REASON_UNANSWERED will be emitted in these case: 1) libs2 is in Verify Delivery state and receives a Nonce Report SOS from the node being delivered to and will re-transmit the encrypted message 2) libs2 has already re-transmitted and receives a second SOS from the node being transmitted to during Verify Delivery timeout. A ef S2_send_done_event() with status=TRANSMIT_COMPLETE_NO_ACK will be emitted instead.Params::node_id - which node this message pertains to:reason - 0 = SOS_EVENT_REASON_UNANSWERED in zipgateway","ref":"Grizzly.ZWave.Commands.S2ResynchronizationEvent.html","title":"Grizzly.ZWave.Commands.S2ResynchronizationEvent","type":"module"},{"doc":"What does this command do??Params::scene_id - a scene id (required):dimming_duration - the time that the transition from the current level to the target level (required - ignored if not applicable to target device)","ref":"Grizzly.ZWave.Commands.SceneActivationSet.html","title":"Grizzly.ZWave.Commands.SceneActivationSet","type":"module"},{"doc":"","ref":"Grizzly.ZWave.Commands.SceneActivationSet.html#t:param/0","title":"Grizzly.ZWave.Commands.SceneActivationSet.param/0","type":"type"},{"doc":"This command is used to request the settings for a given scene identifier or for the scene currently active.Params::scene_id - a scene id, 0 for the curretly active scene, if any (required)","ref":"Grizzly.ZWave.Commands.SceneActuatorConfGet.html","title":"Grizzly.ZWave.Commands.SceneActuatorConfGet","type":"module"},{"doc":"","ref":"Grizzly.ZWave.Commands.SceneActuatorConfGet.html#t:param/0","title":"Grizzly.ZWave.Commands.SceneActuatorConfGet.param/0","type":"type"},{"doc":"This command is used to advertise the settings associated to a scene identifier.Params::scene_id - a scene id (required):dimming_duration - the time it must take to reach the target level associated to the actual Scene ID (required - ignored if not supported) :instantly | [seconds: 1..127] | [minutes: 1..126] | :factory_settings:level - the target level to be set if override is true (required)","ref":"Grizzly.ZWave.Commands.SceneActuatorConfReport.html","title":"Grizzly.ZWave.Commands.SceneActuatorConfReport","type":"module"},{"doc":"","ref":"Grizzly.ZWave.Commands.SceneActuatorConfReport.html#t:param/0","title":"Grizzly.ZWave.Commands.SceneActuatorConfReport.param/0","type":"type"},{"doc":"This command is used to associate the specified scene ID to the defined actuator settings.Params::scene_id - a scene id (required):dimming_duration - the time it must take to reach the target level associated to the actual Scene ID (required - ignored if not supported) :instantly | [seconds: 1..127] | [minutes: 1..126] | :factory_settings:override - If false, the current actuator settings must be used as settings for the actual Scene ID (required):level - the target level to be set if override is true (required)","ref":"Grizzly.ZWave.Commands.SceneActuatorConfSet.html","title":"Grizzly.ZWave.Commands.SceneActuatorConfSet","type":"module"},{"doc":"","ref":"Grizzly.ZWave.Commands.SceneActuatorConfSet.html#t:param/0","title":"Grizzly.ZWave.Commands.SceneActuatorConfSet.param/0","type":"type"},{"doc":"What does this command do??Params:sensor_type - the type of sensor (required) one of :general_purpose | :smoke | :co | :co2 | :heat | :water | :freeze | :tamper | :aux | :door_window | :tilt | :motion | :glass_break","ref":"Grizzly.ZWave.Commands.SensorBinaryGet.html","title":"Grizzly.ZWave.Commands.SensorBinaryGet","type":"module"},{"doc":"","ref":"Grizzly.ZWave.Commands.SensorBinaryGet.html#t:param/0","title":"Grizzly.ZWave.Commands.SensorBinaryGet.param/0","type":"type"},{"doc":"This command is used to advertise whether a binary sensor was triggered.Params::triggered - whether the sensor is triggered (required):sensor_type - the type of sensor (optional)","ref":"Grizzly.ZWave.Commands.SensorBinaryReport.html","title":"Grizzly.ZWave.Commands.SensorBinaryReport","type":"module"},{"doc":"","ref":"Grizzly.ZWave.Commands.SensorBinaryReport.html#t:param/0","title":"Grizzly.ZWave.Commands.SensorBinaryReport.param/0","type":"type"},{"doc":"This module implements command SENSOR_MULTILEVEL_GET of command class COMMAND_CLASS_SENSOR_MULTILEVEL. The command is used to request the current reading from a multilevel sensor.Params: * :sensor_type - one of :temperature or :illuminance or :power or :humidity etc.(v5) * `:scale` - ` 0..3 - identifies a unit of measurement` (v5)","ref":"Grizzly.ZWave.Commands.SensorMultilevelGet.html","title":"Grizzly.ZWave.Commands.SensorMultilevelGet","type":"module"},{"doc":"","ref":"Grizzly.ZWave.Commands.SensorMultilevelGet.html#t:param/0","title":"Grizzly.ZWave.Commands.SensorMultilevelGet.param/0","type":"type"},{"doc":"","ref":"Grizzly.ZWave.Commands.SensorMultilevelGet.html#t:sensor_type/0","title":"Grizzly.ZWave.Commands.SensorMultilevelGet.sensor_type/0","type":"type"},{"doc":"This module implements command COMMAND_CLASS_SENSOR_MULTILEVEL implements the SENSOR_MULTILEVEL_REPORT command class.This command is used to advertise a multilevel sensor reading.Params::sensor_type - one of :temperature, :illuminance, :power, or :humidity etc.(required):scale - 0..3 - identifies a unit of measurement (required):value - the sensed, numerical value (required)","ref":"Grizzly.ZWave.Commands.SensorMultilevelReport.html","title":"Grizzly.ZWave.Commands.SensorMultilevelReport","type":"module"},{"doc":"","ref":"Grizzly.ZWave.Commands.SensorMultilevelReport.html#t:param/0","title":"Grizzly.ZWave.Commands.SensorMultilevelReport.param/0","type":"type"},{"doc":"","ref":"Grizzly.ZWave.Commands.SensorMultilevelReport.html#t:sensor_type/0","title":"Grizzly.ZWave.Commands.SensorMultilevelReport.sensor_type/0","type":"type"},{"doc":"This module implements command SENSOR_MULTILEVEL_SUPPORTED_GET_SENSOR of command class COMMAND_CLASS_SENSOR_MULTILEVEL The command requests the list of supported sensor types.Params: - none -","ref":"Grizzly.ZWave.Commands.SensorMultilevelSupportedSensorGet.html","title":"Grizzly.ZWave.Commands.SensorMultilevelSupportedSensorGet","type":"module"},{"doc":"This module implements command SENSOR_MULTILEVEL_SUPPORTED_SENSOR_REPORT of the COMMAND_CLASS_SENSOR_MULTILEVEL command class. This command is used to advertise the supported Sensor Types by a supporting node.Params::sensor_types - list of :temperature or :illuminance or :power or :humidity etc. (required)","ref":"Grizzly.ZWave.Commands.SensorMultilevelSupportedSensorReport.html","title":"Grizzly.ZWave.Commands.SensorMultilevelSupportedSensorReport","type":"module"},{"doc":"","ref":"Grizzly.ZWave.Commands.SensorMultilevelSupportedSensorReport.html#t:param/0","title":"Grizzly.ZWave.Commands.SensorMultilevelSupportedSensorReport.param/0","type":"type"},{"doc":"","ref":"Grizzly.ZWave.Commands.SensorMultilevelSupportedSensorReport.html#t:sensor_type/0","title":"Grizzly.ZWave.Commands.SensorMultilevelSupportedSensorReport.sensor_type/0","type":"type"},{"doc":"This command is sent to the unsolicited destinations when a Smart Start inclusion starts.The Add Node Status Command MUST be issued after the Smart Start inclusion and S2 bootstrapping attempts took place.Params: :seq_number - the sequence number for the networked command (required):dsk - a DSK string for the device see Grizzly.ZWave.DSK for more more information (required)","ref":"Grizzly.ZWave.Commands.SmartStartJoinStarted.html","title":"Grizzly.ZWave.Commands.SmartStartJoinStarted","type":"module"},{"doc":"","ref":"Grizzly.ZWave.Commands.SmartStartJoinStarted.html#t:param/0","title":"Grizzly.ZWave.Commands.SmartStartJoinStarted.param/0","type":"type"},{"doc":"This command is used to clear all statistic registers maintained by the node.Params: -none-","ref":"Grizzly.ZWave.Commands.StatisticsClear.html","title":"Grizzly.ZWave.Commands.StatisticsClear","type":"module"},{"doc":"This command is used to query Installation and Maintenance statistics from a node.Params::node_id - the node destination for which the current network route is requested (required)","ref":"Grizzly.ZWave.Commands.StatisticsGet.html","title":"Grizzly.ZWave.Commands.StatisticsGet","type":"module"},{"doc":"","ref":"Grizzly.ZWave.Commands.StatisticsGet.html#t:param/0","title":"Grizzly.ZWave.Commands.StatisticsGet.param/0","type":"type"},{"doc":"This command is used to query Installation and Maintenance statistics from a node.Params::node_id - the NodeID for which statistics are requested:statistics - statistics collected about the node","ref":"Grizzly.ZWave.Commands.StatisticsReport.html","title":"Grizzly.ZWave.Commands.StatisticsReport","type":"module"},{"doc":"","ref":"Grizzly.ZWave.Commands.StatisticsReport.html#t:param/0","title":"Grizzly.ZWave.Commands.StatisticsReport.param/0","type":"type"},{"doc":"This command is used to initiate the execution of a command and to request the immediate and future status of the process being initiated.Params::status_updates - used to allow a receiving node to advertise application status updates in future Supervision Report Commands (required):session_id - used to detect redundant invocations due to retransmissions (required):encapsulated_command - an encapsulated command (required) -see ZWave Transport Encapsulation Command Class Specifications","ref":"Grizzly.ZWave.Commands.SupervisionGet.html","title":"Grizzly.ZWave.Commands.SupervisionGet","type":"module"},{"doc":"","ref":"Grizzly.ZWave.Commands.SupervisionGet.html#t:param/0","title":"Grizzly.ZWave.Commands.SupervisionGet.param/0","type":"type"},{"doc":"","ref":"Grizzly.ZWave.Commands.SupervisionGet.html#t:status_updates/0","title":"Grizzly.ZWave.Commands.SupervisionGet.status_updates/0","type":"type"},{"doc":"This command is used to advertise the status of one or more command process(es).Params::more_status_updates - used to advertise if more Supervision Reports follow for the actual Session ID (required):session_id - carries the same value as the Session ID field of the Supervision Get Command which initiated this session (required):status - the current status of the command process, one of :no_support, :working, :fail or :success (required):duration - the time in seconds needed to complete the current operation (required)","ref":"Grizzly.ZWave.Commands.SupervisionReport.html","title":"Grizzly.ZWave.Commands.SupervisionReport","type":"module"},{"doc":"","ref":"Grizzly.ZWave.Commands.SupervisionReport.html#t:more_status_updates/0","title":"Grizzly.ZWave.Commands.SupervisionReport.more_status_updates/0","type":"type"},{"doc":"","ref":"Grizzly.ZWave.Commands.SupervisionReport.html#t:param/0","title":"Grizzly.ZWave.Commands.SupervisionReport.param/0","type":"type"},{"doc":"","ref":"Grizzly.ZWave.Commands.SupervisionReport.html#t:status/0","title":"Grizzly.ZWave.Commands.SupervisionReport.status/0","type":"type"},{"doc":"Get the command value of a binary switchParams: -none-","ref":"Grizzly.ZWave.Commands.SwitchBinaryGet.html","title":"Grizzly.ZWave.Commands.SwitchBinaryGet","type":"module"},{"doc":"Module for the SWITCH_BINARY_REPORT commandParams::target_value - :on, :off, or :unknown (required):duration - 0-255 (required V2):current_value - :on, :off, or :unknown (required V2)","ref":"Grizzly.ZWave.Commands.SwitchBinaryReport.html","title":"Grizzly.ZWave.Commands.SwitchBinaryReport","type":"module"},{"doc":"","ref":"Grizzly.ZWave.Commands.SwitchBinaryReport.html#encode_target_value/1","title":"Grizzly.ZWave.Commands.SwitchBinaryReport.encode_target_value/1","type":"function"},{"doc":"","ref":"Grizzly.ZWave.Commands.SwitchBinaryReport.html#t:param/0","title":"Grizzly.ZWave.Commands.SwitchBinaryReport.param/0","type":"type"},{"doc":"","ref":"Grizzly.ZWave.Commands.SwitchBinaryReport.html#t:value/0","title":"Grizzly.ZWave.Commands.SwitchBinaryReport.value/0","type":"type"},{"doc":"Module for the SWITCH_BINARY_SET commandParams::target_value - :on or :off(required):duration - 0-255 (optional v2)","ref":"Grizzly.ZWave.Commands.SwitchBinarySet.html","title":"Grizzly.ZWave.Commands.SwitchBinarySet","type":"module"},{"doc":"","ref":"Grizzly.ZWave.Commands.SwitchBinarySet.html#encode_target_value/1","title":"Grizzly.ZWave.Commands.SwitchBinarySet.encode_target_value/1","type":"function"},{"doc":"","ref":"Grizzly.ZWave.Commands.SwitchBinarySet.html#t:param/0","title":"Grizzly.ZWave.Commands.SwitchBinarySet.param/0","type":"type"},{"doc":"Module for the SWITCH_MULTILEVEL_GETParams: - none -","ref":"Grizzly.ZWave.Commands.SwitchMultilevelGet.html","title":"Grizzly.ZWave.Commands.SwitchMultilevelGet","type":"module"},{"doc":"Module for the SWITCH_MULTILEVEL_REPORTParams::value - ':off or a value betweem 1 and 100:duration - How long the switch should take to reach target value, 0 -&gt; instantly, 1..127 -&gt; seconds, 128..253 -&gt; minutes, 255 -&gt; unknown (optional v2)","ref":"Grizzly.ZWave.Commands.SwitchMultilevelReport.html","title":"Grizzly.ZWave.Commands.SwitchMultilevelReport","type":"module"},{"doc":"","ref":"Grizzly.ZWave.Commands.SwitchMultilevelReport.html#encode_value/1","title":"Grizzly.ZWave.Commands.SwitchMultilevelReport.encode_value/1","type":"function"},{"doc":"","ref":"Grizzly.ZWave.Commands.SwitchMultilevelReport.html#t:param/0","title":"Grizzly.ZWave.Commands.SwitchMultilevelReport.param/0","type":"type"},{"doc":"Module for the SWITCH_MULTILEVEL_SETParams::target_value - ':off, :previous or a value betweem 1 and 99:duration - How long the switch should take to reach target value, 0 -&gt; instantly, 1..127 -&gt; seconds, 128..254 -&gt; minutes, 256 -&gt; factory default (option v2)","ref":"Grizzly.ZWave.Commands.SwitchMultilevelSet.html","title":"Grizzly.ZWave.Commands.SwitchMultilevelSet","type":"module"},{"doc":"","ref":"Grizzly.ZWave.Commands.SwitchMultilevelSet.html#encode_target_value/1","title":"Grizzly.ZWave.Commands.SwitchMultilevelSet.encode_target_value/1","type":"function"},{"doc":"","ref":"Grizzly.ZWave.Commands.SwitchMultilevelSet.html#t:param/0","title":"Grizzly.ZWave.Commands.SwitchMultilevelSet.param/0","type":"type"},{"doc":"Module for the SWITCH_MULTILEVEL_START_LEVEL_CHANGEParams::up_down - initiating change of level :up or :down:duration - seconds to take to go from 0 to 99, or 99 to 0 - optional v2 Note that support for secodary switch introduced in v3 is deprecated and ignored here. A controller SHOULD ignore Start Level; it is always ignored here.","ref":"Grizzly.ZWave.Commands.SwitchMultilevelStartLevelChange.html","title":"Grizzly.ZWave.Commands.SwitchMultilevelStartLevelChange","type":"module"},{"doc":"","ref":"Grizzly.ZWave.Commands.SwitchMultilevelStartLevelChange.html#decode_up_down/1","title":"Grizzly.ZWave.Commands.SwitchMultilevelStartLevelChange.decode_up_down/1","type":"function"},{"doc":"","ref":"Grizzly.ZWave.Commands.SwitchMultilevelStartLevelChange.html#encode_up_down/1","title":"Grizzly.ZWave.Commands.SwitchMultilevelStartLevelChange.encode_up_down/1","type":"function"},{"doc":"","ref":"Grizzly.ZWave.Commands.SwitchMultilevelStartLevelChange.html#t:param/0","title":"Grizzly.ZWave.Commands.SwitchMultilevelStartLevelChange.param/0","type":"type"},{"doc":"Module for the SWITCH_MULTILEVEL_STOP_LEVEL_CHANGEParams: -none-","ref":"Grizzly.ZWave.Commands.SwitchMultilevelStopLevelChange.html","title":"Grizzly.ZWave.Commands.SwitchMultilevelStopLevelChange","type":"module"},{"doc":"This module implements command THERMOSTAT_FAN_MODE_GET of the COMMAND_CLASS_THERMOSTAT_FAN_MODE command classThis command is used to request the fan mode.Params: -none-","ref":"Grizzly.ZWave.Commands.ThermostatFanModeGet.html","title":"Grizzly.ZWave.Commands.ThermostatFanModeGet","type":"module"},{"doc":"This module implement command THERMOSTAT_FAN_MODE_REPORT of the COMMAND_CLASS_THERMOSTAT_FAN_MODE command classThis command is used to report the fan mode.Params::mode - one of :auto_low | :low | :auto_high | :high (required)","ref":"Grizzly.ZWave.Commands.ThermostatFanModeReport.html","title":"Grizzly.ZWave.Commands.ThermostatFanModeReport","type":"module"},{"doc":"","ref":"Grizzly.ZWave.Commands.ThermostatFanModeReport.html#t:param/0","title":"Grizzly.ZWave.Commands.ThermostatFanModeReport.param/0","type":"type"},{"doc":"This module implement command THERMOSTAT_FAN_MODE_SET of the COMMAND_CLASS_THERMOSTAT_FAN_MODE command classThis command is used to set the fan mode.Params::mode - one of :auto_low | :low | :auto_high | :high (required)","ref":"Grizzly.ZWave.Commands.ThermostatFanModeSet.html","title":"Grizzly.ZWave.Commands.ThermostatFanModeSet","type":"module"},{"doc":"","ref":"Grizzly.ZWave.Commands.ThermostatFanModeSet.html#t:param/0","title":"Grizzly.ZWave.Commands.ThermostatFanModeSet.param/0","type":"type"},{"doc":"This module implement command THERMOSTAT_FAN_STATE_GET of the COMMAND_CLASS_THERMOSTAT_FAN_STATE command classThis command is used to request the fan operating state.Params: -none-","ref":"Grizzly.ZWave.Commands.ThermostatFanStateGet.html","title":"Grizzly.ZWave.Commands.ThermostatFanStateGet","type":"module"},{"doc":"This module implements command THERMOSTAT_FAN_STATE_REPORT of the COMMAND_CLASS_THERMOSTAT_FAN_STATE command class. This command is used to report the fan operating state of the thermostat device.Params::state - the state of the fan (required)","ref":"Grizzly.ZWave.Commands.ThermostatFanStateReport.html","title":"Grizzly.ZWave.Commands.ThermostatFanStateReport","type":"module"},{"doc":"","ref":"Grizzly.ZWave.Commands.ThermostatFanStateReport.html#t:param/0","title":"Grizzly.ZWave.Commands.ThermostatFanStateReport.param/0","type":"type"},{"doc":"This module implements command THERMOSTAT_MODE_GET of the command class COMMAND_CLASS_THERMOSTAT_MODE.The command is used to request the current mode set at the receiving node.Params: - none -","ref":"Grizzly.ZWave.Commands.ThermostatModeGet.html","title":"Grizzly.ZWave.Commands.ThermostatModeGet","type":"module"},{"doc":"This module implements command THERMOSTAT_MODE_REPORT of the COMMAND_CLASS_THERMOSTAT_MODE command class.This command is used to report the mode from the thermostat device.Params::mode - the mode of the thermostat, see ThermostatMode (required)","ref":"Grizzly.ZWave.Commands.ThermostatModeReport.html","title":"Grizzly.ZWave.Commands.ThermostatModeReport","type":"module"},{"doc":"","ref":"Grizzly.ZWave.Commands.ThermostatModeReport.html#t:param/0","title":"Grizzly.ZWave.Commands.ThermostatModeReport.param/0","type":"type"},{"doc":"This module implements command THERMOSTAT_MODE_SET of the COMMAND_CLASS_THERMOSTAT_MODE command class.This command is used to set the mode from the thermostat device.Params::mode - the mode of the thermostat, see ThermostatMode (required)","ref":"Grizzly.ZWave.Commands.ThermostatModeSet.html","title":"Grizzly.ZWave.Commands.ThermostatModeSet","type":"module"},{"doc":"","ref":"Grizzly.ZWave.Commands.ThermostatModeSet.html#t:param/0","title":"Grizzly.ZWave.Commands.ThermostatModeSet.param/0","type":"type"},{"doc":"This module implement command THERMOSTAT_OPERATING_STATE_GET of the COMMAND_CLASS_THERMOSTAT_OPERATING_STATE command classThis command gets the operating state of the thermostat.Params: -none-","ref":"Grizzly.ZWave.Commands.ThermostatOperatingStateGet.html","title":"Grizzly.ZWave.Commands.ThermostatOperatingStateGet","type":"module"},{"doc":"This module implement command THERMOSTAT_OPERATING_STATE_REPORT (v1) of the COMMAND_CLASS_THERMOSTAT_OPERATING_STATE command classThis command report the operating state of the thermostat.Params::state - the operating state (required)","ref":"Grizzly.ZWave.Commands.ThermostatOperatingStateReport.html","title":"Grizzly.ZWave.Commands.ThermostatOperatingStateReport","type":"module"},{"doc":"","ref":"Grizzly.ZWave.Commands.ThermostatOperatingStateReport.html#t:param/0","title":"Grizzly.ZWave.Commands.ThermostatOperatingStateReport.param/0","type":"type"},{"doc":"This module implements command THERMOSTAT_SETBACK_GET of the command class COMMAND_CLASS_THERMOSTAT_SETBACK.This command is used to request the current setback state of the thermostat.Params: - none -","ref":"Grizzly.ZWave.Commands.ThermostatSetbackGet.html","title":"Grizzly.ZWave.Commands.ThermostatSetbackGet","type":"module"},{"doc":"This module implements command THERMOSTAT_SETBACK_REPORT of the COMMAND_CLASS_THERMOSTAT_SETBACK command class. This command is used to report the setback state of the thermostat.Params::type - the setback type (required):state - the setback state (required)","ref":"Grizzly.ZWave.Commands.ThermostatSetbackReport.html","title":"Grizzly.ZWave.Commands.ThermostatSetbackReport","type":"module"},{"doc":"","ref":"Grizzly.ZWave.Commands.ThermostatSetbackReport.html#t:param/0","title":"Grizzly.ZWave.Commands.ThermostatSetbackReport.param/0","type":"type"},{"doc":"This module implements command THERMOSTAT_SETBACK_SET of the COMMAND_CLASS_THERMOSTAT_SETBACK command class. This command is used to set the setback state of the thermostat.Params::type - the type the setback (required):state - the setback state (required)","ref":"Grizzly.ZWave.Commands.ThermostatSetbackSet.html","title":"Grizzly.ZWave.Commands.ThermostatSetbackSet","type":"module"},{"doc":"","ref":"Grizzly.ZWave.Commands.ThermostatSetbackSet.html#t:param/0","title":"Grizzly.ZWave.Commands.ThermostatSetbackSet.param/0","type":"type"},{"doc":"This module implements command THERMOSTAT_SETPOINT_GET of the COMMAND_CLASS_THERMOSTAT_SETPOINT command class.This command is used to request the target value for a given setpoint type.Params::type - the setback type (required)","ref":"Grizzly.ZWave.Commands.ThermostatSetpointGet.html","title":"Grizzly.ZWave.Commands.ThermostatSetpointGet","type":"module"},{"doc":"","ref":"Grizzly.ZWave.Commands.ThermostatSetpointGet.html#t:param/0","title":"Grizzly.ZWave.Commands.ThermostatSetpointGet.param/0","type":"type"},{"doc":"This module implements command THERMOSTAT_SETPOINT_REPORT of the COMMAND_CLASS_THERMOSTAT_SETPOINT command class.This command is used to advertise the target value for a given setpoint type.Params::type - the setpoint type (required):scale - the setpoint scale (required):value - the value of the setpoint (required)","ref":"Grizzly.ZWave.Commands.ThermostatSetpointReport.html","title":"Grizzly.ZWave.Commands.ThermostatSetpointReport","type":"module"},{"doc":"","ref":"Grizzly.ZWave.Commands.ThermostatSetpointReport.html#t:param/0","title":"Grizzly.ZWave.Commands.ThermostatSetpointReport.param/0","type":"type"},{"doc":"This module implements command THERMOSTAT_SETPOINT_SET of the COMMAND_CLASS_THERMOSTAT_SETPOINT command class.This command is used to set the target value for a given setpoint type.Params::type - the setpoint type (required):scale - the setpoint scale (required):value - the value of the setpoint (required)","ref":"Grizzly.ZWave.Commands.ThermostatSetpointSet.html","title":"Grizzly.ZWave.Commands.ThermostatSetpointSet","type":"module"},{"doc":"","ref":"Grizzly.ZWave.Commands.ThermostatSetpointSet.html#t:param/0","title":"Grizzly.ZWave.Commands.ThermostatSetpointSet.param/0","type":"type"},{"doc":"This command is used to request the current time from a supporting node.Params: - none -","ref":"Grizzly.ZWave.Commands.TimeGet.html","title":"Grizzly.ZWave.Commands.TimeGet","type":"module"},{"doc":"This command is used to request the Time Zone Offset (TZO) and Daylight Savings Time (DST) parameters from a supporting node.Params: - none -","ref":"Grizzly.ZWave.Commands.TimeOffsetGet.html","title":"Grizzly.ZWave.Commands.TimeOffsetGet","type":"module"},{"doc":"This command is used to advertise the Time Zone Offset (TZO) and Daylight Savings Time (DST) parameters.Params::sign_tzo - This field is used to indicate the sign (:plus or :minus) to apply to the Hour TZO and Minute TZO fields. (required):hour_tzo - This field is used to indicate the number of hours that the originating time zone deviates from UTC. (required - 0..14):minute_tzo - This field is used to indicate the number of minutes that the originating time zone deviates from UTC. (required - 0..59):sign_offset_dst - This field is used to indicate the sign (:plus or :minus) for the Minute Offset DST field to apply to the current time while in the Daylight Saving Time. (required):minute_offset_dst - This field MUST indicate the number of minutes by which the current time is to be adjusted when Daylight Saving Time starts. (required - 0..59):month_start_dst - This field MUST indicate the month of the year when Daylight Saving Time starts. (required, 1..12):day_start_dst - This field MUST indicate the day of the month when Daylight Saving Time starts. (required - 1..31):hour_start_dst - This field MUST indicate the hour of the day when Daylight Saving Time starts. (required - 0..23):month_end_dst - This field MUST indicate the month of the year when Daylight Saving Time ends. (required, 1..12):day_end_dst - This field MUST indicate the day of the month when Daylight Saving Time ends. (required - 1..31):hour_end_dst - This field MUST indicate the hour of the day when Daylight Saving Time ends. (required - 0..23)","ref":"Grizzly.ZWave.Commands.TimeOffsetReport.html","title":"Grizzly.ZWave.Commands.TimeOffsetReport","type":"module"},{"doc":"","ref":"Grizzly.ZWave.Commands.TimeOffsetReport.html#t:param/0","title":"Grizzly.ZWave.Commands.TimeOffsetReport.param/0","type":"type"},{"doc":"","ref":"Grizzly.ZWave.Commands.TimeOffsetReport.html#t:sign/0","title":"Grizzly.ZWave.Commands.TimeOffsetReport.sign/0","type":"type"},{"doc":"This command is used to set Time Zone Offset (TZO) and Daylight Savings Time (DST) at the supporting node.Params::sign_tzo - This field is used to indicate the sign (:plus or :minus) to apply to the Hour TZO and Minute TZO fields. (required):hour_tzo - This field is used to indicate the number of hours that the originating time zone deviates from UTC. (required - 0..14):minute_tzo - This field is used to indicate the number of minutes that the originating time zone deviates from UTC. (required - 0..59):sign_offset_dst - This field is used to indicate the sign (:plus or :minus) for the Minute Offset DST field to apply to the current time while in the Daylight Saving Time. (required):minute_offset_dst - This field MUST indicate the number of minutes by which the current time is to be adjusted when Daylight Saving Time starts. (required - 0..59):month_start_dst - This field MUST indicate the month of the year when Daylight Saving Time starts. (required, 1..12):day_start_dst - This field MUST indicate the day of the month when Daylight Saving Time starts. (required - 1..31):hour_start_dst - This field MUST indicate the hour of the day when Daylight Saving Time starts. (required - 0..23):month_end_dst - This field MUST indicate the month of the year when Daylight Saving Time ends. (required, 1..12):day_end_dst - This field MUST indicate the day of the month when Daylight Saving Time ends. (required - 1..31):hour_end_dst - This field MUST indicate the hour of the day when Daylight Saving Time ends. (required - 0..23)","ref":"Grizzly.ZWave.Commands.TimeOffsetSet.html","title":"Grizzly.ZWave.Commands.TimeOffsetSet","type":"module"},{"doc":"","ref":"Grizzly.ZWave.Commands.TimeOffsetSet.html#t:param/0","title":"Grizzly.ZWave.Commands.TimeOffsetSet.param/0","type":"type"},{"doc":"This command is used to request date and time parameters.Params:- none -","ref":"Grizzly.ZWave.Commands.TimeParametersGet.html","title":"Grizzly.ZWave.Commands.TimeParametersGet","type":"module"},{"doc":"This command is used to advertise date and time.Params::year - the year (required):month - the month (required - 1..12):day - the day (required - 1..31):hour_utc - the hour in UTC time (required - 0..23):minute_utc - the minute in UTC time (required - 0..59):second_utc - the second in UTC time (required - 0..59)","ref":"Grizzly.ZWave.Commands.TimeParametersReport.html","title":"Grizzly.ZWave.Commands.TimeParametersReport","type":"module"},{"doc":"","ref":"Grizzly.ZWave.Commands.TimeParametersReport.html#t:param/0","title":"Grizzly.ZWave.Commands.TimeParametersReport.param/0","type":"type"},{"doc":"This command is used to set current date and time in Universal Time (UTC).Params::year - the year (required):month - the month (required - 1..12):day - the day (required - 1..31):hour_utc - the hour in UTC time (required - 0..23):minute_utc - the minute in UTC time (required - 0..59):second_utc - the second in UTC time (required - 0..59)","ref":"Grizzly.ZWave.Commands.TimeParametersSet.html","title":"Grizzly.ZWave.Commands.TimeParametersSet","type":"module"},{"doc":"","ref":"Grizzly.ZWave.Commands.TimeParametersSet.html#t:param/0","title":"Grizzly.ZWave.Commands.TimeParametersSet.param/0","type":"type"},{"doc":"This command is used to report the current time.Params::rtc_failure? - Many RTC chips have a stop bit indicating if the oscillator has been stopped. The RTC failure bit MUST be set to 1 in order to indicate to the receiving node that the RTC has been stopped and that the advertised time might be inaccurate. (optional - defaults to false):hour - the hour (required):minute - the minute (required):second - the second of the setpoint (required)","ref":"Grizzly.ZWave.Commands.TimeReport.html","title":"Grizzly.ZWave.Commands.TimeReport","type":"module"},{"doc":"","ref":"Grizzly.ZWave.Commands.TimeReport.html#t:param/0","title":"Grizzly.ZWave.Commands.TimeReport.param/0","type":"type"},{"doc":"This module implements command USER_CODE_GET of the COMMAND_CLASS_USER_CODE command class.This command is used to request the User Code of a specific User Identifier.Params:user_id - the user identifier, an integer between 1 and 255 (required)","ref":"Grizzly.ZWave.Commands.UserCodeGet.html","title":"Grizzly.ZWave.Commands.UserCodeGet","type":"module"},{"doc":"","ref":"Grizzly.ZWave.Commands.UserCodeGet.html#t:param/0","title":"Grizzly.ZWave.Commands.UserCodeGet.param/0","type":"type"},{"doc":"UserCodeReport reports on a user codeParams::user_id - the id of the user code (required):user_id_status - the status if the user id slot (required):user_code - a 4 - 10 user code pin in string format (required)","ref":"Grizzly.ZWave.Commands.UserCodeReport.html","title":"Grizzly.ZWave.Commands.UserCodeReport","type":"module"},{"doc":"","ref":"Grizzly.ZWave.Commands.UserCodeReport.html#t:param/0","title":"Grizzly.ZWave.Commands.UserCodeReport.param/0","type":"type"},{"doc":"","ref":"Grizzly.ZWave.Commands.UserCodeReport.html#t:user_id_status/0","title":"Grizzly.ZWave.Commands.UserCodeReport.user_id_status/0","type":"type"},{"doc":"UserCodeSet sets the user codeParams::user_id - the id of the user code (required):user_id_status - the status if the user id slot (required):user_code - a 4 - 10 user code pin in string format (required)","ref":"Grizzly.ZWave.Commands.UserCodeSet.html","title":"Grizzly.ZWave.Commands.UserCodeSet","type":"module"},{"doc":"","ref":"Grizzly.ZWave.Commands.UserCodeSet.html#t:param/0","title":"Grizzly.ZWave.Commands.UserCodeSet.param/0","type":"type"},{"doc":"This module implements the command USERS_NUMBER_GET from the COMMAND_CLASS_USER_CODE command class.This command is used to request the number of user codes supportedParams: -none-","ref":"Grizzly.ZWave.Commands.UserCodeUsersNumberGet.html","title":"Grizzly.ZWave.Commands.UserCodeUsersNumberGet","type":"module"},{"doc":"Gets the number of supported user codesParams:supported_users - the number of supported users (required)extended_supported_users - if different, the total amount of supported users (required - v2 and above)","ref":"Grizzly.ZWave.Commands.UserCodeUsersNumberReport.html","title":"Grizzly.ZWave.Commands.UserCodeUsersNumberReport","type":"module"},{"doc":"","ref":"Grizzly.ZWave.Commands.UserCodeUsersNumberReport.html#t:param/0","title":"Grizzly.ZWave.Commands.UserCodeUsersNumberReport.param/0","type":"type"},{"doc":"This module implements command VERSION_COMMAND_CLASS_GET of command class COMMAND_CLASS_VERSIONParams::command_class - the atom name of a command class (required)","ref":"Grizzly.ZWave.Commands.VersionCommandClassGet.html","title":"Grizzly.ZWave.Commands.VersionCommandClassGet","type":"module"},{"doc":"","ref":"Grizzly.ZWave.Commands.VersionCommandClassGet.html#t:param/0","title":"Grizzly.ZWave.Commands.VersionCommandClassGet.param/0","type":"type"},{"doc":"Reports the command class version for a deviceParams::command_class - the name of the command class the report is for (required):version - the version of the command class in the report (required)","ref":"Grizzly.ZWave.Commands.VersionCommandClassReport.html","title":"Grizzly.ZWave.Commands.VersionCommandClassReport","type":"module"},{"doc":"","ref":"Grizzly.ZWave.Commands.VersionCommandClassReport.html#t:param/0","title":"Grizzly.ZWave.Commands.VersionCommandClassReport.param/0","type":"type"},{"doc":"This module implements command VERSION_GET of command class COMMAND_CLASS_VERSIONParams: - none -","ref":"Grizzly.ZWave.Commands.VersionGet.html","title":"Grizzly.ZWave.Commands.VersionGet","type":"module"},{"doc":"This module implements command VERSION_REPORT of command class COMMAND_CLASS_VERSIONParams::library_type - The type of Z-Wave device library is running (required):protocol_version - The &quot;version.sub&quot; of the implemented Z-Wave protocol (required):firmware_version - The &quot;version.sub&quot; of the firmware (required):hardware_version - the hardware version - (optional V1, required V2 and above):other_firmware_versions - The list of &quot;version.sub&quot; of the other firmware targets (optional V1, required V2 and above)","ref":"Grizzly.ZWave.Commands.VersionReport.html","title":"Grizzly.ZWave.Commands.VersionReport","type":"module"},{"doc":"","ref":"Grizzly.ZWave.Commands.VersionReport.html#t:firmware_version/0","title":"Grizzly.ZWave.Commands.VersionReport.firmware_version/0","type":"type"},{"doc":"","ref":"Grizzly.ZWave.Commands.VersionReport.html#t:library_type/0","title":"Grizzly.ZWave.Commands.VersionReport.library_type/0","type":"type"},{"doc":"","ref":"Grizzly.ZWave.Commands.VersionReport.html#t:param/0","title":"Grizzly.ZWave.Commands.VersionReport.param/0","type":"type"},{"doc":"","ref":"Grizzly.ZWave.Commands.VersionReport.html#t:protocol_version/0","title":"Grizzly.ZWave.Commands.VersionReport.protocol_version/0","type":"type"},{"doc":"This module implements the WAKE_UP_INTERVAL_CAPABILITIES_GET command of the COMMAND_CLASS_WAKE_UP command class.Params: -none-","ref":"Grizzly.ZWave.Commands.WakeUpIntervalCapabilitiesGet.html","title":"Grizzly.ZWave.Commands.WakeUpIntervalCapabilitiesGet","type":"module"},{"doc":"This module implements the WAKE_UP_INTERVAL_CAPABILITIES_REPORT command of the COMMAND_CLASS_WAKE_UP command class.Params::minimum_seconds - the minimum Wake Up Interval supported by the sending node - v2:maximum_seconds - the maximum Wake Up Interval supported by the sending node - v2:default_seconds - the default Wake Up Interval value for the sending node. - v2:step_seconds - the resolution of valid Wake Up Intervals values for the sending node - v2:on_demand - whether the supporting node supports the Wake Up On Demand functionality - v3","ref":"Grizzly.ZWave.Commands.WakeUpIntervalCapabilitiesReport.html","title":"Grizzly.ZWave.Commands.WakeUpIntervalCapabilitiesReport","type":"module"},{"doc":"","ref":"Grizzly.ZWave.Commands.WakeUpIntervalCapabilitiesReport.html#t:param/0","title":"Grizzly.ZWave.Commands.WakeUpIntervalCapabilitiesReport.param/0","type":"type"},{"doc":"This module implements the WAKE_UP_INTERVAL_GET command of the COMMAND_CLASS_WAKE_UP command classParams: - none -","ref":"Grizzly.ZWave.Commands.WakeUpIntervalGet.html","title":"Grizzly.ZWave.Commands.WakeUpIntervalGet","type":"module"},{"doc":"This module implements the WAKE_UP_INTERVAL_REPORT command of the COMMAND_CLASS_WAKE_UP command class.Params::seconds - the time in seconds between Wake Up periods at the sending node (required):node_id - the Wake Up destination NodeID configured at the sending node (required)","ref":"Grizzly.ZWave.Commands.WakeUpIntervalReport.html","title":"Grizzly.ZWave.Commands.WakeUpIntervalReport","type":"module"},{"doc":"","ref":"Grizzly.ZWave.Commands.WakeUpIntervalReport.html#t:param/0","title":"Grizzly.ZWave.Commands.WakeUpIntervalReport.param/0","type":"type"},{"doc":"This module implements the WAKE_UP_INTERVAL_SET command of the COMMAND_CLASS_WAKE_UP command class.Params::seconds - the time in seconds between Wake Up periods at the sending node (required):node_id - the Wake Up destination NodeID configured at the sending node (required)","ref":"Grizzly.ZWave.Commands.WakeUpIntervalSet.html","title":"Grizzly.ZWave.Commands.WakeUpIntervalSet","type":"module"},{"doc":"","ref":"Grizzly.ZWave.Commands.WakeUpIntervalSet.html#t:param/0","title":"Grizzly.ZWave.Commands.WakeUpIntervalSet.param/0","type":"type"},{"doc":"This module implements the WAKE_UP_NO_MORE_INFORMATION command of the COMMAND_CLASS_WAKE_UP command classParams: - none -","ref":"Grizzly.ZWave.Commands.WakeUpNoMoreInformation.html","title":"Grizzly.ZWave.Commands.WakeUpNoMoreInformation","type":"module"},{"doc":"This module implements the WAKE_UP_NOTIFICATION command of the COMMAND_CLASS_WAKE_UP command classParams: - none -","ref":"Grizzly.ZWave.Commands.WakeUpNotification.html","title":"Grizzly.ZWave.Commands.WakeUpNotification","type":"module"},{"doc":"The Z/IP Packet keep alive commandParams::ack_flag - the flag if the receiving node should acknowledge the keep alive packet or not","ref":"Grizzly.ZWave.Commands.ZIPKeepAlive.html","title":"Grizzly.ZWave.Commands.ZIPKeepAlive","type":"module"},{"doc":"","ref":"Grizzly.ZWave.Commands.ZIPKeepAlive.html#encode_ack_flag/1","title":"Grizzly.ZWave.Commands.ZIPKeepAlive.encode_ack_flag/1","type":"function"},{"doc":"","ref":"Grizzly.ZWave.Commands.ZIPKeepAlive.html#t:ack_flag/0","title":"Grizzly.ZWave.Commands.ZIPKeepAlive.ack_flag/0","type":"type"},{"doc":"","ref":"Grizzly.ZWave.Commands.ZIPKeepAlive.html#t:param/0","title":"Grizzly.ZWave.Commands.ZIPKeepAlive.param/0","type":"type"},{"doc":"Command for sending Z-Wave commands via Z/IP","ref":"Grizzly.ZWave.Commands.ZIPPacket.html","title":"Grizzly.ZWave.Commands.ZIPPacket","type":"module"},{"doc":"","ref":"Grizzly.ZWave.Commands.ZIPPacket.html#ack_response?/1","title":"Grizzly.ZWave.Commands.ZIPPacket.ack_response?/1","type":"function"},{"doc":"","ref":"Grizzly.ZWave.Commands.ZIPPacket.html#command_name/1","title":"Grizzly.ZWave.Commands.ZIPPacket.command_name/1","type":"function"},{"doc":"Get the extension by extension name","ref":"Grizzly.ZWave.Commands.ZIPPacket.html#extension/3","title":"Grizzly.ZWave.Commands.ZIPPacket.extension/3","type":"function"},{"doc":"","ref":"Grizzly.ZWave.Commands.ZIPPacket.html#flag_to_byte/1","title":"Grizzly.ZWave.Commands.ZIPPacket.flag_to_byte/1","type":"function"},{"doc":"","ref":"Grizzly.ZWave.Commands.ZIPPacket.html#make_ack_response/2","title":"Grizzly.ZWave.Commands.ZIPPacket.make_ack_response/2","type":"function"},{"doc":"Make a :nack_response","ref":"Grizzly.ZWave.Commands.ZIPPacket.html#make_nack_response/1","title":"Grizzly.ZWave.Commands.ZIPPacket.make_nack_response/1","type":"function"},{"doc":"","ref":"Grizzly.ZWave.Commands.ZIPPacket.html#make_nack_waiting_response/2","title":"Grizzly.ZWave.Commands.ZIPPacket.make_nack_waiting_response/2","type":"function"},{"doc":"","ref":"Grizzly.ZWave.Commands.ZIPPacket.html#meta_to_byte/3","title":"Grizzly.ZWave.Commands.ZIPPacket.meta_to_byte/3","type":"function"},{"doc":"Make a Z/IP Packet Command that encapsulates another Z-Wave command","ref":"Grizzly.ZWave.Commands.ZIPPacket.html#with_zwave_command/3","title":"Grizzly.ZWave.Commands.ZIPPacket.with_zwave_command/3","type":"function"},{"doc":"","ref":"Grizzly.ZWave.Commands.ZIPPacket.html#t:flag/0","title":"Grizzly.ZWave.Commands.ZIPPacket.flag/0","type":"type"},{"doc":"","ref":"Grizzly.ZWave.Commands.ZIPPacket.html#t:param/0","title":"Grizzly.ZWave.Commands.ZIPPacket.param/0","type":"type"},{"doc":"Functions for working with the header extension in a Z/IP Packet.","ref":"Grizzly.ZWave.Commands.ZIPPacket.HeaderExtensions.html","title":"Grizzly.ZWave.Commands.ZIPPacket.HeaderExtensions","type":"module"},{"doc":"Try to parse a binary string into HeaderExtensions.t()","ref":"Grizzly.ZWave.Commands.ZIPPacket.HeaderExtensions.html#from_binary/1","title":"Grizzly.ZWave.Commands.ZIPPacket.HeaderExtensions.from_binary/1","type":"function"},{"doc":"","ref":"Grizzly.ZWave.Commands.ZIPPacket.HeaderExtensions.html#to_binary/1","title":"Grizzly.ZWave.Commands.ZIPPacket.HeaderExtensions.to_binary/1","type":"function"},{"doc":"","ref":"Grizzly.ZWave.Commands.ZIPPacket.HeaderExtensions.html#t:encapsulation_format_info/0","title":"Grizzly.ZWave.Commands.ZIPPacket.HeaderExtensions.encapsulation_format_info/0","type":"type"},{"doc":"","ref":"Grizzly.ZWave.Commands.ZIPPacket.HeaderExtensions.html#t:extension/0","title":"Grizzly.ZWave.Commands.ZIPPacket.HeaderExtensions.extension/0","type":"type"},{"doc":"Encapsulation format info for a Z/IP Packet","ref":"Grizzly.ZWave.Commands.ZIPPacket.HeaderExtensions.EncapsulationFormatInfo.html","title":"Grizzly.ZWave.Commands.ZIPPacket.HeaderExtensions.EncapsulationFormatInfo","type":"module"},{"doc":"Make a new EncapsulationFormatInfo struct","ref":"Grizzly.ZWave.Commands.ZIPPacket.HeaderExtensions.EncapsulationFormatInfo.html#new/2","title":"Grizzly.ZWave.Commands.ZIPPacket.HeaderExtensions.EncapsulationFormatInfo.new/2","type":"function"},{"doc":"","ref":"Grizzly.ZWave.Commands.ZIPPacket.HeaderExtensions.EncapsulationFormatInfo.html#security_to_security_from_byte/1","title":"Grizzly.ZWave.Commands.ZIPPacket.HeaderExtensions.EncapsulationFormatInfo.security_to_security_from_byte/1","type":"function"},{"doc":"","ref":"Grizzly.ZWave.Commands.ZIPPacket.HeaderExtensions.EncapsulationFormatInfo.html#security_to_security_to_byte/1","title":"Grizzly.ZWave.Commands.ZIPPacket.HeaderExtensions.EncapsulationFormatInfo.security_to_security_to_byte/1","type":"function"},{"doc":"Make an EncapsulationFormatInfo into a binary","ref":"Grizzly.ZWave.Commands.ZIPPacket.HeaderExtensions.EncapsulationFormatInfo.html#to_binary/1","title":"Grizzly.ZWave.Commands.ZIPPacket.HeaderExtensions.EncapsulationFormatInfo.to_binary/1","type":"function"},{"doc":"","ref":"Grizzly.ZWave.Commands.ZIPPacket.HeaderExtensions.EncapsulationFormatInfo.html#t:security/0","title":"Grizzly.ZWave.Commands.ZIPPacket.HeaderExtensions.EncapsulationFormatInfo.security/0","type":"type"},{"doc":"","ref":"Grizzly.ZWave.Commands.ZIPPacket.HeaderExtensions.EncapsulationFormatInfo.html#t:t/0","title":"Grizzly.ZWave.Commands.ZIPPacket.HeaderExtensions.EncapsulationFormatInfo.t/0","type":"type"},{"doc":"Expected Delay is the header extension that is found in a Z/IP Command to indicate how many seconds until the command will be received by a node and processed.Non-Sleeping devices: this extension does not applyFrequently Listening Nodes: 1 secondsSleeping devices: &gt; 1","ref":"Grizzly.ZWave.Commands.ZIPPacket.HeaderExtensions.ExpectedDelay.html","title":"Grizzly.ZWave.Commands.ZIPPacket.HeaderExtensions.ExpectedDelay","type":"module"},{"doc":"","ref":"Grizzly.ZWave.Commands.ZIPPacket.HeaderExtensions.ExpectedDelay.html#to_binary/1","title":"Grizzly.ZWave.Commands.ZIPPacket.HeaderExtensions.ExpectedDelay.to_binary/1","type":"function"},{"doc":"The installation and maintenance report for a Z/IP Packet","ref":"Grizzly.ZWave.Commands.ZIPPacket.HeaderExtensions.InstallationAndMaintenanceReport.html","title":"Grizzly.ZWave.Commands.ZIPPacket.HeaderExtensions.InstallationAndMaintenanceReport","type":"module"},{"doc":"","ref":"Grizzly.ZWave.Commands.ZIPPacket.HeaderExtensions.InstallationAndMaintenanceReport.html#from_binary/1","title":"Grizzly.ZWave.Commands.ZIPPacket.HeaderExtensions.InstallationAndMaintenanceReport.from_binary/1","type":"function"},{"doc":"","ref":"Grizzly.ZWave.Commands.ZIPPacket.HeaderExtensions.InstallationAndMaintenanceReport.html#ime_from_binary/1","title":"Grizzly.ZWave.Commands.ZIPPacket.HeaderExtensions.InstallationAndMaintenanceReport.ime_from_binary/1","type":"function"},{"doc":"Used to get additional information of a Z-Wave Plus device.Params: - none -","ref":"Grizzly.ZWave.Commands.ZwaveplusInfoGet.html","title":"Grizzly.ZWave.Commands.ZwaveplusInfoGet","type":"module"},{"doc":"This command reports the version of the Z-Wave Plus framework used and provides additional information of the Z-Wave Plus device.Params::zwaveplus_version - the Z-Wave Plus framework version (required):role_type - the role the Z-Wave Plus device (required):node_type - the type of node the Z-Wave Plus device (required):installer_icon_type - the icon to use in Graphical User Interfaces for network management (required):user_icon_type - the icon to use in Graphical User Interfaces for end users (required)","ref":"Grizzly.ZWave.Commands.ZwaveplusInfoReport.html","title":"Grizzly.ZWave.Commands.ZwaveplusInfoReport","type":"module"},{"doc":"","ref":"Grizzly.ZWave.Commands.ZwaveplusInfoReport.html#t:param/0","title":"Grizzly.ZWave.Commands.ZwaveplusInfoReport.param/0","type":"type"},{"doc":"Module for working with the SmartStart and S2 DSKs","ref":"Grizzly.ZWave.DSK.html","title":"Grizzly.ZWave.DSK","type":"module"},{"doc":"Take a binary representation of the DSK and change it into the string representation","ref":"Grizzly.ZWave.DSK.html#binary_to_string/1","title":"Grizzly.ZWave.DSK.binary_to_string/1","type":"function"},{"doc":"Make a new DSKIf less than 16 bytes are passed in, the rest are initialized to zero. Due to how DSKs are constructed, odd length binaries aren't allowed since they should never be possible.","ref":"Grizzly.ZWave.DSK.html#new/1","title":"Grizzly.ZWave.DSK.new/1","type":"function"},{"doc":"Parse a textual representation of a DSK","ref":"Grizzly.ZWave.DSK.html#parse/1","title":"Grizzly.ZWave.DSK.parse/1","type":"function"},{"doc":"Parse a DSK PINPINs can also be parsed by parse/1. When working with PINs, though, it's nice to be more forgiving and accept PINs as integers or strings without leading zeros.String examples:iex&gt; {:ok, dsk} = DSK.parse_pin(&quot;12345&quot;); dsk #DSK&lt;12345-00000-00000-00000-00000-00000-00000-00000&gt; iex&gt; {:ok, dsk} = DSK.parse_pin(&quot;123&quot;); dsk #DSK&lt;00123-00000-00000-00000-00000-00000-00000-00000&gt;Integer examples:iex&gt; {:ok, dsk} = DSK.parse_pin(12345); dsk #DSK&lt;12345-00000-00000-00000-00000-00000-00000-00000&gt; iex&gt; {:ok, dsk} = DSK.parse_pin(123); dsk #DSK&lt;00123-00000-00000-00000-00000-00000-00000-00000&gt;","ref":"Grizzly.ZWave.DSK.html#parse_pin/1","title":"Grizzly.ZWave.DSK.parse_pin/1","type":"function"},{"doc":"Take a string representation of the DSK and change it into the binary representation","ref":"Grizzly.ZWave.DSK.html#string_to_binary/1","title":"Grizzly.ZWave.DSK.string_to_binary/1","type":"function"},{"doc":"Return the first five digits of a DSK for use as a PINiex&gt; {:ok, dsk} = DSK.parse(&quot;50285-18819-09924-30691-15973-33711-04005-03623&quot;) iex&gt; DSK.to_pin_string(dsk) &quot;50285&quot; iex&gt; {:ok, dsk} = DSK.parse(&quot;00001-18819-09924-30691-15973-33711-04005-03623&quot;) iex&gt; DSK.to_pin_string(dsk) &quot;00001&quot;","ref":"Grizzly.ZWave.DSK.html#to_pin_string/1","title":"Grizzly.ZWave.DSK.to_pin_string/1","type":"function"},{"doc":"Convert the DSK to a stringiex&gt; {:ok, dsk} = DSK.parse(&quot;50285-18819-09924-30691-15973-33711-04005-03623&quot;) iex&gt; DSK.to_string(dsk) &quot;50285-18819-09924-30691-15973-33711-04005-03623&quot; iex&gt; {:ok, dsk} = DSK.parse(&quot;50285-18819-09924-30691-15973-33711-04005-03623&quot;) iex&gt; DSK.to_string(dsk, delimiter: &quot;&quot;) &quot;5028518819099243069115973337110400503623&quot;Options::delimiter - character to join the 5 byte sections together (default &quot;-&quot;)","ref":"Grizzly.ZWave.DSK.html#to_string/2","title":"Grizzly.ZWave.DSK.to_string/2","type":"function"},{"doc":"Generate a DSK that is all zerosThis is useful for placeholder/default DSKs.","ref":"Grizzly.ZWave.DSK.html#zeros/0","title":"Grizzly.ZWave.DSK.zeros/0","type":"function"},{"doc":"The DSK binary is the elixir binary string form of the DSKThe format is &lt;&lt;b1, b2, b3, ... b16&gt;&gt;That is 16 bytes.An example of this would be:&lt;&lt;196, 109, 73, 131, 38, 196, 119, 227, 62, 101, 131, 175, 15, 165, 14, 39&gt;&gt;","ref":"Grizzly.ZWave.DSK.html#t:dsk_binary/0","title":"Grizzly.ZWave.DSK.dsk_binary/0","type":"type"},{"doc":"The DSK string is the string version of the DSKThe general format is XXXXX-XXXXX-XXXXX-XXXXX-XXXXX-XXXXX-XXXXX-XXXXXThat is 8 blocks of 16 bit integers separated by a dash.An example of this would be 50285-18819-09924-30691-15973-33711-04005-03623","ref":"Grizzly.ZWave.DSK.html#t:dsk_string/0","title":"Grizzly.ZWave.DSK.dsk_string/0","type":"type"},{"doc":"","ref":"Grizzly.ZWave.DSK.html#t:t/0","title":"Grizzly.ZWave.DSK.t/0","type":"type"},{"doc":"Z-Wave device classes","ref":"Grizzly.ZWave.DeviceClasses.html","title":"Grizzly.ZWave.DeviceClasses","type":"module"},{"doc":"Try to make a basic device class from a byte","ref":"Grizzly.ZWave.DeviceClasses.html#basic_device_class_from_byte/1","title":"Grizzly.ZWave.DeviceClasses.basic_device_class_from_byte/1","type":"function"},{"doc":"Make a byte from a device class","ref":"Grizzly.ZWave.DeviceClasses.html#basic_device_class_to_byte/1","title":"Grizzly.ZWave.DeviceClasses.basic_device_class_to_byte/1","type":"function"},{"doc":"Try to get the generic device class for the byte","ref":"Grizzly.ZWave.DeviceClasses.html#generic_device_class_from_byte/1","title":"Grizzly.ZWave.DeviceClasses.generic_device_class_from_byte/1","type":"function"},{"doc":"Turn the generic device class into a byte","ref":"Grizzly.ZWave.DeviceClasses.html#generic_device_class_to_byte/1","title":"Grizzly.ZWave.DeviceClasses.generic_device_class_to_byte/1","type":"function"},{"doc":"Try to get the specific device class from the byte given the generic device class","ref":"Grizzly.ZWave.DeviceClasses.html#specific_device_class_from_byte/2","title":"Grizzly.ZWave.DeviceClasses.specific_device_class_from_byte/2","type":"function"},{"doc":"Make the specific device class into a byte","ref":"Grizzly.ZWave.DeviceClasses.html#specific_device_class_to_byte/2","title":"Grizzly.ZWave.DeviceClasses.specific_device_class_to_byte/2","type":"function"},{"doc":"","ref":"Grizzly.ZWave.DeviceClasses.html#t:basic_device_class/0","title":"Grizzly.ZWave.DeviceClasses.basic_device_class/0","type":"type"},{"doc":"","ref":"Grizzly.ZWave.DeviceClasses.html#t:generic_device_class/0","title":"Grizzly.ZWave.DeviceClasses.generic_device_class/0","type":"type"},{"doc":"","ref":"Grizzly.ZWave.DeviceClasses.html#t:specific_device_class/0","title":"Grizzly.ZWave.DeviceClasses.specific_device_class/0","type":"type"},{"doc":"The installer icon type is used in Z-Wave Plus devices to allow interoperability with generic Z-Wave graphical user interfaces.These interfaces are useful when using generic Z-Wave tooling and debugging to allow the user to get a meaningful representation of any product included in the network, and is mandatory according the Z-Wave Plus specification.See SDS11847 Z-Wave Plus Device Type Specification.pdf Appendix A provided by Silicon Labs for more information.","ref":"Grizzly.ZWave.IconType.html","title":"Grizzly.ZWave.IconType","type":"module"},{"doc":"Get the icon type's name from a 16-bit integer value","ref":"Grizzly.ZWave.IconType.html#to_name/1","title":"Grizzly.ZWave.IconType.to_name/1","type":"function"},{"doc":"Get the 16-bit integer value from the icon type's name","ref":"Grizzly.ZWave.IconType.html#to_value/1","title":"Grizzly.ZWave.IconType.to_value/1","type":"function"},{"doc":"","ref":"Grizzly.ZWave.IconType.html#t:name/0","title":"Grizzly.ZWave.IconType.name/0","type":"type"},{"doc":"","ref":"Grizzly.ZWave.IconType.html#t:value/0","title":"Grizzly.ZWave.IconType.value/0","type":"type"},{"doc":"","ref":"Grizzly.ZWave.Notifications.html","title":"Grizzly.ZWave.Notifications","type":"module"},{"doc":"","ref":"Grizzly.ZWave.Notifications.html#decode_alarm_types/1","title":"Grizzly.ZWave.Notifications.decode_alarm_types/1","type":"function"},{"doc":"","ref":"Grizzly.ZWave.Notifications.html#decode_event_params/3","title":"Grizzly.ZWave.Notifications.decode_event_params/3","type":"function"},{"doc":"","ref":"Grizzly.ZWave.Notifications.html#decode_type_events/2","title":"Grizzly.ZWave.Notifications.decode_type_events/2","type":"function"},{"doc":"","ref":"Grizzly.ZWave.Notifications.html#encode_alarm_types/1","title":"Grizzly.ZWave.Notifications.encode_alarm_types/1","type":"function"},{"doc":"","ref":"Grizzly.ZWave.Notifications.html#encode_event_params/3","title":"Grizzly.ZWave.Notifications.encode_event_params/3","type":"function"},{"doc":"","ref":"Grizzly.ZWave.Notifications.html#encode_type_events/2","title":"Grizzly.ZWave.Notifications.encode_type_events/2","type":"function"},{"doc":"Get the event from the byte given the notification type","ref":"Grizzly.ZWave.Notifications.html#event_from_byte/2","title":"Grizzly.ZWave.Notifications.event_from_byte/2","type":"function"},{"doc":"Get the event byte given the event type","ref":"Grizzly.ZWave.Notifications.html#event_to_byte/2","title":"Grizzly.ZWave.Notifications.event_to_byte/2","type":"function"},{"doc":"","ref":"Grizzly.ZWave.Notifications.html#status_from_byte/1","title":"Grizzly.ZWave.Notifications.status_from_byte/1","type":"function"},{"doc":"","ref":"Grizzly.ZWave.Notifications.html#status_to_byte/1","title":"Grizzly.ZWave.Notifications.status_to_byte/1","type":"function"},{"doc":"Get the type from the byte","ref":"Grizzly.ZWave.Notifications.html#type_from_byte/1","title":"Grizzly.ZWave.Notifications.type_from_byte/1","type":"function"},{"doc":"Get the byte for the event name","ref":"Grizzly.ZWave.Notifications.html#type_to_byte/1","title":"Grizzly.ZWave.Notifications.type_to_byte/1","type":"function"},{"doc":"","ref":"Grizzly.ZWave.Notifications.html#t:event/0","title":"Grizzly.ZWave.Notifications.event/0","type":"type"},{"doc":"","ref":"Grizzly.ZWave.Notifications.html#t:status/0","title":"Grizzly.ZWave.Notifications.status/0","type":"type"},{"doc":"","ref":"Grizzly.ZWave.Notifications.html#t:type/0","title":"Grizzly.ZWave.Notifications.type/0","type":"type"},{"doc":"","ref":"Grizzly.ZWave.Notifications.html#t:zwave_alarm_status/0","title":"Grizzly.ZWave.Notifications.zwave_alarm_status/0","type":"type"},{"doc":"Z-Wave QR code This module handles Z-Wave QR codes that follow Silicon Labs Software Design Specification SDS13937 and SDS13944.","ref":"Grizzly.ZWave.QRCode.html","title":"Grizzly.ZWave.QRCode","type":"module"},{"doc":"Encode device information into Z-Wave QR Code format The output of this is either a 90 byte or 136 byte string that should be put into a QR Code. Z-Wave specifies that the 90-byte code (no UUID16) is made into a 29x29 pixel QR Code. The 136-byte* code (w/ UUID16) should be put into a 33x33 pixel QR Code. QR Codes should be encoded as type &quot;text&quot; with error correction &quot;L&quot;. NOTE: SDS13937 has a mistake with the code length. It says 134 bytes, but the UUID16 encode has 2 extra bytes for presentation, so it should be 136.","ref":"Grizzly.ZWave.QRCode.html#encode!/1","title":"Grizzly.ZWave.QRCode.encode!/1","type":"function"},{"doc":"Device information:zwave_device_type - either {generic_device_type, specific_device_type} or a number","ref":"Grizzly.ZWave.QRCode.html#t:t/0","title":"Grizzly.ZWave.QRCode.t/0","type":"type"},{"doc":"QR Code version (S2-only or Smart Start-enabled)","ref":"Grizzly.ZWave.QRCode.html#t:version/0","title":"Grizzly.ZWave.QRCode.version/0","type":"type"},{"doc":"Helpers for security","ref":"Grizzly.ZWave.Security.html","title":"Grizzly.ZWave.Security","type":"module"},{"doc":"","ref":"Grizzly.ZWave.Security.html#byte_to_keys/1","title":"Grizzly.ZWave.Security.byte_to_keys/1","type":"function"},{"doc":"Decode a byte representation of the key exchanged failed type","ref":"Grizzly.ZWave.Security.html#failed_type_from_byte/1","title":"Grizzly.ZWave.Security.failed_type_from_byte/1","type":"function"},{"doc":"","ref":"Grizzly.ZWave.Security.html#failed_type_to_byte/1","title":"Grizzly.ZWave.Security.failed_type_to_byte/1","type":"function"},{"doc":"Gets the highest security level key from a key listSince Z-Wave will work at the highest S2 security group available on a node, if multiple groups are in a list of keys it will assume that highest level is the security level of the node who provided this list.If the node S0 security Z-Wave will response with granted keys with the lone key being S0.","ref":"Grizzly.ZWave.Security.html#get_highest_level/1","title":"Grizzly.ZWave.Security.get_highest_level/1","type":"function"},{"doc":"Get the byte representation of a key.The key :none is an invalid key to encode to, so this function does not support encoding to that key.","ref":"Grizzly.ZWave.Security.html#key_byte/1","title":"Grizzly.ZWave.Security.key_byte/1","type":"function"},{"doc":"Get the list of available security keys","ref":"Grizzly.ZWave.Security.html#keys/0","title":"Grizzly.ZWave.Security.keys/0","type":"function"},{"doc":"","ref":"Grizzly.ZWave.Security.html#keys_to_byte/1","title":"Grizzly.ZWave.Security.keys_to_byte/1","type":"function"},{"doc":"Validate the user input pin length, should be a 16 bit number","ref":"Grizzly.ZWave.Security.html#validate_user_input_pin_length/1","title":"Grizzly.ZWave.Security.validate_user_input_pin_length/1","type":"function"},{"doc":"","ref":"Grizzly.ZWave.Security.html#t:key/0","title":"Grizzly.ZWave.Security.key/0","type":"type"},{"doc":"","ref":"Grizzly.ZWave.Security.html#t:key_byte/0","title":"Grizzly.ZWave.Security.key_byte/0","type":"type"},{"doc":"Possible key exchange failures:none - Bootstrapping was successful:key - No match between requested and granted keys:scheme - no scheme is supported by the controller or joining node:decrypt - joining node failed to decrypt the input pin from the value. Wrong input value/DSK from user:cancel - user has canceled the S2 bootstrapping:auth - the echo kex change frame does not match the earlier exchanged frame:get - the joining node requested a key that was not granted by the controller at an earlier stage:verify - the joining node cannot verify and decrypt the exchanged key:report - the including node transmitted a frame containing a different key than what was currently being exchanged","ref":"Grizzly.ZWave.Security.html#t:key_exchange_fail_type/0","title":"Grizzly.ZWave.Security.key_exchange_fail_type/0","type":"type"},{"doc":"Meta Extensions for SmartStart devices for QR codes and node provisioning list","ref":"Grizzly.ZWave.SmartStart.MetaExtension.html","title":"Grizzly.ZWave.SmartStart.MetaExtension","type":"module"},{"doc":"Encode an extension into a binary","ref":"Grizzly.ZWave.SmartStart.MetaExtension.html#encode/1","title":"Grizzly.ZWave.SmartStart.MetaExtension.encode/1","type":"function"},{"doc":"Parse the binary into the list of extensions","ref":"Grizzly.ZWave.SmartStart.MetaExtension.html#parse/1","title":"Grizzly.ZWave.SmartStart.MetaExtension.parse/1","type":"function"},{"doc":"Version of the application in a string format of &quot;Major.Minor&quot;","ref":"Grizzly.ZWave.SmartStart.MetaExtension.html#t:application_version/0","title":"Grizzly.ZWave.SmartStart.MetaExtension.application_version/0","type":"type"},{"doc":"The mode to use when including the node advertised in the provisioning list:security_2 - the node must be manually set to learn mode and follow the S2 bootstrapping instructions:smart_start - the node will use S2 bootstrapping automatically using the SmartStart functionality:long_range - included the device using the Z-Waver long range protocol. If no keys are granted in the :advanced_joining extension this inclusion will fail.","ref":"Grizzly.ZWave.SmartStart.MetaExtension.html#t:bootstrapping_mode/0","title":"Grizzly.ZWave.SmartStart.MetaExtension.bootstrapping_mode/0","type":"type"},{"doc":"Meta extension for SmartStart devices:advanced_joining - used to specify which S2 security keys to grant during S2 inclusion:bootstrapping_mode - used to specify the bootstrapping mode the including node must join with:location_information - used to advertise the location assigned to the node:max_inclusion_request_interval - used to advertise if a power constrained smart start node will issue an inclusion request at a higher interval than the default 512 seconds:name_information - used to advertise the name of the node:network_status - used to advertise if the node is in the network and its node id:product_id - used to advertise product identifying data:product_type - used to advertise the product type data:smart_start_inclusion_setting - used to advertise the smart start inclusion setting:uuid16 - used to advertise the 16 byte manufacturer-defined information that is unique to the that device:unknown - sometimes new extensions are released without first class support, so this extension is used for those extensions that still need to be supported in this library","ref":"Grizzly.ZWave.SmartStart.MetaExtension.html#t:extension/0","title":"Grizzly.ZWave.SmartStart.MetaExtension.extension/0","type":"type"},{"doc":"Generic Device Class for the product type extension","ref":"Grizzly.ZWave.SmartStart.MetaExtension.html#t:generic_device_class/0","title":"Grizzly.ZWave.SmartStart.MetaExtension.generic_device_class/0","type":"type"},{"doc":"The interval (in seconds) must be in the range of 640..12672 inclusive, and has to be in steps of 128 seconds.So after 640 the next valid interval is 640 + 128 which is 768 seconds.See SDS13944 Node Provisioning Information Type Registry.pdf section 3.1.2.3 for more information.","ref":"Grizzly.ZWave.SmartStart.MetaExtension.html#t:inclusion_interval/0","title":"Grizzly.ZWave.SmartStart.MetaExtension.inclusion_interval/0","type":"type"},{"doc":"Settings for the smart start inclusion setting exentsion:pending - the node will be added to the network when it issues SmartStart inclusion requests.:passive - this node is unlikely to issues a SmartStart inclusion request and SmartStart inclusion requests will be ignored from this node by the Z/IP Gateway. All nodes in the list with this setting must be updated to :pending when Provisioning List Iteration Get command is issued.:ignored - All SmartStart inclusion request are ignored from this node until updated via Z/IP Client (Grizzly) or a controlling node.","ref":"Grizzly.ZWave.SmartStart.MetaExtension.html#t:inclusion_setting/0","title":"Grizzly.ZWave.SmartStart.MetaExtension.inclusion_setting/0","type":"type"},{"doc":"The location string cannot contain underscores and cannot end with a dash.The location string can contain a period (.) but a sublocation cannot end a dash. For example:123.123-.123The above location invalid. To make it valid remove the - before ..A node's location cannot be more than 62 bytes.","ref":"Grizzly.ZWave.SmartStart.MetaExtension.html#t:information_location/0","title":"Grizzly.ZWave.SmartStart.MetaExtension.information_location/0","type":"type"},{"doc":"The name string cannot contain underscores and cannot end with a dash.A node's name cannot be more than 62 bytes.","ref":"Grizzly.ZWave.SmartStart.MetaExtension.html#t:information_name/0","title":"Grizzly.ZWave.SmartStart.MetaExtension.information_name/0","type":"type"},{"doc":"Installer icon for the product type extension","ref":"Grizzly.ZWave.SmartStart.MetaExtension.html#t:installer_icon_type/0","title":"Grizzly.ZWave.SmartStart.MetaExtension.installer_icon_type/0","type":"type"},{"doc":"Id of the manufacturer for the product id extension","ref":"Grizzly.ZWave.SmartStart.MetaExtension.html#t:manufacturer_id/0","title":"Grizzly.ZWave.SmartStart.MetaExtension.manufacturer_id/0","type":"type"},{"doc":"The different network statuses are::not_in_network - the node in the provisioning list is not included in the network:included - the node in the provisioning list is included in the network and is functional:failing - the node in the provisioning list is included in the network but is now marked as failing","ref":"Grizzly.ZWave.SmartStart.MetaExtension.html#t:network_status/0","title":"Grizzly.ZWave.SmartStart.MetaExtension.network_status/0","type":"type"},{"doc":"Id of the product produced by the manufacturer for the product id extension","ref":"Grizzly.ZWave.SmartStart.MetaExtension.html#t:product_id/0","title":"Grizzly.ZWave.SmartStart.MetaExtension.product_id/0","type":"type"},{"doc":"","ref":"Grizzly.ZWave.SmartStart.MetaExtension.html#t:product_id_values/0","title":"Grizzly.ZWave.SmartStart.MetaExtension.product_id_values/0","type":"type"},{"doc":"Type of product produced by the manufacturer for the product id extension","ref":"Grizzly.ZWave.SmartStart.MetaExtension.html#t:product_type/0","title":"Grizzly.ZWave.SmartStart.MetaExtension.product_type/0","type":"type"},{"doc":"","ref":"Grizzly.ZWave.SmartStart.MetaExtension.html#t:product_type_values/0","title":"Grizzly.ZWave.SmartStart.MetaExtension.product_type_values/0","type":"type"},{"doc":"Specific Device Class for the product type extension","ref":"Grizzly.ZWave.SmartStart.MetaExtension.html#t:specific_device_class/0","title":"Grizzly.ZWave.SmartStart.MetaExtension.specific_device_class/0","type":"type"},{"doc":"Unsigned 16 bit integer","ref":"Grizzly.ZWave.SmartStart.MetaExtension.html#t:unit_16/0","title":"Grizzly.ZWave.SmartStart.MetaExtension.unit_16/0","type":"type"},{"doc":"This is used to advertise 16 bytes of manufactured-defined information that is unique for a given product. Z-Wave UUIDs are not limited to the format outlined in RFC 4122 but can also be ASCII characters and a relevant prefix.","ref":"Grizzly.ZWave.SmartStart.MetaExtension.UUID16.html","title":"Grizzly.ZWave.SmartStart.MetaExtension.UUID16","type":"module"},{"doc":"Make a binary string from a UUID16.t()","ref":"Grizzly.ZWave.SmartStart.MetaExtension.UUID16.html#encode/1","title":"Grizzly.ZWave.SmartStart.MetaExtension.UUID16.encode/1","type":"function"},{"doc":"Make a new UUID16.t()","ref":"Grizzly.ZWave.SmartStart.MetaExtension.UUID16.html#new/2","title":"Grizzly.ZWave.SmartStart.MetaExtension.UUID16.new/2","type":"function"},{"doc":"Take a binary string and try to make a UUID16.t() from it If the critical bit is set in teh binary this will return {:error, :critical_bit_set} and the information should be ignored. If the format in the binary is not part of the defined Z-Wave specification this will return {:error, :invalid_format}","ref":"Grizzly.ZWave.SmartStart.MetaExtension.UUID16.html#parse/1","title":"Grizzly.ZWave.SmartStart.MetaExtension.UUID16.parse/1","type":"function"},{"doc":"The three formats that the Z-Wave UUID can be formatted in are :ascii, :hex, or :rfc4122.Both :ascii and :hex can also have the prefix sn: or UUID:.Valid :hex formatted UUIDs look like:0102030405060708090A141516171819sn:0102030405060708090A141516171819UUID:0102030405060708090A141516171819Valid :ascii formatted UUIDs look like:Hello Elixir!!!sn:Hello Elixir!!!UUID:Hello Elixir!!!Lastly rfc4122 format looks like 58D5E212-165B-4CA0-909B-C86B9CEE0111 where every two digits make up one hex value.More information about RFC 4122 and the specification format can be found here.","ref":"Grizzly.ZWave.SmartStart.MetaExtension.UUID16.html#t:format/0","title":"Grizzly.ZWave.SmartStart.MetaExtension.UUID16.format/0","type":"type"},{"doc":"","ref":"Grizzly.ZWave.SmartStart.MetaExtension.UUID16.html#t:t/0","title":"Grizzly.ZWave.SmartStart.MetaExtension.UUID16.t/0","type":"type"},{"doc":"","ref":"Grizzly.ZWave.SmartStart.MetaExtension.UUID16.html#t:uuid/0","title":"Grizzly.ZWave.SmartStart.MetaExtension.UUID16.uuid/0","type":"type"},{"doc":"Prints the generated zipgateway config to the console mix zipgateway.cfg","ref":"Mix.Tasks.Zipgateway.Cfg.html","title":"Mix.Tasks.Zipgateway.Cfg","type":"task"},{"doc":"Callback implementation for Mix.Task.run/1.","ref":"Mix.Tasks.Zipgateway.Cfg.html#run/1","title":"Mix.Tasks.Zipgateway.Cfg.run/1","type":"function"},{"doc":"Generates the scaffolding for a new Z-Wave Command mix zwave.gen.command ThermostatModeSet Thermostat modeThe pattern is mix zwave.gen.command CommandModuleName CommandClassModule params....Flags:--no-save - will print the generated module out to the console--target-dir &lt;path&gt; - will generate the new module at the provided path--no_test - if set, will not generate a test file","ref":"Mix.Tasks.Zwave.Gen.Command.html","title":"Mix.Tasks.Zwave.Gen.Command","type":"task"},{"doc":"Callback implementation for Mix.Task.run/1.","ref":"Mix.Tasks.Zwave.Gen.Command.html#run/1","title":"Mix.Tasks.Zwave.Gen.Command.run/1","type":"function"},{"doc":"Generates the scaffolding for a new Z-Wave Command mix zwave.gen.command_class ThermostatThe pattern is mix zwave.gen.command_class CommandClassModuleFlags:--no-save - will print the generated module out to the console--target-dir &lt;path&gt; - will generate the new module at the provided path","ref":"Mix.Tasks.Zwave.Gen.CommandClass.html","title":"Mix.Tasks.Zwave.Gen.CommandClass","type":"task"},{"doc":"","ref":"Mix.Tasks.Zwave.Gen.CommandClass.html#get_target/1","title":"Mix.Tasks.Zwave.Gen.CommandClass.get_target/1","type":"function"},{"doc":"Callback implementation for Mix.Task.run/1.","ref":"Mix.Tasks.Zwave.Gen.CommandClass.html#run/1","title":"Mix.Tasks.Zwave.Gen.CommandClass.run/1","type":"function"},{"doc":"Exception for when decoding a Z-Wave Command goes wrong","ref":"Grizzly.ZWave.DecodeError.html","title":"Grizzly.ZWave.DecodeError","type":"exception"},{"doc":"Callback implementation for Exception.message/1.","ref":"Grizzly.ZWave.DecodeError.html#message/1","title":"Grizzly.ZWave.DecodeError.message/1","type":"function"},{"doc":"","ref":"Grizzly.ZWave.DecodeError.html#t:t/0","title":"Grizzly.ZWave.DecodeError.t/0","type":"type"},{"doc":"An Elixir library for Z-Wave","ref":"readme.html","title":"README","type":"extras"},{"doc":"def deps do [ {:grizzly, &quot;~&gt; 0.19.1&quot;} ] end","ref":"readme.html#installation","title":"README - Installation","type":"extras"},{"doc":"Z-Wave Bridge ControllerZ-Wave 500Z-Wave 700Compatible SystemNerves Compatible Systemzipgateway-envSilicon Labs zipgateway binaryThe zipgateway binary allows Grizzly to use Z-Wave over IP or Z/IP. Using the zipgateway binary provided by Silicon labs allows Grizzly to support the full range of Z-Wave features quickly and reliability. Some of the more advanced features like S2 security and smart start are already supported in Grizzly.See instructions below for compiling the zipgateway binary and/or running locally.If you want a quick reference to common uses of Grizzly see the cookbook docs.","ref":"readme.html#hardware-requirements","title":"README - Hardware Requirements","type":"extras"},{"doc":"Grizzly exposes a supervisor Grizzly.Supervisor for the consuming application to add to its supervisor tree. This gives the most flexibility and control over when Grizzly's processes start. Common ways to start Grizzly can look like:# all the default options are fine Grizzly.Supervisor.start_link() # using custom hardware where the serial port is different than the default # the default serial port is /dev/ttyUSB0. Grizzly.Supervisor.start_link(serial_port: &quot;/dev/ttyS4&quot;) # if your system is using zipgateway-env and/or something other than Grizzly # will start and manage running the zipgateway binary Grizzly.Supervisor.start_link(run_zipgateway: false)There are other configuration options you can pass to Grizzly but the above are most common options. The Grizzly.Supervisor docs explains all the options in more detail.To use a device you have to add it to the Z-Wave network. This is &quot;called including a device&quot; or &quot;starting an inclusion.&quot; While most of the Grizzly's API is synchronous the process of adding a node is not. So, if you are working from the IEx console you can use flush to see the newly add device. Here's how this process roughly goes.iex&gt; Grizzly.Inclusions.add_node() :ok iex&gt; flush {:grizzly, :report, %Grizzly.Report{ command: %Grizzly.ZWave.Command{ name: :node_add_status, params: [&lt;node info in here&gt;] } }}To remove a device we have to do an exclusion. Z-Wave uses the umbrella term &quot;inclusions&quot; for both adding a removing a device, but an &quot;inclusion&quot; is only about device pairing and &quot;exclusion&quot; is only about device removal. The way to remove the device from your network in IEx:iex&gt; Grizzly.Inclusions.remove_node() :ok iex&gt; flush {:grizzly, :report, %Grizzly.Report{ command: %Grizzly.ZWave.Command{ name: :node_remove_status, params: [&lt;node info in here&gt;] } }}There are more details about this process and how to better tie into the Grizzly runtime for this events in Grizzly.Inclusions.After you included a node it will be given a node id that you can use to send Z-Wave commands to it. Say for example we added an on off switch to our network, in Z-Wave this will be called a binary switch, and it was given the id of 5. Turning it off and on would look like this in IEx:iex&gt; Grizzly.send_command(5, :switch_binary_set, target_value: :on) {:ok, %Grizzly.Report{}} iex&gt; Grizzly.send_command(5, :switch_binary_set, target_value: :off) {:ok, %Grizzly.Report{}}For more documentation on what Grizzly.send_command/4 can return see the Grizzly and Grizzly.Report module documentation.Successful Commands{:ok, %Grizzly.Report{type: :ack_response}} - normally for setting things on a device or changing the device's state{:ok, %Grizzly.Report{type: :command}} - this is normally returned when asking for a device state or about some information about a device or Z-Wave network. The command be access by the :command field field of the report.{:ok, %Grizzly.Report{type: :queued}} - some devices sleep, so sending a command to it will be queued for some amount of type that can be access in the :queued_delay field. Once a device wakes up the calling process will receive the messages in this form: {:grizzly, :report, %Grizzly.Report{}} where the type can either be :queued_ping or :command. To check if the report you receive was queued you can check the :queued field in the report.{:ok, %Grizzly.Report{type: :timeout}} - the command was sent but for some reason this commanded timed out.When things go wrong{:error, :nack_response} - for when the node is not responding to the command. Grizzly has automatic retries, so if you got this message that might mean the node is reachable, your Z-Wave network is experiencing a of traffic, or the node has recently been hit with a lot of commands and cannot handle anymore at this moment.{:error, :including} - the Z-Wave controller is currently in the inclusion state and the controller cannot send any commands currently{:error, :firmware_updating} - the Z-Wave controller is currently in the process of having it's firmware updated and is not able to send commandsMore information about Grizzly.send_command/4 and the options like timeouts and retries that can be passed to see the Grizzly module.More information about reports see the documentation in the Grizzly.Report module.","ref":"readme.html#basic-usage","title":"README - Basic Usage","type":"extras"},{"doc":"When reports are sent from the Z-Wave network to the controller without the controller asking for a report these are called unsolicited messages. A concrete example of this is when you manually unlock a lock, the controller will receive a message from the device if the associations are setup correctly (see Grizzly.Node.set_lifeline_association/2 for more information). You can listen for these reports using either Grizzly.subscribe_command/1 or Grizzly.subscribe_commands/1.Grizzly.subscribe_command(:door_lock_operation_report) # manually unlock a lock flush {:grizzly, :report, %Grizzly.Report{type: :unsolicited}}To know what reports a device sends please see the device's user manual as these events will be outlined by the manufacture in the manual.Compile and Configure zipgateway","ref":"readme.html#unsolicited-messages","title":"README - Unsolicited Messages","type":"extras"},{"doc":"If you want to run Grizzly locally for development and/or learning before going through the challenge of compiling and running in Nerves we recommend the zipgateway-env project. This provides a docker container and CLI for compiling and running different versions of zipgateway.","ref":"readme.html#quick-and-fast-running-locally","title":"README - Quick and Fast running locally","type":"extras"},{"doc":"First download the Z/IP GW SDK from Silicon Labs. You'll need to create an account with them to do this, but the download is free.The default binaries that come with the download will not work by default in Nerves system, so you will need to compile the source for your target. The source code can be found in the Source directory.This can be tricky and the instructions are a work in progress, so for now please contact us if you any troubles.Connecting zipgateway to Grizzlyzipgateway runs as a separate server, accessed over a DTLS (UDP over SSL) connection. Grizzly will automatically start this server. It assumes the executable is in /usr/sbin/zipgateway. If this is not the case, you can specify the actual location withconfig :grizzly, zipgateway_path: &quot;«path»&quot;Grizzly uses the taptun module to manage the TCP connection: it checks that this is loaded as it starts.Configuring zipgatewayThe zipgateway binary is passed a configuration file named zipgateway.cfg. This has configuration parameters around networking and setting device specific information. Most of these configuration settings are static, so Grizzly can handle those for you in a reliable way. However, there are few exposed configuration options to allow some customization around device specific information, logging, and network interface set up.Supported configuration fields are::tun_script - a path to the .tun script (default priv dir of Grizzly):manufacturer_id: Id to set in the version report (default 0):hardware_version - Hardware version to set in the version report (default 1):product_id - Id to set in the version report (default 1):product_type - Id to set in the version report (default 1):serial_log - Log file for serial communication. Used for debugging. If this option is not set the no logging is done (default none)For the most part if you are using Grizzly to run zipgateway the defaults should just work.When going through certification you will need provide some device specific information:config :grizzly, zipgateway_cfg: %{ manufacturer_id: 0, product_type: 1, product_id: 1, hardware_version: 1 }The manufacturer_id will be given to you by Silicon Labs, and will default to 0if not set (this is zipgateway level default).The above fields have no impact on the Grizzly runtime, and are only useful for certification processes.When running zipgateway binary out side of Grizzly this configuration field is ignored and you will need to pass in the location to your configuration like so:zipgateway -c /path/to/zipgateway.cfg","ref":"readme.html#nerves-devices-wip","title":"README - Nerves Devices (WIP)","type":"extras"},{"doc":"Z-Wave Specification DocumentationZ-Wave Learning ResourcesSpecific Z-Wave product information","ref":"readme.html#resources","title":"README - Resources","type":"extras"},{"doc":"","ref":"changelog.html","title":"CHANGELOG","type":"extras"},{"doc":"","ref":"changelog.html#changelog","title":"CHANGELOG - Changelog","type":"extras"},{"doc":"AddedConfiguration option for setting the RF regionConfiguration option for setting power level settingsImprovementsAllow passing send command options to functions in Grizzly.SwitchBinary moduleThank you to djantea for testing out the RF configuration changes!","ref":"changelog.html#v0-19-1-2021-4-23","title":"CHANGELOG - v0.19.1 - 2021-4-23","type":"extras"},{"doc":"Breaking change in regards to how meta extensions are passed to Grizzly.Network.set_node_provisioning/3.The meta extension were once structs that need to be built and passed to the function, but now they are a keyword list. Please see Grizzly.ZWave.SmartStart.MetaExtension module for more details on the keyword keys and their values.","ref":"changelog.html#v0-19-0-2021-4-19","title":"CHANGELOG - v0.19.0 - 2021-4-19","type":"extras"},{"doc":"Added Grizzly.SwitchBinary has a higher level helper module to control binary switchesAdded basic support for including Z-Wave LR devicesAdded LR command class support for NetworkManagementInclusionSupport version 2 of User Number Report command","ref":"changelog.html#added","title":"CHANGELOG - Added","type":"extras"},{"doc":"Better handling of RSSI channel reportsBetter handling of Association Group Name Report commandThank you to those who contributed to this release:Jean-Francois Cloutier","ref":"changelog.html#improvements","title":"CHANGELOG - Improvements","type":"extras"},{"doc":"AddedGrizzly.ZWave.DSK.parse_pin/1Grizzly.ZWave.DSK.to_pin_string/1FixesEnsure that the DSK binary is 128 bits","ref":"changelog.html#v0-18-3-2021-3-11","title":"CHANGELOG - v0.18.3 - 2021-3-11","type":"extras"},{"doc":"ImprovementsUse cerlc library for Grizzly.ZWave.CRCClean up inspects from testsEnsure zipgateway files are usable by system untils for zipgateway","ref":"changelog.html#v0-18-2-2021-2-18","title":"CHANGELOG - v0.18.2 - 2021-2-18","type":"extras"},{"doc":"FixesFix up dialyzer typesThank you to those who contributed to this release:Jean-Francois Cloutier","ref":"changelog.html#v0-18-1-2021-2-10","title":"CHANGELOG - v0.18.1 - 2021-2-10","type":"extras"},{"doc":"This release breaks the DSK API and other supporting APIs. If you have not supported S2 inclusions, smart start, or use the DSK API for any reason then it should be safe to upgrade.The break to DSKs is the new Grizzly.ZWave.DSK.t() struct. All inclusion and node provisioning commands now expect a Grizzly.ZWave.DSK.t(). There are two times you will need to get a DSK.t():User input of a DSK pin (the nicely formatted representation)The binary (&lt;&lt;&gt;&gt;) representation.For the first case you can use Grizzly.ZWave.DSK.parse/1 and for the second case you can use Grizzly.ZWave.DSK.new/1.A common use case for DSKs is using the DSK pin (the first 5 digits in the DSK) to do S2 inclusion. This was done by calling Grizzly.Inclusions.set_input_dsk/1. Where the input DSK was an non_neg_integer(). This API has been changed to take a DSK.t().Exampledsk_pin = &quot;12345&quot; {:ok, dsk} = Grizzly.ZWave.DSK.parse(dsk_pin) Grizzly.Inclusions.set_input_dsk(dsk)This API is more useful for taking user input (which the DSK pin is), parsing it, and passing the DSK to the inclusion process. Also this pushes validation of DSK to the Grizzly.ZWave.DSK.parse/1 function.dsk_pin = &quot;123456&quot; {:error, :invalid_dsk} = Grizzly.ZWave.DSK.parse(dsk_pin)The DSK.t() has the String.Chars protocol implemented so if you want to a pretty representation of the DSK, say for logging or displaying the DSK to the user, you call the to_string/1 function on the DSK.t(). Also, see Grizzly.ZWave.DSK.to_string/2 for more details.If you need to access the raw binary form of the DSK you the DSK.t() exposes the :raw field, so you can access that via dsk.raw.This release also added support S2/SmartStart QR code generation. See the Grizzly.ZWave.QRCode module for more details.ChangedGrizzly.Inclusions.set_input_dsk/1 use to take non_neg_integer() type as an argument, but the type has changed to Grizzly.ZWave.DSK.t()Grizzly.ZWave.CommandClasses.NodeProvisioning.optional_dsk_to_binary/1 use to take a string as the DSK input but now it takes Grizzly.ZWave.DSK.t()Grizzly.ZWave.CommandClasses.NodeProvisioning.optional_binary_to_dsk/1 use to take a string as the DSK input but now it takes Grizzly.ZWave.DSK.t()The following commands had params that took a string for the DSK and now take Grizzly.ZWave.DSK.t():Grizzly.ZWave.Commands.DSKReportGrizzly.ZWave.Commands.LearnModeSetStatusGrizzly.ZWave.Commands.NodeAddDSKReportGrizzly.ZWave.Commands.NodeAddDSKSetGrizzly.ZWave.Commands.NodeAddStatusGrizzly.ZWave.Commands.NodeProvisioningDeleteGrizzly.ZWave.Commands.NodeProvisioningGetGrizzly.ZWave.Commands.NodeProvisioningListIterationReportGrizzly.ZWave.Commands.NodeProvisioningReportGrizzly.ZWave.Commands.NodeProvisioningSetGrizzly.ZWave.Commands.SmartStartJoinStartedAddedQR code support via the Grizzly.ZWave.QRCode module.","ref":"changelog.html#v0-18-0-2021-2-10","title":"CHANGELOG - v0.18.0 - 2021-2-10","type":"extras"},{"doc":"FixedAn issue when zipgateway sends an invalid FirmwareMDReport packet causing invalid hardware version errors during firmware updates.Thank you to those who contributed to this release:Jean-Francois Cloutier","ref":"changelog.html#v0-17-7-2021-2-4","title":"CHANGELOG - v0.17.7 - 2021-2-4","type":"extras"},{"doc":"FixedGrizzly would throw an exception when calling Grizzly.commands_for_command_class/1Grizzly would always return an empty list of supported commands for a command class when calling Grizzly.commands_for_command_class/1 even though Grizzly supports commands for that command classFix S2 DSK pin setting when the pin was &lt;256Thank you to those who contributed to this release:Jean-Francois Cloutier","ref":"changelog.html#v0-17-6-2021-2-3","title":"CHANGELOG - v0.17.6 - 2021-2-3","type":"extras"},{"doc":"AddedDocs on operating indicator lightFixedCrash when indicator handler is nilMath for MeterReportThank you to those who contributed to this release:Jean-Francois Cloutier","ref":"changelog.html#v0-17-5-2021-1-26","title":"CHANGELOG - v0.17.5 - 2021-1-26","type":"extras"},{"doc":"AddedSupport for handling indicator events via the :indicator_handler option to the Grizzly.Supervisor.","ref":"changelog.html#v0-17-4-2021-1-21","title":"CHANGELOG - v0.17.4 - 2021-1-21","type":"extras"},{"doc":"AddedGrizzly.Trace module for logging Z/IP packets that are sent from and received by Grizzly.FixedNo match error when trying to encode a node id list","ref":"changelog.html#v0-17-3-2021-1-14","title":"CHANGELOG - v0.17.3 - 2021-1-14","type":"extras"},{"doc":"AddedDecoding the NodeInfoCacheGet commandFixedIncorrect return value for NodeInfoCacheGet when decoding the paramsIssues around firmware updates and zipgateway versions &gt;= 7.14.2Thank you to those who contributed to this release:Jean-Francois Cloutier","ref":"changelog.html#v0-17-2-2021-1-13","title":"CHANGELOG - v0.17.2 - 2021-1-13","type":"extras"},{"doc":"Added supported for using zipgateway versions &gt;= 7.14.2.When upgrading from a zipgateway version less than 7.14.2 you should provide the zgw_eeprom_to_sqlite utility in your system or firmware. The utility should be located in /usr/bin. Grizzly will try to run the utility if we detected it.You can configure the database file and eeprom file via :database_file and :eeprom_file options for the Grizzly.Supervisor. These are optional and no changes are necessary for how you start Grizzly if you have already been using Grizzly.AddedSupport for zipgateway versions &gt;= 7.14.2:eeprom_file to supervisor args (optional):database_file to supervisor args (optional)Thank you to those who contributed to this release:Frank Hunleth","ref":"changelog.html#v0-17-1-2021-1-12","title":"CHANGELOG - v0.17.1 - 2021-1-12","type":"extras"},{"doc":"Breaking change with how Grizzly reports water alarms.If you are listening for water alarm notifications you will need to update from :water to :water_alarm. This change was made to align better with the Z-Wave specification.AddedComplete support for all notification eventsSupport for version 2 of the Antitheft command classSupport for SceneActuatorConf command classSupport for SceneActivation command classMore support for Erlang 23.2 DSL messagesChanged:water is not :water_alarm notificationFixedWhen receiving the supervision command class with a command encapsulated Grizzly was not actually processing the encapsulated command.Thank you to those who contributed to this release:Jean-Francois Cloutier","ref":"changelog.html#v0-17-0-2021-1-8","title":"CHANGELOG - v0.17.0 - 2021-1-8","type":"extras"},{"doc":"Added:list_mode param for the Grizzly.ZWave.Commands.AssociationGroupInfoReport command.","ref":"changelog.html#v0-16-2-2020-12-23","title":"CHANGELOG - v0.16.2 - 2020-12-23","type":"extras"},{"doc":"AddedGrizzly.ZWave.Commands.S2ResynchronizationEventFixedData structure change in the associations file when deleting all associationsWrong MultiChannelAssociation version number being reported to devicesEnsure ack responses are sent when extra commands are receivedForce bind to fd00::aaaa::2 since zipgateway forces that all acks come from this addressCrash when receiving errors other than timeouts when trying to establish connections to zipgatewayThank you to those who contributed to this release:Frank Hunleth","ref":"changelog.html#v0-16-1-2020-12-22","title":"CHANGELOG - v0.16.1 - 2020-12-22","type":"extras"},{"doc":"This release introduces a breaking change to the naming of the command class get and command class report modules. If you are using those modules directly, you will need to update to the use the new module names.ChangedGrizzly.ZWave.Commands.CommandClassGet is now Grizzly.ZWave.Commands.VersionCommandClassGetThe :name field for :command_class_get is now :version_command_class_getGrizzly.ZWave.Commands.CommandClassReport is now Grizzly.ZWave.Commands.VersionCommandClassReportThe :name field for :command_class_report is now :version_command_class_reportAddedAdded support for forcing the Z-Wave cache to update when fetching node information. See Grizzly.Node.get_info/2 for more information.Support for OTP 23.2FixedIn some GenServers an exception would cascadeUpdatesEasier to read stack traces when some GenServers crash","ref":"changelog.html#v0-16-0-2020-12-21","title":"CHANGELOG - v0.16.0 - 2020-12-21","type":"extras"},{"doc":"AddedSupport for DoorLock command class version 4FixedQuerying command class versions for extra commands on the LAN will return the version report correctly now.Thank you to those who contributed to this release:Jean-Francois Cloutier","ref":"changelog.html#v0-15-11-2020-12-11","title":"CHANGELOG - v0.15.11 - 2020-12-11","type":"extras"},{"doc":"AddedSupport for querying the gateway about the command class versions it supports when querying extra supported command classes.FixedSpelling error fix for the WakeUpNoMoreInformation command nameThank you to those who contributed to this release:Jean-Francois Cloutier","ref":"changelog.html#v0-15-10-2020-12-8","title":"CHANGELOG - v0.15.10 - 2020-12-8","type":"extras"},{"doc":"AddedSending commands directly to the Z-Wave Gateway by passing Grizzly.send_command/4 :gateway as the node id.How to get DSK for a device in the cookbook docsFixedSpelling, whitespace and markdown issues in docsThank you to those who contributed to this release:Frank Hunleth","ref":"changelog.html#v0-15-9-2020-12-4","title":"CHANGELOG - v0.15.9 - 2020-12-4","type":"extras"},{"doc":"AddedSupport for ZwavePlusInfo command classFixedNo function clause matching error when a connection closesMissing support for :undefined indicatorThank you to those who contributed to this release:Jean-Francois Cloutier","ref":"changelog.html#v0-15-8-2020-12-1","title":"CHANGELOG - v0.15.8 - 2020-12-1","type":"extras"},{"doc":"AddedAdd Grizzly.send_binary/2FixedError when handling older Z-Wave devices that use CRC16 checksums over any security schemaInternal typoThank you to those who contributed to this release:Jean-Francois Cloutier","ref":"changelog.html#v0-15-7-2020-11-30","title":"CHANGELOG - v0.15.7 - 2020-11-30","type":"extras"},{"doc":"AddedAdd support for NetworkUpdateRequest commandAdd Grizzly.Network.request_network_update/0ChangesDrop support for Elixir 1.8 and 1.9Thank you to those who contributed to this release:Jean-Francois Cloutier","ref":"changelog.html#v0-15-6-2020-11-19","title":"CHANGELOG - v0.15.6 - 2020-11-19","type":"extras"},{"doc":"AddedSupport multi-channel associations in the unsolicited destinationFixedAdd the :aggregated_endpoints params to the MultiChannelEndpointReportThank you to those who contributed to this release:Jean-Francois Cloutier","ref":"changelog.html#v0-15-5-2020-11-12","title":"CHANGELOG - v0.15.5 - 2020-11-12","type":"extras"},{"doc":"AddedNetwork management installation and maintenance command classClock command classUnsolicited server support for the extra command classes:Association group command class listAssociation group name getAssociation group info getDevice reset locally notificationChangedWhen a supervision get command is received in the unsolicited destination we send the supervision report for that command back to the sender.Dev deps updatesCode clean upThank you to those who contributed to this release:Jean-Francois Cloutier","ref":"changelog.html#v0-15-4-2020-11-5","title":"CHANGELOG - v0.15.4 - 2020-11-5","type":"extras"},{"doc":"FixedDocumentation fixesInternal firmware update runner bugChangedUpdates in internal association persistenceThank you to those who contributed to this release:Jean-Francois Cloutier","ref":"changelog.html#v0-15-3-2020-10-27","title":"CHANGELOG - v0.15.3 - 2020-10-27","type":"extras"},{"doc":"AddedSupport for the unknown_event notification event for the access_control notification typeFixedSupport SupervisionGet command for notifications.Tried to send :ack_response via unsolicited server which the unsolicited server should not be sending anything directly.Fix typo in codeThank you to those who contributed to this release:Jean-Francois Cloutier","ref":"changelog.html#v0-15-2-2020-10-23","title":"CHANGELOG - v0.15.2 - 2020-10-23","type":"extras"},{"doc":"AddedSupport for getting association grouping report via the Z-Wave PANSupport for setting associations via the Z-Wave PANSupport for removing associations via the Z-Wave PANSupport for getting specific associations via the Z-Wave PANAdded option to Grizzly.Supervisor for where to store data used by the unsolicited server for support of extra command classesChangedWhen getting the associations via the Z-Wave PAN, Grizzly will now look at the stored data and respond accordingly.FixedGrizzly.ZWave.Commands.SwitchBinaryReport did not properly encode and decode the version 2 of the switch binary command class","ref":"changelog.html#v0-15-1-2020-10-09","title":"CHANGELOG - v0.15.1 - 2020-10-09","type":"extras"},{"doc":"This release does a major overhaul on the Grizzly.Transport behaviour. If you haven't implemented a custom transport this release should not effect you and you should be able to update with out too many issues, see the &quot;Removed&quot; section of this release to note any other breaking changes. If you have created a custom transport please see the documentation for Grizzly.Transport to see how transports are now implemented.AddedHow to resetting the controller to the cook bookThe :unsolicited_destination option to the Grizzly.SupervisorSupport for the association get command via the Z-Wave PAN networkSupport proper ack response when a command is delivered through the Z-Wave PANGrizzly.Transports.UDP - This is experimental and is subject to change.Grizzly.ZWave.CommandClasses.CRC16EncapGrizzly.ZWave.Commands.CRC16EncapGrizzly.ZWave.CommandClasses.PowerLevelGrizzly.ZWave.Commands.PowerlevelGetGrizzly.ZWave.Commands.PowerlevelReportGrizzly.ZWave.Commands.PowerlevelSetGrizzly.ZWave.Commands.PowerlevelTestNodeGetGrizzly.ZWave.Commands.PowerlevelTestNodeReportGrizzly.ZWave.Commands.PowerlevelTestNodeSetChangedRefactored the Grizzly.Transport behaviour - please see documentation to see how to use the behaviour now.RemovedGrizzly.Node.get_node_info/1FixedMultiChannelAssociationGet command name fixDocumentationCommand class fixes for the Grizzly.ZWave.CommandClasses.TimeThank you to those who contributed to this release:Jean-Francois CloutierJon Wood","ref":"changelog.html#v0-15-0-2020-10-08","title":"CHANGELOG - v0.15.0 - 2020-10-08","type":"extras"},{"doc":"AddedSupport for power management notifications","ref":"changelog.html#v0-14-8-2020-09-29","title":"CHANGELOG - v0.14.8 - 2020-09-29","type":"extras"},{"doc":"AddedAdded Grizzly.ZWave.Commands.FailedNodeListReport commandThank you to those who contributed to this release:Jean-Francois Cloutier","ref":"changelog.html#v0-14-7-2020-09-25","title":"CHANGELOG - v0.14.7 - 2020-09-25","type":"extras"},{"doc":"AddedCookbook documentation for common uses of GrizzlyChangedReduced the amount of logging","ref":"changelog.html#v0-14-6-2020-09-18","title":"CHANGELOG - v0.14.6 - 2020-09-18","type":"extras"},{"doc":"FixedCommands with aggregated reports did not aggregate the results as expectedCommands with aggregated reports would crash if that device was also handling another command due to the aggregate handler assuming that only one command was being processed at one time","ref":"changelog.html#v0-14-5-2020-09-02","title":"CHANGELOG - v0.14.5 - 2020-09-02","type":"extras"},{"doc":"AddedFull support for ThermostatFanMode mode typesThank you to those who contributed to this release:Jean-Francois Cloutier","ref":"changelog.html#v0-14-4-2020-09-01","title":"CHANGELOG - v0.14.4 - 2020-09-01","type":"extras"},{"doc":"FixedFix the start order of the connection supervisor and Z-Wave ready checker to ensure the supervisor process is alive before trying to test the connection","ref":"changelog.html#v0-14-3-2020-08-31","title":"CHANGELOG - v0.14.3 - 2020-08-31","type":"extras"},{"doc":"AddedGrizzly.ZWave.CRC module for CRC functions related to the Z-Wave protocolRemovedcrc dependency","ref":"changelog.html#v0-14-2","title":"CHANGELOG - v0.14.2","type":"extras"},{"doc":"EnhancementsSupport zipgateway 7.14.01Add Grizzly.ZWave.CommandClasses.CentralSceneAdd Grizzly.ZWave.Commands.CentralSceneConfigurationGetAdd Grizzly.ZWave.Commands.CentralSceneConfigurationSetAdd Grizzly.ZWave.Commands.CentralSceneConfigurationReportAdd Grizzly.ZWave.Commands.CentralSceneNotificationAdd Grizzly.ZWave.Commands.CentralSceneSupportedGetAdd Grizzly.ZWave.Commands.CentralSceneSupportedReportThank you to those who contributed to this release:Jean-Francois Cloutier","ref":"changelog.html#v0-14-1","title":"CHANGELOG - v0.14.1","type":"extras"},{"doc":"This breaking change has to do with how Grizzly is started. It is no longer an application. Grizzly exposes the Grizzly.Supervisor module for a consuming application to add to its supervision tree. All other APIs are backwards capable.See the upgrade guide for more specifics on how to upgrade.Breaking ChangesGrizzly is not an OTP application anymore and will need to be started manually via the new Grizzly.Supervisor moduleAll application config/mix config options are not usedRemoved the Grizzly.Runtime moduleEnhancementsAdd Grizzly.Supervisor moduleAdd Grizzly.ZWave.CommandClasses.IndicatorAdd Grizzly.ZWave.Commands.IndicatorGetAdd Grizzly.ZWave.Commands.IndicatorSetAdd Grizzly.ZWave.Commands.IndicatorReportAdd Grizzly.ZWave.Commands.IndicatorSupportedGetAdd Grizzly.ZWave.Commands.IndicatorSupportedReportAdd Grizzly.ZWave.CommandClasses.AntitheftAdd Grizzly.ZWave.Commands.AntitheftGetAdd Grizzly.ZWave.Commands.AntitheftReportAdd Grizzly.ZWave.CommandClasses.AntitheftUnlockAdd Grizzly.ZWave.Commands.AntitheftUnlockSetAdd Grizzly.ZWave.Commands.AntitheftUnlockGetAdd Grizzly.ZWave.Commands.AntitheftUnlockReportAdd Grizzly.ZWave.Commands.ConfigurationBulkGetAdd Grizzly.ZWave.Commands.ConfigurationBulkSetAdd Grizzly.ZWave.Commands.ConfigurationBulkReportAdd Grizzly.ZWave.Commands.ConfigurationPropertiesGetAdd Grizzly.ZWave.CommandClasses.ApplicationStatusAdd Grizzly.ZWave.Commands.ApplicationBusyAdd Grizzly.ZWave.Commands.ApplicationRejectedRequestThank you to those who contributed to this release:Jean-Francois Cloutier","ref":"changelog.html#v0-14-0","title":"CHANGELOG - v0.14.0","type":"extras"},{"doc":"This update breaks the main Grizzly.send_command/4 API as Grizzly use to respond with different tuples but now it will return with the new Grizzly.Report.t() data structure. A full guide on the breaking changes and what needs to be updated can be found here.This change allows us to gather more information about a response from Grizzly. For example, with this change you can get transmission stats about network properties when sending a command now:{:ok, report} = Grizzly.send_command(node_id, command, command_args, transmission_stats: true) report.transmission_statsSee the Grizzly.Report module for full details.EnhancementsAdd Grizzly.ReportAdd getting transmission stats for sent commandsDocs and type spec updates","ref":"changelog.html#v0-13-0","title":"CHANGELOG - v0.13.0","type":"extras"},{"doc":"FixesHandle multichannel commands that are not appropriately encapsulatedThank you to those who contributed to this release:Jean-Francois Cloutier","ref":"changelog.html#v0-12-3","title":"CHANGELOG - v0.12.3","type":"extras"},{"doc":"EnhancementsAdd Grizzly.ZWave.CommandClasses.HailAdd Grizzly.ZWave.Commands.HailSupport updated Z-Wave spec command params for Grizzly.ZWave.Commands.DoorLockOperationReport","ref":"changelog.html#v0-12-2","title":"CHANGELOG - v0.12.2","type":"extras"},{"doc":"EnhancementsAdd Grizzly.ZWave.Commands.MultiChannelAggregatedMemberGetAdd Grizzly.ZWave.Commands.MultiChannelAggregatedMemberReportAdd Grizzly.ZWave.Commands.MultiChannelCapabilityGetAdd Grizzly.ZWave.Commands.MultiChannelCommandEncapsulationAdd Grizzly.ZWave.Commands.MultiChannelEndpointFindAdd Grizzly.ZWave.Commands.MultiChannelEndpointFindReportAdd Grizzly.ZWave.CommandClasses.MultiCommandAdd Grizzly.ZWave.Commands.MultiCommandEncapsulationAdd Grizzly.ZWave.CommandClasses.TimeAdd Grizzly.ZWave.Commands.DateGetAdd Grizzly.ZWave.Commands.DateReportAdd Grizzly.ZWave.Commands.TimeGetAdd Grizzly.ZWave.Commands.TimeReportAdd Grizzly.ZWave.Commands.TimeOffsetGetAdd Grizzly.ZWave.Commands.TimeOffsetReportAdd Grizzly.ZWave.Commands.TimeOffsetSetAdd Grizzly.ZWave.CommandsClasses.TimeParametersAdd Grizzly.ZWave.Commands.TimeParametersGetAdd Grizzly.ZWave.Commands.TimeParametersReportAdd Grizzly.ZWave.Commands.TimeParametersSetDocumentation updatesFixesSome devices send alarm reports that do not match the specification in a minor way. So, we allow for parsing of these reports now.Fixed internal command class name to module implementation mapping issue for :switch_multilevel_set and :switch_multilevel_get commands.Thank you to those who contributed to this release:Jean-Francois Cloutier","ref":"changelog.html#v0-12-1","title":"CHANGELOG - v0.12.1","type":"extras"},{"doc":"There is a small breaking change that will only effect you if you hard have :water_leak_detected_known_location and :water_leak_dropped_known_location hard coded into your application for any reason. These are notifications about water leaks, and so if you have not directly tried to match on or handle logic about water leak notifications then this breaking change should not effect you.From a high level this release provides updates to Z-Wave notifications in terms of command support and package parsing, extra tooling for better introspection, a handful of new commands and command classes, and helpful configuration items.EnhancementsAdd Grizzly.ZWave.Commands.ApplicationNodeInfoReportAdd Grizzly.ZWave.CommandClass.NodeNamingAdd Grizzly.ZWave.Commands.NodeLocationGetAdd Grizzly.ZWave.Commands.NodeLocationReportAdd Grizzly.ZWave.Commands.NodeLocationSetAdd Grizzly.ZWave.Commands.NodeNameGetAdd Grizzly.ZWave.Commands.NodeNameReportAdd Grizzly.ZWave.Commands.NodeNameSetAdd Grizzly.ZWave.Commands.AlarmGetAdd Grizzly.ZWave.Commands.AlarmSetAdd Grizzly.ZWave.Commands.AlarmEventSupportedGetAdd Grizzly.ZWave.Commands.AlarmEventSupportedReportAdd Grizzly.ZWave.Commands.AlarmTypeSupportedGetAdd Grizzly.ZWave.Commands.AlarmTypeSupportedReportAdd Grizzly.ZWave.Commands.AssociationGroupingsGetAdd Grizzly.ZWave.Commands.AssociationGroupingsReportAdd Grizzly.ZWave.Commands.AssociationRemoveAdd Grizzly.ZWave.Commands.AssociationReportAdd Grizzly.ZWave.Commands.AssociationSpecificGroupingsGetAdd Grizzly.ZWave.Commands.AssociationSpecificGroupingsReportAdd Grizzly.ZWave.CommandClasses.MultiChannelAssociationAdd Grizzly.ZWave.Commands.MultiChannelAssociationGroupingsGetAdd Grizzly.ZWave.Commands.MultiChannelAssociationGroupingsReportAdd Grizzly.ZWave.Commands.MultiChannelAssociationRemoveAdd Grizzly.ZWave.Commands.MultiChannelAssociationReportAdd Grizzly.ZWave.Commands.MultiChannelAssociationSetAdd Grizzly.ZWave.CommandClass.DeviceResetLocallyAdd Grizzly.ZWave.Commands.DeviceResetLocallyNotificationAdd Grizzly.ZWave.Commands.LearnModeSetAdd Grizzly.ZWave.Commands.LearnModeSetStatusAdd Grizzly.Inclusions.learn_mode/1Add Grizzly.Inclusions.learn_mode_stop/0Support version 8 of the Grizzly.ZWave.Commands.AlarmReportSupport parsing naming and location parameters from Z-Wave notificationsAdd mix zipgateway.cfg to print out the zipgateway config that Grizzly is configured to use.Add Grizzly.list_commands/0 to list all support Z-Wave commands in Grizzly.Add Grizzly.commands_for_command_class/1 for listing the Z-Wave commands support by Grizzly for a particular command class.Add :handlers to :grizzly configuration options for firmware update and inclusion handlers.Documentation updatesFixesParsing the wrong byte for into the wrong notification typeInvalid type spec for Grizzly.ZWave.Security.failed_type_from_byte/1Thank you to those who contributed to this release:Jean-Francois Cloutier","ref":"changelog.html#v0-12-0","title":"CHANGELOG - v0.12.0","type":"extras"},{"doc":"Grizzly now supports parsing alarm/notification parameters as a keyword list of parameters. This change is breaking because the event parameters use to be the raw binary we received from the Z-Wave network and now it is a keyword list.We only support lock and keypad event parameters currently, but this puts into place the start of being able to support event parameters.EnhancementsSupport parsing event parameters for lock and keypad operationsThank you to those who contributed to this release:Jean-Francois Cloutier","ref":"changelog.html#v0-11-0","title":"CHANGELOG - v0.11.0","type":"extras"},{"doc":"EnhancementsAdd handle_timeout/2 to the Grizzly.InclusionHandler behaviour. This allows for handling when an inclusion process timesout.Add Grizzly.Inclusions.stop/0 force stop any type of inclusion process.Add Grizzly.FirmwareUpdates module for updating the Z-Wave firmware on Z-Wave hardwareFixesnot parsing command classes correctly on Grizzly.ZWave.Commands.NodeAddStatusNot stopping an inclusion process correctly when calling Grizzly.Inclusions.add_node_stop/0Thank you to those who contributed to this release:Jean-Francois Cloutier","ref":"changelog.html#v0-10-3","title":"CHANGELOG - v0.10.3","type":"extras"},{"doc":"EnhancementsAdd Grizzly.ZWave.Commands.FailedNodeRemoveAdd Grizzly.ZWave.Commands.FailedNodeRemoveStatusFixesSensor types returned from the support sensors reportBroken link in docsThank you to those who contributed to this release:Jean-Francois Cloutier","ref":"changelog.html#v-0-10-2","title":"CHANGELOG - v.0.10.2","type":"extras"},{"doc":"EnhancementsAdd Grizzly.ZWave.Commands.ConfigurationGetAdd Grizzly.ZWave.Commands.ConfigurationReportThank you to those who contributed to this release:Jean-Francois Cloutier","ref":"changelog.html#v-0-10-1","title":"CHANGELOG - v.0.10.1","type":"extras"},{"doc":"Removed the parameter :secure_command_classes from Grizzly.ZWave.Command.NodeInfoCacheReport. Also updated the param :command_classes to be a keyword list of the various command classes that the node can have.The fields in the keyword list are::non_secure_supported:non_secure_controlled:secure_supported:secure_controlledIf you are using :secure_command_classes for checking if the device is securely added you can update like this: {:ok, node_info} = Grizzly.Node.get_info(10) Keyword.get(Grizzly.ZWave.Command.param!(node_info, :command_classes), :secure_controlled)EnhancementsAdd Grizzly.ZWave.Commands.AssociationGroupCommandListGetAdd Grizzly.ZWave.Commands.AssociationGroupCommandListReportAdd Grizzly.ZWave.Commands.AssociationGroupInfoGetAdd Grizzly.ZWave.Commands.AssociationGroupInfoReportAdd Grizzly.ZWave.Commands.AssociationGroupNameGetAdd Grizzly.ZWave.Commands.AssociationGroupNameReportAdd Grizzly.ZWave.Commands.MultiChannelEndpointGetAdd Grizzly.ZWave.Commands.MultiChannelEndpointReportFixesInternal command class name discrepanciesThank you to those who contributed to this release:Jean-Francois Cloutier","ref":"changelog.html#v0-10-0","title":"CHANGELOG - v0.10.0","type":"extras"},{"doc":"The official v0.9.0 release!If you trying to upgrade from v0.8.x please see Grizzly v0.8.0 -&gt; v0.9.0 guide and follow the Changelog from the initial v0.9.0-rc.0 release.Changes from the last rc are:EnhancementsSupport Erlang 23.0 with Elixir 1.10Dep updates and tooling enhancementsFixesmiss spellings of command namesThank you to those who contributed to this release:Jean-Francois Cloutier","ref":"changelog.html#v0-9-0","title":"CHANGELOG - v0.9.0","type":"extras"},{"doc":"EnhancementsAdd Grizzly.ZWave.Commands.FirmwareMDGetAdd Grizzly.ZWave.Commands.FirmwareUpdateMDRequestGetAdd Grizzly.ZWave.Commands.FirmwareUpdateMDRequestReportAdd Grizzly.ZWave.Commands.FirmwareUpdateMDStatusReportAdd Grizzly.ZWave.Commands.FirmwareUpdateMDReportAdd Grizzly.ZWave.Commands.FirmwareUpdateActivationSetAdd Grizzly.ZWave.Commands.FirmwareUpdateActivationReportRemove some dead codeFixesWhen resetting the controller we were not closing the connections to the nodes. This caused some error logging in zipgateway and also left open unused resources. This could cause problems later when reconnecting devices to resources that were already in the system.Thank you to those who contributed to this release:Jean-Francois Cloutier","ref":"changelog.html#v0-9-0-rc-4","title":"CHANGELOG - v0.9.0-rc.4","type":"extras"},{"doc":"EnhancementsSome Z-Wave devices report the wrong value for the switch multilevel report so we added support for those values.FixesWhen two processes quickly sent the same command to the same device only one process would receive the responseThank you to those who contributed to this release:Jean-Francois Cloutier","ref":"changelog.html#v0-9-0-rc-3","title":"CHANGELOG - v0.9.0-rc.3","type":"extras"},{"doc":"DeprecatedGrizzly.Node.get_node_info/1 - use Grizzly.Node.get_info/1 insteadAddedGrizzly.Node.get_info/1Grizzly.ZWave.CommandClasses.SupervisionGrizzly.ZWave.Commands.SupervisionGetGrizzly.ZWave.Commands.SupervisionReportGrizzly.ZWave.CommandClasses.SensorBinaryGrizzly.ZWave.Commands.SensorBinaryGetGrizzly.ZWave.Commands.SensorBinaryReportEnhancementsSupport for DoorLockOperationReport &gt;= V3 parsingFixesBad parsing of NodAddStatus :failed valueThank you to those who contributed to this release:Jean-Francois Cloutier","ref":"changelog.html#v0-9-0-rc-2","title":"CHANGELOG - v0.9.0-rc.2","type":"extras"},{"doc":"Breaking ChangesGrizzly.ZWave.IconTypes removed icon_type from the atom values of the icon name.Grizzly.ZWave.DeciveTypes.icon_name() -&gt; Grizzly.ZWave.DeviceTypes.name()Grizzly.ZWave.DeciveTypes.icon_integer() -&gt; Grizzly.ZWave.DeviceTypes.value()EnhancementsDoc updatesInternal code qualityDeps updatesBetter types around DSKsCI support for elixir versions 1.8, 1.9, and 1.10Support all versions of the meter reportSupport a low battery report","ref":"changelog.html#v0-9-0-rc-1","title":"CHANGELOG - v0.9.0-rc.1","type":"extras"},{"doc":"For more detailed guide to the breaking changes and how to upgrade please see our Grizzly v0.8.0 -&gt; v0.9.0 guide.This release presents a simpler API, faster boot time, more robustness in Z-Wave communication, and resolves all open issues on Grizzly that were reported as bugs.Removed APIsGrizzly.Node structGrizzly.Conn moduleGrizzly.Notifications moduleGrizzly.Packet moduleGrizzly.close_connectionGrizzly.command_class_versions_known?Grizzly.update_command_class_versionsGrizzly.start_learn_modeGrizzly.get_command_class_versionGrizzly.has_command_classGrizzly.connected?Grizzly.has_command_class_namesGrizzly.configGrizzly.Network.busy?Grizzly.Network.ready?Grizzly.Network.get_stateGrizzly.Network.set_stateGrizzly.Network.get_nodeGrizzly.Node.newGrizzly.Node.updateGrizzly.Node.put_ipGrizzly.Node.get_ipGrizzly.Node.connectGrizzly.Node.disconnectGrizzly.Node.make_configGrizzly.Node.has_command_class?Grizzly.Node.connected?Grizzly.Node.command_class_namesGrizzly.Node.update_command_class_versionsGrizzly.Node.get_command_class_versionGrizzly.Node.command_class_version_known?Grizzly.Node.update_command_classGrizzly.Node.put_associationGrizzly.Node.get_association_listGrizzly.Node.configure_associationGrizzly.Node.get_network_informationGrizzly.Node.initialize_command_versionsMoved APIsGrizzly.reset_controller -&gt; Grizzly.Network.reset_controllerGrizzly.get_nodes -&gt; Grizzly.Network.get_node_idsGrizzly.get_node_info -&gt; Grizzly.Node.get_node_infoGrizzly.Notifications.subscribe -&gt; Grizzly.subscribe_command and Grizzly.subscribe_commandsGrizzly.Notifications.unsubscribe -&gt; Grizzly.unsubscribeGrizzly.add_node -&gt; Grizzly.Inclusions.add_nodeGrizzly.remove_node -&gt; Grizzly.Inclusions.remove_nodeGrizzly.add_node_stop -&gt; Grizzly.Inclusions.add_node_stopGrizzly.remove_node_stop -&gt; Grizzly.Inclusions.remove_node_stopGrizzly.Client -&gt; Grizzly.TransportGrizzly.Security -&gt; Grizzly.ZWave.SecurityGrizzly.DSK -&gt; Grizzly.ZWave.DSKGrizzly.Node.add_lifeline_group -&gt; Grizzly.Node.set_lifeline_associationWe moved all the commands and command classes to be under the the Grizzly.ZWave module namespace and refactored the command behaviour.Grizzly.send_command ChangesThe main API function to Grizzly has changed in that it only takes a node id, command name (atom), command args, and command options.Also it no longer returns a plain map when there is data to report back from a Z-Wave node but it will return {:ok, %Grizzly.ZWave.Command{}}.Please see Grizzly and Grizzly.ZWave.Command docs for more information.ConnectionsGrizzly uses the zipgateway binary under the hood. The binary has its own networking stack and provides a DTLS server for us to connect to. Prior to Grizzly v0.9.0 we greatly exposed that implementation detail. However, starting in Grizzly v0.9.0 we have hidden that implementation detail away and all connection functionally is handle by Grizzly internally. This leaves the consumer of Grizzly to just work about sending and receiving commands.If you are using %Grizzly.Conn{} directly this is no longer available and you should upgrade to just using the node id you were sending commands to.When Grizzly is ReadyWe use to send a notification to let the consumer to know when Grizzly is read. Staring in v0.9.0 the consumer needs to configure Grizzly's runtime with the on_ready module, function, arg callback.config :grizzly, runtime: [ on_ready: {MyApp, :some_function, []} ]See Grizzly.Runtime for more detailsInclusion Handler BehaviourAdding and removing a Z-Wave node can be a very interactive process that involves users being able to talk to the including controller and device. The way Grizzly &lt; v0.9.0 did it wasn't vary useful or robust. By adding the the inclusion handler behaviour we allow the consumer to have full control over the inclusion process, enabling closer to Z-Wave specification inclusion process.See Grizzly.InclusionHandler and Grizzly.Inclusions for more information.Command Handler BehaviourIf you need to handle a Z-Wave command lifecycle differently than the default Grizzly implementation you can make your own handler and pass it into Grizzly.send_command as an option:Grizzly.send_command(node_id, :switch_binary_set, [value: :on], handler: MyHandler)See Grizzly.CommandHandler for more information.Supporting CommandsAt the point of the rc.0 release are not fully 100% supporting the same commands as in &lt; v0.8.8, but we are really close. The commands that we haven't pulled over are not critical to average Z-Wave device control. We will work to get all the commands back into place.Thank you to Jean-Francois Cloutier for contributing so much to this release.","ref":"changelog.html#v0-9-0-rc-0","title":"CHANGELOG - v0.9.0-rc.0","type":"extras"},{"doc":"EnhancementsMake Z-Wave versions standard version formattingFixesParing the FirmwareMD report for version 5Fix spec for queued commands","ref":"changelog.html#v0-8-8","title":"CHANGELOG - v0.8.8","type":"extras"},{"doc":"EnhancementsSupport FIRMWARE_UPDATE_MD meta data report command v5","ref":"changelog.html#v0-8-7","title":"CHANGELOG - v0.8.7","type":"extras"},{"doc":"Fixesduplicate fields on the Grizzly.Node struct","ref":"changelog.html#v0-8-6","title":"CHANGELOG - v0.8.6","type":"extras"},{"doc":"Fixesvarious spelling and documentation fixesdialzyer fixes","ref":"changelog.html#v0-8-5","title":"CHANGELOG - v0.8.5","type":"extras"},{"doc":"FixesHandle when there are no nodes in the node provisioning list when requesting all the DSKs.","ref":"changelog.html#v0-8-4","title":"CHANGELOG - v0.8.4","type":"extras"},{"doc":"EnhancementsSupport Wake Up v2 and Multi Channel Association v3","ref":"changelog.html#v0-8-3","title":"CHANGELOG - v0.8.3","type":"extras"},{"doc":"EnhancementsSupport SWITCH_BINARY_REPORT version 2","ref":"changelog.html#v0-8-2","title":"CHANGELOG - v0.8.2","type":"extras"},{"doc":"EnhancementsUpdate docs and resourcesFixesAn issue when the unsolicited message server would cause a no match error that propagated up the supervision treeThank you to those who contributed to this release:Ryan Winchester","ref":"changelog.html#v0-8-1","title":"CHANGELOG - v0.8.1","type":"extras"},{"doc":"Adds support for handling SmartStart meta extension fields.These fields give more information about the current status, inclusion methods, and product information for the SmartStart device.There are two breaking changes:All SmartStart meta extensions were moved from Grizzly.CommandClass.NodeProvisioning namespace into the Grizzly.SmartStart.MetaExtension namespace.Upon finalizing the meta extension behaviour and API we made changes to how previously supported meta extensions worked. Namely, we added a new/1 callback that does parameter validation, and returns {:ok, MetaExtension.t()}. This breaks the pervious behaviour of to_binary/1 functions in perviously implemented meta extensions.EnhancementsFull support for SmartStart meta extensionsAdd meta_extensions field to Grizzly.CommandClass.NodeProvisioning commands that can handle meta extensionsUpdate Grizzly.Conn.Server.Config docsFixesInvalid keep alive (heart beat) intervalSet correct constraints on Time command offset valuesThank you to those who contributed to this release:Jean-Francois CloutierRyan Winchester","ref":"changelog.html#v0-8-0","title":"CHANGELOG - v0.8.0","type":"extras"},{"doc":"Introduces SmartStart support!SmartStart will allow you to pair a device to a Z-Wave controller with out turning the device on. Devices that support SmartStart will have a device specific key (DSK) that you can provide to the controller prior to turning on the device.iex&gt; Grizzly.send_command(Grizzly.Controller, Grizzly.CommandClass.NodeProvisioning.Set, dsk: dsk) :okAfter running the above command you can plug in your SmartStart device and the controller will try to join the Z-Wave network automatically.As a note, your controller might not have the necessary firmware to have SmartStart.To verify this you can use RingLogger to read zipgateway logs which at the start will log if the controller supports SmartStart.Breaking ChangesBreaking change to the return value of sending Grizzly.CommandClass.ZipNd.InvNodeSolicitation.When using that function send_command would return {:ok, {:node_ip, node_id, ip_address}} but now it returns {:ok, %{ip_address: ip_address, node_id: node_id, home_id: home_id}}.EnhancementsSmartStart support through the NodeProvisioning command classAdded home_id field to Grizzly.Node.t()Support fetching home_id of the Z-Wave nodes when fetching Z-Wave information about the node","ref":"changelog.html#v0-7-0","title":"CHANGELOG - v0.7.0","type":"extras"},{"doc":"FixesApplication start failure when providing the correct data structure to the zipgateway_cfg configuration field","ref":"changelog.html#v0-6-6","title":"CHANGELOG - v0.6.6","type":"extras"},{"doc":"EnhancementsSupport GetDSK commandSupport FailedNodeRemove commandAllow zipgateway_path configurationGenerate the zipgateway.cfg to allow device specific information to be passed into the zipgateway runtime.","ref":"changelog.html#v0-6-5","title":"CHANGELOG - v0.6.5","type":"extras"},{"doc":"EnhancementsValidation of UserCode arguments to help ensure usage of Grizzly follows the Z-Wave specification","ref":"changelog.html#v0-6-4","title":"CHANGELOG - v0.6.4","type":"extras"},{"doc":"EnhancementsSupports AssociationGroupInformation Command Class","ref":"changelog.html#v0-6-3","title":"CHANGELOG - v0.6.3","type":"extras"},{"doc":"EnhancementsRemove the dependence on pidof allowing grizzly to work on any nerves device without the need of busyboxv0.6.1EnhancementsUpdate commands IntervalGet and ManufacturerSpecificGet to be more consistentBetter handling of invalid ManufacturerSpecific info received from devicesv0.6.0Changed Grizzly.CommandClass.CommandClassVersion to Grizzly.CommandClass.Version and changed Grizzly.ComamndClass.CommandClassVersion.Get to Grizzly.CommandClass.Version.CommandClassGet as these names reflect the Z-Wave specification better.If you only have used Grizzly.get_command_class_version/2 and the related function in Grizzly.Node module this change should not effect you.EnhancementsAdd support for:MultiChannelAssociation Command ClassWakeUp Command Class NoMoreInformation commandComplete Association Command ClassZwaveplusInfo Command ClassVersion Get CommandClean up docsRenamed Grizzly.CommandClass.CommandClassVersion to Grizzly.CommandClass.VersionRenamed Grizzly.CommandClass.CommandClassVersion.Get to Grizzly.CommandClass.Version.CommandClassGetv0.5.0Introduces Grizzly.Command.EncodeError exception and updates encoding and decoding functions to return tagged tuples. We now use these things when trying to send a command via Grizzly.send_command/3 so if you have invalid command arguments we can provide useful error handling with {:error, Grizzly.Command.EncodeError.t()}. The EncodeError.t() implements Elixir's exception behaviour so you can leverage the standard library to work with the exception.Unless you have implemented custom commands or used one of the many command encoders or decodes explicitly this update should not affect you too much. If you have used the encoder/decoders explicitly please see the documentation for the ones you have used to see the updated API. If you have written a command we encourage you to validate the arguments and return the {:error, EncodeError.t()} to improve the usability of and robustness your command. The new Grizzly.Command.Encoding module provides some useful functionality for validating specs for command arguments.EnhancementsProvide command argument validation and error handling via Grizzly.Command.EncodeError.()Update all the command arg encoder/decoder to use tagged tuples for better handling of invalid command argumentsIntroduces new Grizzly.Command.Encoding modules for helping validate command arugment specificationsFixesCrashes when providing invalid command argumentsv0.4.3EnhancementsSupport Powerlevel command classDoc clean upGrizzly.send_command/2 and Grizzly.send_command/3 can be passed a node id instead of a node.v0.4.2EnhancementsSupport NoOperation command classv0.4.1EnhancementsAdd support for Network Management Installation MaintenanceUpdates to docs and examplesv0.4.0Changed how configuration works.Grizzly now requires the serial port to be configured:config :grizzly, serial_port: &quot;/dev/ttyACM0&quot;Also added the pidof_bin configuration option to allow official Nerves systems to work with some of the Grizzly scripts the call that utility by using the busybox package and pointing to the executable of pidof that is compiled with busybox.If you are using a custom system you can add that utility to the busybox config, and not need to use this configuration option.config :grizzly, pidof_bin: &quot;/srv/erlang/lib/busybox-0.1.2/priv/bin/pidof&quot;Double check the version of busybox you are using and make sure that version matches the version in the pidof_bin path.Changed run_grizzly_bin to run_zipgateway_bin.","ref":"changelog.html#v0-6-2","title":"CHANGELOG - v0.6.2","type":"extras"},{"doc":"EnhancementsImplement multilevel sensor command to get supported sensor types","ref":"changelog.html#v0-3-1","title":"CHANGELOG - v0.3.1","type":"extras"},{"doc":"The big change here is removing the in memory cache for devices on the network. Most common use cases will be for a consuming application to hold on to the network device information and apply some costume logic to now that is managed.Also, we would have to keep both the external and internal cache in sync, which is really hard and was creating an odd event based system, which also lends itself to complexity.Breaking ChangesGrizzly.list_nodes() -&gt; Grizzly.get_nodes()This is mostly because before we were listing nodes from a cache, and now we are getting nodes from the Z-Wave network.Also with get_nodes we don't automatically connect to the nodes. So getting and connecting to all nodes on the Z-Wave network might look something like this:def get_and_connect() do case Grizzly.get_nodes() do {:ok, nodes} -&gt; Enum.map(nodes, &amp;Grizzly.Node.connect/1) error -&gt; error end endGrizzly.update_command_class_versions/2 -&gt; Grizzly.update_command_class_versions/1Before we would pass if the update would be async or not after reviewing how this gets used it made sense to always do it sync. Also it returns a Node.t() now with the command classes updated with the version.This is the same change found in Grizzly.Node.update_command_class_versionsGrizzly.command_class_version/3 -&gt; Grizzly.get_command_class_version/2Removed the use_cache param as there is no longer a cache.Same change found in Grizzly.Node.get_command_class_versionEnhancementsSupport Grizzly.CommandClass.Time command classSupport Grizzly.CommandClass.TimeParameters GET and SET commandsSupport Grizzly.CommandClass.ScheduleEntryLock command classGrizzly.Notifications.subscribe_all/1 - subscribe to many notifications at onceGrizzly.CommandClass.name/1 - get the name of the command classGrizzly.CommandClass.version/1 - get the version of the command classGrizzly.Network.get_nodes/0 - get the nodes on the networkGrizzly.Network.get_node/1 - get a node by node id from the networkGrizzly.Network.get_node_info/1 - get node information about a node via node idGrizzly.Node.get_ip/1 - can now take either a Node.t() or a node idUpdatesDocs and type clean upFixesTimeout when getting command class versions","ref":"changelog.html#v0-3-0","title":"CHANGELOG - v0.3.0","type":"extras"},{"doc":"UpdatesSupport for the time command classFixesTime-boxing of getting a command class version","ref":"changelog.html#v0-2-1","title":"CHANGELOG - v0.2.1","type":"extras"},{"doc":"FixesLogging with old ZipGateway label is now GrizzlyFix queued API from {ZipGateway, :queued_response, ref, response} to {Grizzly, :queued_response, ref, response}Fix timeout error when waiting for DTLS server from the zipgateway side","ref":"changelog.html#v0-2-0","title":"CHANGELOG - v0.2.0","type":"extras"},{"doc":"Grizzly CookbookBelow are short notes about using Grizzly.Starting GrizzlyDocker Local DevelopmentAdd DevicesRemove DevicesFactory Reset ControllerCommand BasicsBinary SwitchesDoor LocksDSKIndicator Light","ref":"cookbook.html","title":"Grizzly Cookbook","type":"extras"},{"doc":"If you using Grizzly you will need to start the supervision tree manually.Grizzly.Supervisor.start_link(opts)or add the supervisor to your supervision tree:children = [ ... other processes ... {Grizzly.Supervisor, grizzly_opts}, ... other processes ... ] Supervisor.init(children, supervisor_opts)","ref":"cookbook.html#starting-grizzly","title":"Grizzly Cookbook - Starting Grizzly","type":"extras"},{"doc":"Getting the zipgateway binary compiled and running can be hard. Due to licenses we cannot redistribute a pre-compiled version either. However, the zipgateway-env project has is a docker based environment that is setup to compile zipgateway from source and provides a CLI for running the binary.After getting zipgateway-env setup and working you can use grizzly locally. You will need to pass the :run_zipgateway option when you start Grizzly setting it to false:iex&gt; Grizzly.Supervisor.start_link(run_zipgateway: false)children = [ ... other processes ... {Grizzly.Supervisor, [run_zipgateway: false]}, ... other processes ... ] Supervisor.init(children, supervisor_opts)","ref":"cookbook.html#docker-local-development","title":"Grizzly Cookbook - Docker Local Development","type":"extras"},{"doc":"There are 3 security schemas a device can be included with:No SecurityS0[S2]When adding a device you will need to put the device into inclusion mode. How to do this is normally found in the device's user manual. So, be sure to read that to learn how to add the device to the Z-Wave network.Also, you will need to put the controller into inclusion mode:Grizzly.Inclusions.add_node()After an inclusion is done the calling process will receive this message:{:grizzly, :report, %Grizzly.Report{}}Where the Grizzly.Report will have the command field contain the NodeAddStatus command.That command's param :status will tell you if inclusion failed or not:alias Grizzly.ZWave.Command #... code ... def handle_info({:grizzly, :report, report}, state) do case report.command.name do :node_add_status -&gt; handle_node_add_status(report.command, state) end end defp handle_node_status(command, state) do case Command.param!(command, :status) do :done -&gt; Logger.info(&quot;YAY!&quot;) :failed -&gt; Logger.info(&quot;Sad!&quot;) end {:noreply, state} endIf you want to check the security schema that was used you can check the NodeAddStatus command param :granted_keys:def get_security(node_add_status_command) do node_add_status_command |&gt; Command.param!(:granted_keys) |&gt; Grizzly.ZWave.Security.get_highest_level() endNo SecurityNo security is done in these 3 stepsPut the controller in inclusion modePut the device in inclusion modeWait until NodeAddStatus command is receivedS0S0 inclusion is done the same way as No Security. The only difference the :granted_keys param will be [:s0].","ref":"cookbook.html#add-devices","title":"Grizzly Cookbook - Add Devices","type":"extras"},{"doc":"To remove a device you can call:Grizzly.Inclusions.remove_device()By default you will get a message sent to the calling process that looks like:{:grizzly, :report, %Grizzly.Report{}}Where the report command that is received is Grizzly.ZWave.Commands.NodeRemoveStatus.You can also provide an Inclusion handler which is explained in Add Devices.","ref":"cookbook.html#remove-devices","title":"Grizzly Cookbook - Remove Devices","type":"extras"},{"doc":"If you have been doing development and adding and removing devices or testing some Z-Wave Network functionally that has lead to the network getting in a broken state and you just want to start over again you can reset your controller by doing this:Grizzly.Network.reset_controller()This will make the controller forget any devices that are paired with it and delete all node provisioning entries from the SmartStart node provisioning list.For devices that thought they were included on the newly reset controller you will to excluded them by going through the remove devices steps before you are able to re-include them back into the controller's network.","ref":"cookbook.html#factory-reset-controller","title":"Grizzly Cookbook - Factory Reset Controller","type":"extras"},{"doc":"In Z-Wave everything that is sent and received is a command. The controller will send commands to a device and the device will send commands back. However, there is lifecycle these command go through within Grizzly so the abstraction Grizzly presents is you send a command and receive a report.The reason for a report is because normally when you send a command and the device answers to that command it will send a command who's name normally ends with Report.When you get command reports backThe most common case you get a command report back is when you send a GET based command. That is you want to read some value from the device. Common commands that expect a report are:Grizzly.ZWave.Commands.SwitchBinaryGetGrizzly.ZWave.Commands.DoorLockOperationGetGrizzly.ZWave.Commands.UserCodesGetGrizzly.ZWave.Commands.ThermostatSetpointGetJust to highlight a few.There is common pattern here: If the command name ends with Get it probably will receive a report command back.When you get ack responses backThe other main report you will receive is an :ack_response. This report just says the communication to the device was successful. That does not mean the device will perform what you sent, but that is was received. This is common when you want to set a value on the device.Commands ending with Set will normally be these commands.But the Get and the Set commands can have exceptions to the normal so please read the module documentation for the command your are using.","ref":"cookbook.html#command-basics","title":"Grizzly Cookbook - Command Basics","type":"extras"},{"doc":"Binary switches are your basic on-off switch. Z-Wave commands to control these are:Commands:Grizzly.ZWave.Commands.SwitchBinaryGetGrizzly.ZWave.Commands.SwitchBinarySetReport:Grizzly.ZWave.Commands.SwitchBinaryReportUsage:iex&gt; {ok, report} = Grizzly.send_command(switch_id, :switch_binary_get) iex&gt; Command.param!(report.command, :target_value) :oniex&gt; {:ok, %Grizzly.Report{type: :ack_response}} = Grizzly.send_command(switch_id, :switch_binary_set, value: :off) {:ok, %Grizzly.Report{}}","ref":"cookbook.html#binary-switches","title":"Grizzly Cookbook - Binary Switches","type":"extras"},{"doc":"Commands:Grizzly.ZWave.Commands.DockLockOperationGetGrizzly.ZWave.Commands.DockLockOperationSetReports:Grizzly.ZWave.Commands.DockLockOperationReportUsage:iex&gt; {:ok, report} = Grizzly.send_command(lock_id, :door_lock_operation_get) iex&gt; Command.param!(report.command, :mode) :securediex&gt; {:ok, %Grizzly.Report{type: :ack_response}} = Grizzly.send_command(lock_id, :dock_lock_operation_set, mode: :unsecured) {:ok, %Grizzly.Report{}}","ref":"cookbook.html#door-locks","title":"Grizzly Cookbook - Door Locks","type":"extras"},{"doc":"This returns this node's DSK. This is normally printed on a label as a QRCode or a UUID and is what will show up on a hub if you include this node into a Z-Wave network.iex&gt; Grizzly.Node.get_dsk(1, :learn) {:ok, %Grizzly.Report{ command: %Grizzly.ZWave.Command{ command_byte: 9, command_class: Grizzly.ZWave.CommandClasses.NetworkManagementBasicNode, impl: Grizzly.ZWave.Commands.DSKReport, name: :dsk_report, params: [ seq_number: 58, add_mode: :learn, dsk: &quot;12345-12345-12345-12345-12345-12345-12345-12345&quot; ] }, command_ref: #Reference&lt;0.2080011265.2613837825.149583&gt;, node_id: 1, queued: false, queued_delay: 0, status: :complete, transmission_stats: [], type: :command }}","ref":"cookbook.html#dsk","title":"Grizzly Cookbook - DSK","type":"extras"},{"doc":"Z-Wave requires that devices be able to identify themselves. Here's how to test this:# Turn the indicator on iex&gt; Grizzly.send_command(1, :indicator_set, resources: [ [indicator_id: :node_identify, property_id: :toggling_periods, value: 1], [indicator_id: :node_identify, property_id: :toggling_cycles, value: 1] ] ) # Turn off iex&gt; Grizzly.send_command(1, :indicator_set, resources: [ [indicator_id: :node_identify, property_id: :toggling_periods, value: 0], [indicator_id: :node_identify, property_id: :toggling_cycles, value: 0] ] )","ref":"cookbook.html#indicator-light","title":"Grizzly Cookbook - Indicator Light","type":"extras"}]